@@ -115,7 +115,7 @@ bool CPlayListPlayer::OnMessage(CGUIMessage &message)
   return false;
 }
 
-int CPlayListPlayer::GetNextSong(int offset) const
+int CPlayListPlayer::GetNextItemIdx(int offset) const
 {
   if (m_iCurrentPlayList == TYPE_NONE)
     return -1;
@@ -141,7 +141,7 @@ int CPlayListPlayer::GetNextSong(int offset) const
   return song;
 }
 
-int CPlayListPlayer::GetNextSong()
+int CPlayListPlayer::GetNextItemIdx()
 {
   if (m_iCurrentPlayList == TYPE_NONE)
     return -1;
@@ -182,7 +182,7 @@ int CPlayListPlayer::GetNextSong()
 
 bool CPlayListPlayer::PlayNext(int offset, bool bAutoPlay)
 {
-  int iSong = GetNextSong(offset);
+  int iSong = GetNextItemIdx(offset);
   const CPlayList& playlist = GetPlaylist(m_iCurrentPlayList);
 
   if ((iSong < 0) || (iSong >= playlist.size()) || (playlist.GetPlayable() <= 0))
@@ -197,7 +197,11 @@ bool CPlayListPlayer::PlayNext(int offset, bool bAutoPlay)
     return false;
   }
 
-  return Play(iSong, "", false);
+  const auto& components = CServiceBroker::GetAppComponents();
+  const auto appPlayer = components.GetComponent<CApplicationPlayer>();
+  const std::string player = appPlayer->GetName();
+
+  return Play(iSong, player, false);
 }
 
 bool CPlayListPlayer::PlayPrevious()
@@ -241,7 +245,7 @@ bool CPlayListPlayer::Play()
   return Play(0, "");
 }
 
-bool CPlayListPlayer::PlaySongId(int songId)
+bool CPlayListPlayer::PlayItemIdx(int itemIdx)
 {
   if (m_iCurrentPlayList == TYPE_NONE)
     return false;
@@ -252,7 +256,8 @@ bool CPlayListPlayer::PlaySongId(int songId)
 
   for (int i = 0; i < playlist.size(); i++)
   {
-    if (playlist[i]->HasMusicInfoTag() && playlist[i]->GetMusicInfoTag()->GetDatabaseId() == songId)
+    if (playlist[i]->HasMusicInfoTag() &&
+        playlist[i]->GetMusicInfoTag()->GetDatabaseId() == itemIdx)
       return Play(i, "");
   }
   return Play();
@@ -403,13 +408,13 @@ bool CPlayListPlayer::Play(int iSong,
   return true;
 }
 
-void CPlayListPlayer::SetCurrentSong(int iSong)
+void CPlayListPlayer::SetCurrentItemIdx(int iSong)
 {
   if (iSong >= -1 && iSong < GetPlaylist(m_iCurrentPlayList).size())
     m_iCurrentSong = iSong;
 }
 
-int CPlayListPlayer::GetCurrentSong() const
+int CPlayListPlayer::GetCurrentItemIdx() const
 {
   return m_iCurrentSong;
 }
@@ -689,6 +694,10 @@ void CPlayListPlayer::Add(Id playlistId, const CFileItemPtr& pItem)
   list.Add(pItem);
   if (list.IsShuffled())
     ReShuffle(playlistId, iSize);
+
+  // its likely that the playlist changed
+  CGUIMessage msg(GUI_MSG_PLAYLIST_CHANGED, 0, 0);
+  CServiceBroker::GetGUI()->GetWindowManager().SendMessage(msg);
 }
 
 void CPlayListPlayer::Add(Id playlistId, const CFileItemList& items)
@@ -837,11 +846,11 @@ void PLAYLIST::CPlayListPlayer::OnApplicationMessage(KODI::MESSAGING::ThreadMess
       Play();
     break;
 
-  case TMSG_PLAYLISTPLAYER_PLAY_SONG_ID:
+  case TMSG_PLAYLISTPLAYER_PLAY_ITEM_ID:
     if (pMsg->param1 != -1)
     {
       bool *result = (bool*)pMsg->lpVoid;
-      *result = PlaySongId(pMsg->param1);
+      *result = PlayItemIdx(pMsg->param1);
     }
     else
       Play();
