@@ -8,27 +8,38 @@
 
 #pragma once
 
+#include "threads/CriticalSection.h"
+
+#include <map>
 #include <memory>
+#include <string>
 
 #include <pipewire/core.h>
 
-namespace AE
-{
-namespace SINK
+namespace KODI
 {
 namespace PIPEWIRE
 {
 
+class CPipewireCore;
+class CPipewireGlobal;
+
 class CPipewireRegistry
 {
 public:
-  explicit CPipewireRegistry(pw_core* core);
+  explicit CPipewireRegistry(CPipewireCore& core);
   CPipewireRegistry() = delete;
-  ~CPipewireRegistry() = default;
+  ~CPipewireRegistry();
 
   pw_registry* Get() const { return m_registry.get(); }
 
-  void AddListener(void* userdata);
+  CPipewireCore& GetCore() const { return m_core; }
+
+  std::map<uint32_t, std::unique_ptr<CPipewireGlobal>>& GetGlobals() { return m_globals; }
+
+  // C++ BasicLockable requirements
+  void lock() { m_lock.lock(); }
+  void unlock() { m_lock.unlock(); }
 
 private:
   static void OnGlobalAdded(void* userdata,
@@ -41,6 +52,8 @@ private:
 
   static pw_registry_events CreateRegistryEvents();
 
+  CPipewireCore& m_core;
+
   const pw_registry_events m_registryEvents;
 
   spa_hook m_registryListener;
@@ -50,8 +63,11 @@ private:
   };
 
   std::unique_ptr<pw_registry, PipewireRegistryDeleter> m_registry;
+
+  std::map<uint32_t, std::unique_ptr<CPipewireGlobal>> m_globals;
+
+  CCriticalSection m_lock;
 };
 
 } // namespace PIPEWIRE
-} // namespace SINK
-} // namespace AE
+} // namespace KODI
