@@ -12,12 +12,8 @@
 
 #include <stdexcept>
 
-namespace AE
-{
-namespace SINK
-{
-namespace PIPEWIRE
-{
+using namespace KODI;
+using namespace PIPEWIRE;
 
 CPipewireThreadLoop::CPipewireThreadLoop()
 {
@@ -39,12 +35,12 @@ void CPipewireThreadLoop::Stop()
   pw_thread_loop_stop(m_mainloop.get());
 }
 
-void CPipewireThreadLoop::Lock()
+void CPipewireThreadLoop::Lock() const
 {
   pw_thread_loop_lock(m_mainloop.get());
 }
 
-void CPipewireThreadLoop::Unlock()
+void CPipewireThreadLoop::Unlock() const
 {
   pw_thread_loop_unlock(m_mainloop.get());
 }
@@ -61,7 +57,3 @@ void CPipewireThreadLoop::Signal(bool accept)
 {
   pw_thread_loop_signal(m_mainloop.get(), accept);
 }
-
-} // namespace PIPEWIRE
-} // namespace SINK
-} // namespace AE
