@@ -1818,7 +1818,11 @@ extern "C"
 
       if (value_start != NULL)
       {
-        char var[64];
+        const size_t varSize = value_start - envstring;
+        char* var = static_cast<char*>(std::malloc(varSize + 1));
+        if (!var)
+          return -1;
+
         int size = strlen(envstring) + 1;
         char *value = (char*)malloc(size);
 
@@ -1827,7 +1831,7 @@ extern "C"
         value[0] = 0;
 
         memcpy(var, envstring, value_start - envstring);
-        var[value_start - envstring] = 0;
+        var[varSize] = 0;
         char* temp = var;
         while (*temp)
         {
@@ -1880,6 +1884,7 @@ extern "C"
         }
 
         free(value);
+        std::free(var);
       }
     }
 
