@@ -15,9 +15,9 @@ CRPProcessInfoAndroid::CRPProcessInfoAndroid() : CRPProcessInfo("Android")
 {
 }
 
-CRPProcessInfo* CRPProcessInfoAndroid::Create()
+std::unique_ptr<CRPProcessInfo> CRPProcessInfoAndroid::Create()
 {
-  return new CRPProcessInfoAndroid();
+  return std::make_unique<CRPProcessInfoAndroid>();
 }
 
 void CRPProcessInfoAndroid::Register()
