@@ -19,7 +19,7 @@ class CRPProcessInfoOSX : public CRPProcessInfo
 public:
   CRPProcessInfoOSX();
 
-  static CRPProcessInfo* Create();
+  static std::unique_ptr<CRPProcessInfo> Create();
   static void Register();
 };
 } // namespace RETRO
