@@ -192,6 +192,15 @@ void CRPBaseRenderer::ManageRenderArea(const IRenderBuffer& renderBuffer)
   if (!(m_context.IsFullScreenVideo() || m_context.IsCalibrating()))
     CRenderUtils::ClipRect(viewRect, m_sourceRect, destRect);
 
+  if (stretchMode == STRETCHMODE::Zoom)
+  {
+    // Crop for zoom mode
+    CRenderUtils::CropSource(m_sourceRect, rotationDegCCW, viewRect.Width(), viewRect.Height(),
+                             static_cast<float>(sourceWidth), static_cast<float>(sourceHeight),
+                             destRect.Width(), destRect.Height());
+    destRect = viewRect;
+  }
+
   // Adapt the drawing rect points if we have to rotate
   m_rotatedDestCoords = CRenderUtils::ReorderDrawPoints(destRect, rotationDegCCW);
 }
