@@ -8,6 +8,7 @@
 
 #pragma once
 
+#include "cores/VideoPlayer/DVDCodecs/Overlay/DVDOverlay.h"
 #include "cores/VideoPlayer/DVDDemuxers/DVDDemux.h"
 
 #include <string>
@@ -48,11 +49,6 @@ public:
    */
   virtual bool Open(CDVDStreamInfo &hints, CDVDCodecOptions &options) = 0;
 
-  /*
-   * Dispose, Free all resources
-   */
-  virtual void Dispose() = 0;
-
   /*
    * returns one or a combination of VC_ messages
    * pData and iSize can be NULL, this means we should flush the rest of the data.
@@ -75,7 +71,7 @@ public:
    * returns a valid overlay or NULL
    * the data is valid until the next Decode call
    */
-  virtual CDVDOverlay* GetOverlay() = 0;
+  virtual std::shared_ptr<CDVDOverlay> GetOverlay() = 0;
 
   /*
    * return codecs name
