@@ -27,14 +27,9 @@ namespace
 constexpr double DEFAULT_DURATION = 20.0 * static_cast<double>(DVD_TIME_BASE);
 } // namespace
 
-CDVDOverlayCodecText::CDVDOverlayCodecText() : CDVDOverlayCodec("Text Subtitle Decoder")
+CDVDOverlayCodecText::CDVDOverlayCodecText()
+  : CDVDOverlayCodec("Text Subtitle Decoder"), m_pOverlay(nullptr)
 {
-  m_pOverlay = nullptr;
-}
-
-CDVDOverlayCodecText::~CDVDOverlayCodecText()
-{
-  Dispose();
 }
 
 bool CDVDOverlayCodecText::Open(CDVDStreamInfo& hints, CDVDCodecOptions& options)
@@ -45,20 +40,11 @@ bool CDVDOverlayCodecText::Open(CDVDStreamInfo& hints, CDVDCodecOptions& options
 
   m_codecId = hints.codec;
 
-  Dispose();
+  m_pOverlay.reset();
 
   return Initialize();
 }
 
-void CDVDOverlayCodecText::Dispose()
-{
-  if (m_pOverlay)
-  {
-    m_pOverlay->Release();
-    m_pOverlay = nullptr;
-  }
-}
-
 OverlayMessage CDVDOverlayCodecText::Decode(DemuxPacket* pPacket)
 {
   if (!pPacket)
@@ -126,25 +112,19 @@ void CDVDOverlayCodecText::PostProcess(std::string& text)
 
 void CDVDOverlayCodecText::Reset()
 {
-  Dispose();
   Flush();
 }
 
 void CDVDOverlayCodecText::Flush()
 {
-  if (m_pOverlay)
-  {
-    m_pOverlay->Release();
-    m_pOverlay = nullptr;
-  }
-
+  m_pOverlay.reset();
   FlushSubtitles();
 }
 
-CDVDOverlay* CDVDOverlayCodecText::GetOverlay()
+std::shared_ptr<CDVDOverlay> CDVDOverlayCodecText::GetOverlay()
 {
   if (m_pOverlay)
     return nullptr;
   m_pOverlay = CreateOverlay();
-  return m_pOverlay->Acquire();
+  return m_pOverlay;
 }
