@@ -23,11 +23,14 @@
 #include "cores/VideoPlayer/VideoRenderers/RenderManager.h"
 #include "media/decoderfilter/DecoderFilterManager.h"
 #include "messaging/ApplicationMessenger.h"
+#include "settings/SettingUtils.h"
 #include "settings/Settings.h"
 #include "settings/SettingsComponent.h"
+#include "settings/lib/Setting.h"
 #include "utils/BitstreamConverter.h"
 #include "utils/BitstreamWriter.h"
 #include "utils/CPUInfo.h"
+#include "utils/StringUtils.h"
 #include "utils/TimeUtils.h"
 #include "utils/log.h"
 #include "windowing/android/AndroidUtils.h"
@@ -35,6 +38,7 @@
 #include "platform/android/activity/JNIXBMCSurfaceTextureOnFrameAvailableListener.h"
 #include "platform/android/activity/XBMCApp.h"
 
+#include <array>
 #include <cassert>
 #include <memory>
 #include <mutex>
@@ -68,27 +72,10 @@ enum MEDIACODEC_STATES
   MEDIACODEC_STATE_STOPPED
 };
 
-static bool IsSupportedColorFormat(int color_format)
-{
-  static const int supported_colorformats[] = {
-    CJNIMediaCodecInfoCodecCapabilities::COLOR_FormatYUV420Planar,
-    CJNIMediaCodecInfoCodecCapabilities::COLOR_TI_FormatYUV420PackedSemiPlanar,
-    CJNIMediaCodecInfoCodecCapabilities::COLOR_FormatYUV420SemiPlanar,
-    CJNIMediaCodecInfoCodecCapabilities::COLOR_QCOM_FormatYUV420SemiPlanar,
-    CJNIMediaCodecInfoCodecCapabilities::OMX_QCOM_COLOR_FormatYVU420SemiPlanarInterlace,
-    -1
-  };
-  for (const int *ptr = supported_colorformats; *ptr != -1; ptr++)
-  {
-    if (color_format == *ptr)
-      return true;
-  }
-  return false;
-}
-
 /*****************************************************************************/
 /*****************************************************************************/
-class CDVDMediaCodecOnFrameAvailable : public CEvent, public CJNIXBMCSurfaceTextureOnFrameAvailableListener
+class CDVDMediaCodecOnFrameAvailable : public CEvent,
+                                       public jni::CJNIXBMCSurfaceTextureOnFrameAvailableListener
 {
 public:
   CDVDMediaCodecOnFrameAvailable(std::shared_ptr<CJNISurfaceTexture> &surfaceTexture)
@@ -114,10 +101,11 @@ private:
 
 /*****************************************************************************/
 /*****************************************************************************/
-void CMediaCodecVideoBuffer::Set(int bufferId, int textureId,
-  std::shared_ptr<CJNISurfaceTexture> surfacetexture,
-  std::shared_ptr<CDVDMediaCodecOnFrameAvailable> frameready,
-  std::shared_ptr<CJNIXBMCVideoView> videoview)
+void CMediaCodecVideoBuffer::Set(int bufferId,
+                                 int textureId,
+                                 std::shared_ptr<CJNISurfaceTexture> surfacetexture,
+                                 std::shared_ptr<CDVDMediaCodecOnFrameAvailable> frameready,
+                                 std::shared_ptr<jni::CJNIXBMCVideoView> videoview)
 {
   m_bufferId = bufferId;
   m_textureId = textureId;
@@ -304,20 +292,13 @@ void CMediaCodecVideoBufferPool::ReleaseMediaCodecBuffers()
 
 /*****************************************************************************/
 /*****************************************************************************/
-CDVDVideoCodecAndroidMediaCodec::CDVDVideoCodecAndroidMediaCodec(CProcessInfo &processInfo, bool surface_render)
-: CDVDVideoCodec(processInfo)
-, m_formatname("mediacodec")
-, m_opened(false)
-, m_jnivideoview(nullptr)
-, m_textureId(0)
-, m_OutputDuration(0)
-, m_fpsDuration(0)
-, m_lastPTS(-1)
-, m_dtsShift(DVD_NOPTS_VALUE)
-, m_bitstream(nullptr)
-, m_render_surface(surface_render)
-, m_mpeg2_sequence(nullptr)
-, m_useDTSforPTS(false)
+CDVDVideoCodecAndroidMediaCodec::CDVDVideoCodecAndroidMediaCodec(CProcessInfo& processInfo,
+                                                                 bool surface_render)
+  : CDVDVideoCodec(processInfo),
+    m_formatname("mediacodec"),
+    m_jnivideoview(nullptr),
+    m_bitstream(nullptr),
+    m_render_surface(surface_render)
 {
   m_videobuffer.Reset();
 }
@@ -387,7 +368,7 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
       "CDVDVideoCodecAndroidMediaCodec::Open hints: Width {} x Height {}, Fpsrate {} / Fpsscale "
       "{}, CodecID {}, Level {}, Profile {}, PTS_invalid {}, Tag {}, Extradata-Size: {}",
       hints.width, hints.height, hints.fpsrate, hints.fpsscale, hints.codec, hints.level,
-      hints.profile, hints.ptsinvalid, hints.codec_tag, hints.extrasize);
+      hints.profile, hints.ptsinvalid, hints.codec_tag, hints.extradata.GetSize());
 
   m_render_surface = CServiceBroker::GetSettingsComponent()->GetSettings()->GetBool(CSettings::SETTING_VIDEOPLAYER_USEMEDIACODECSURFACE);
   m_state = MEDIACODEC_STATE_UNINITIALIZED;
@@ -429,7 +410,7 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
       m_formatname = "amc-vp8";
       break;
     case AV_CODEC_ID_VP9:
-      switch(hints.profile)
+      switch (m_hints.profile)
       {
         case FF_PROFILE_VP9_0:
           profile = CJNIMediaCodecInfoCodecProfileLevel::VP9Profile0;
@@ -447,15 +428,25 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
       }
       m_mime = "video/x-vnd.on2.vp9";
       m_formatname = "amc-vp9";
-      free(m_hints.extradata);
-      m_hints.extradata = nullptr;
-      m_hints.extrasize = 0;
+      m_hints.extradata = {};
       break;
     case AV_CODEC_ID_AVS:
     case AV_CODEC_ID_CAVS:
     case AV_CODEC_ID_H264:
-      switch(hints.profile)
+      switch (m_hints.profile)
       {
+        case FF_PROFILE_H264_BASELINE:
+          profile = CJNIMediaCodecInfoCodecProfileLevel::AVCProfileBaseline;
+          break;
+        case FF_PROFILE_H264_MAIN:
+          profile = CJNIMediaCodecInfoCodecProfileLevel::AVCProfileMain;
+          break;
+        case FF_PROFILE_H264_EXTENDED:
+          profile = CJNIMediaCodecInfoCodecProfileLevel::AVCProfileExtended;
+          break;
+        case FF_PROFILE_H264_HIGH:
+          profile = CJNIMediaCodecInfoCodecProfileLevel::AVCProfileHigh;
+          break;
         case FF_PROFILE_H264_HIGH_10:
           profile = CJNIMediaCodecInfoCodecProfileLevel::AVCProfileHigh10;
           break;
@@ -481,7 +472,8 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
       if (m_hints.extradata && !m_hints.cryptoSession)
       {
         m_bitstream = std::make_unique<CBitstreamConverter>();
-        if (!m_bitstream->Open(m_hints.codec, (uint8_t*)m_hints.extradata, m_hints.extrasize, true))
+        if (!m_bitstream->Open(m_hints.codec, m_hints.extradata.GetData(),
+                               m_hints.extradata.GetSize(), true))
         {
           m_bitstream.reset();
         }
@@ -489,33 +481,117 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
       break;
     case AV_CODEC_ID_HEVC:
     {
-      if (m_hints.profile == FF_PROFILE_HEVC_REXT)
+      switch (m_hints.profile)
       {
-        // No known h/w decoder supporting Hi10P
-        goto FAIL;
+        case FF_PROFILE_HEVC_MAIN:
+          profile = CJNIMediaCodecInfoCodecProfileLevel::HEVCProfileMain;
+          break;
+        case FF_PROFILE_HEVC_MAIN_10:
+          profile = CJNIMediaCodecInfoCodecProfileLevel::HEVCProfileMain10;
+          break;
+        case FF_PROFILE_HEVC_MAIN_STILL_PICTURE:
+          profile = CJNIMediaCodecInfoCodecProfileLevel::HEVCProfileMainStill;
+          break;
+        case FF_PROFILE_HEVC_REXT:
+          // No known h/w decoder supporting Hi10P
+          goto FAIL;
+        default:
+          break;
       }
 
       m_mime = "video/hevc";
       m_formatname = "amc-hevc";
 
+      const auto settings = CServiceBroker::GetSettingsComponent()->GetSettings();
+      bool convertDovi{false};
+      bool removeDovi{false};
+      bool removeHdr10Plus{false};
+
+      if (settings)
+      {
+        convertDovi = settings->GetBool(CSettings::SETTING_VIDEOPLAYER_CONVERTDOVI);
+
+        const std::shared_ptr<CSettingList> allowedHdrFormatsSetting(
+            std::dynamic_pointer_cast<CSettingList>(
+                settings->GetSetting(CSettings::SETTING_VIDEOPLAYER_ALLOWEDHDRFORMATS)));
+        removeDovi = !CSettingUtils::FindIntInList(
+            allowedHdrFormatsSetting, CSettings::VIDEOPLAYER_ALLOWED_HDR_TYPE_DOLBY_VISION);
+        removeHdr10Plus = !CSettingUtils::FindIntInList(
+            allowedHdrFormatsSetting, CSettings::VIDEOPLAYER_ALLOWED_HDR_TYPE_HDR10PLUS);
+      }
+
       bool isDvhe = (m_hints.codec_tag == MKTAG('d', 'v', 'h', 'e'));
       bool isDvh1 = (m_hints.codec_tag == MKTAG('d', 'v', 'h', '1'));
 
-      if (isDvhe || isDvh1)
+      // some files don't have dvhe or dvh1 tag set up but have Dolby Vision side data
+      if (!isDvhe && !isDvh1 && m_hints.hdrType == StreamHdrType::HDR_TYPE_DOLBYVISION)
       {
-        bool displaySupportsDovi = CAndroidUtils::GetDisplayHDRCapabilities().SupportsDolbyVision();
-        bool mediaCodecSupportsDovi =
-            CAndroidUtils::SupportsMediaCodecMimeType("video/dolby-vision");
+        // page 10, table 2 from https://professional.dolby.com/siteassets/content-creation/dolby-vision-for-content-creators/dolby-vision-streams-within-the-http-live-streaming-format-v2.0-13-november-2018.pdf
+        if (m_hints.codec_tag == MKTAG('h', 'v', 'c', '1'))
+          isDvh1 = true;
+        else
+          isDvhe = true;
+      }
 
-        CLog::Log(LOGDEBUG,
-                  "CDVDVideoCodecAndroidMediaCodec::Open Dolby Vision playback support: "
-                  "Display: {}, MediaCodec: {}",
-                  displaySupportsDovi, mediaCodecSupportsDovi);
+      if (!removeDovi && (isDvhe || isDvh1))
+      {
+        bool displaySupportsDovi{false};
+        bool mediaCodecSupportsDovi{false};
+        std::tie(displaySupportsDovi, mediaCodecSupportsDovi) =
+            CAndroidUtils::GetDolbyVisionCapabilities();
 
-        if (displaySupportsDovi && mediaCodecSupportsDovi)
+        // For Dolby Vision profiles that don't have HDR10 fallback, always use
+        // the dvhe decoder even if the display not supports Dolby Vision.
+        // For profiles that has HDR10 fallback (7, 8) is better use HEVC decoder to
+        // ensure HDR10 output if display is not DV capable.
+        const bool notHasHDR10fallback =
+            (m_hints.dovi.dv_profile == 4 || m_hints.dovi.dv_profile == 5);
+
+        if (mediaCodecSupportsDovi && (displaySupportsDovi || notHasHDR10fallback))
         {
           m_mime = "video/dolby-vision";
           m_formatname = isDvhe ? "amc-dvhe" : "amc-dvh1";
+          profile = 0; // not an HEVC profile
+
+          if (CJNIBase::GetSDKVersion() >= 24)
+          {
+            switch (m_hints.dovi.dv_profile)
+            {
+              case 0:
+              case 1:
+              case 2:
+              case 3:
+              case 6:
+                // obsolete profiles that are not supported in current applications.
+                // 0 is ignored in case the AVDOVIDecoderConfigurationRecord hint is unset.
+                break;
+              case 4:
+                profile = CJNIMediaCodecInfoCodecProfileLevel::DolbyVisionProfileDvheDtr;
+                break;
+              case 5:
+                profile = CJNIMediaCodecInfoCodecProfileLevel::DolbyVisionProfileDvheStn;
+                break;
+              case 7:
+                // set profile 8 when converting
+                if (convertDovi && CJNIBase::GetSDKVersion() >= 27)
+                  profile = CJNIMediaCodecInfoCodecProfileLevel::DolbyVisionProfileDvheSt;
+
+                // Profile 7 is not commonly supported. Not setting the profile here
+                // allows to pick the first available Dolby Vision codec.
+                // profile = CJNIMediaCodecInfoCodecProfileLevel::DolbyVisionProfileDvheDtb;
+                break;
+              case 8:
+                if (CJNIBase::GetSDKVersion() >= 27)
+                  profile = CJNIMediaCodecInfoCodecProfileLevel::DolbyVisionProfileDvheSt;
+                break;
+              case 9:
+                if (CJNIBase::GetSDKVersion() >= 27)
+                  profile = CJNIMediaCodecInfoCodecProfileLevel::DolbyVisionProfileDvavSe;
+                break;
+              default:
+                break;
+            }
+          }
         }
       }
 
@@ -523,36 +599,53 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
       if (m_hints.extradata && !m_hints.cryptoSession)
       {
         m_bitstream = std::make_unique<CBitstreamConverter>();
-        if (!m_bitstream->Open(m_hints.codec, (uint8_t*)m_hints.extradata, m_hints.extrasize, true))
+        if (!m_bitstream->Open(m_hints.codec, m_hints.extradata.GetData(),
+                               m_hints.extradata.GetSize(), true))
         {
           m_bitstream.reset();
         }
+
+        if (m_bitstream)
+        {
+          m_bitstream->SetRemoveDovi(removeDovi);
+          m_bitstream->SetRemoveHdr10Plus(removeHdr10Plus);
+
+          // Only set for profile 7, container hint allows to skip parsing unnecessarily
+          if (m_hints.dovi.dv_profile == 7)
+          {
+            CLog::Log(LOGDEBUG,
+                      "CDVDVideoCodecAndroidMediaCodec::Open Dolby Vision compatibility mode "
+                      "enabled: {}",
+                      convertDovi);
+
+            m_bitstream->SetConvertDovi(convertDovi);
+          }
+        }
       }
+
       break;
     }
     case AV_CODEC_ID_WMV3:
-      if (m_hints.extrasize == 4 || m_hints.extrasize == 5)
+      if (m_hints.extradata.GetSize() == 4 || m_hints.extradata.GetSize() == 5)
       {
         // Convert to SMPTE 421M-2006 Annex-L
         static uint8_t annexL_hdr1[] = {0x8e, 0x01, 0x00, 0xc5, 0x04, 0x00, 0x00, 0x00};
         static uint8_t annexL_hdr2[] = {0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
-        free(m_hints.extradata);
-        m_hints.extrasize = 36;
-        m_hints.extradata = malloc(m_hints.extrasize);
+        m_hints.extradata = FFmpegExtraData(36);
 
         unsigned int offset = 0;
         char buf[4];
-        memcpy(m_hints.extradata, annexL_hdr1, sizeof(annexL_hdr1));
+        memcpy(m_hints.extradata.GetData(), annexL_hdr1, sizeof(annexL_hdr1));
         offset += sizeof(annexL_hdr1);
-        memcpy(&((char *)(m_hints.extradata))[offset], hints.extradata, 4);
+        memcpy(m_hints.extradata.GetData() + offset, hints.extradata.GetData(), 4);
         offset += 4;
         BS_WL32(buf, hints.height);
-        memcpy(&((char *)(m_hints.extradata))[offset], buf, 4);
+        memcpy(m_hints.extradata.GetData() + offset, buf, 4);
         offset += 4;
         BS_WL32(buf, hints.width);
-        memcpy(&((char *)(m_hints.extradata))[offset], buf, 4);
+        memcpy(m_hints.extradata.GetData() + offset, buf, 4);
         offset += 4;
-        memcpy(&((char *)(m_hints.extradata))[offset], annexL_hdr2, sizeof(annexL_hdr2));
+        memcpy(m_hints.extradata.GetData() + offset, annexL_hdr2, sizeof(annexL_hdr2));
       }
 
       m_mime = "video/x-ms-wmv";
@@ -560,26 +653,24 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
       break;
     case AV_CODEC_ID_VC1:
     {
-      if (m_hints.extrasize < 16)
+      if (m_hints.extradata.GetSize() < 16)
         goto FAIL;
 
       // Reduce extradata to first SEQ header
       unsigned int seq_offset = 0;
-      for (; seq_offset <= m_hints.extrasize-4; ++seq_offset)
+      for (; seq_offset <= m_hints.extradata.GetSize() - 4; ++seq_offset)
       {
-        char *ptr = &((char*)m_hints.extradata)[seq_offset];
+        const uint8_t* ptr = m_hints.extradata.GetData() + seq_offset;
         if (ptr[0] == 0x00 && ptr[1] == 0x00 && ptr[2] == 0x01 && ptr[3] == 0x0f)
           break;
       }
-      if (seq_offset > m_hints.extrasize-4)
+      if (seq_offset > m_hints.extradata.GetSize() - 4)
         goto FAIL;
 
       if (seq_offset)
       {
-        free(m_hints.extradata);
-        m_hints.extrasize -= seq_offset;
-        m_hints.extradata = malloc(m_hints.extrasize);
-        memcpy(m_hints.extradata, &((char *)(hints.extradata))[seq_offset], m_hints.extrasize);
+        hints.extradata = FFmpegExtraData(hints.extradata.GetData() + seq_offset,
+                                          hints.extradata.GetSize() - seq_offset);
       }
 
       m_mime = "video/wvc1";
@@ -588,7 +679,7 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
     }
     case AV_CODEC_ID_AV1:
     {
-      switch (hints.profile)
+      switch (m_hints.profile)
       {
         case FF_PROFILE_AV1_MAIN:
           profile = CJNIMediaCodecInfoCodecProfileLevel::AV1ProfileMain8;
@@ -602,9 +693,29 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
       }
       m_mime = "video/av01";
       m_formatname = "amc-av1";
-      free(m_hints.extradata);
-      m_hints.extradata = nullptr;
-      m_hints.extrasize = 0;
+
+      if (m_hints.hdrType == StreamHdrType::HDR_TYPE_DOLBYVISION && m_hints.dovi.dv_profile == 10)
+      {
+        bool displaySupportsDovi{false};
+        bool mediaCodecSupportsDovi{false};
+        std::tie(displaySupportsDovi, mediaCodecSupportsDovi) =
+            CAndroidUtils::GetDolbyVisionCapabilities();
+
+        const bool notHasHDRfallback = (m_hints.dovi.dv_bl_signal_compatibility_id == 0 ||
+                                        m_hints.dovi.dv_bl_signal_compatibility_id == 2 ||
+                                        m_hints.dovi.dv_bl_signal_compatibility_id == 3);
+
+        if (mediaCodecSupportsDovi && (displaySupportsDovi || notHasHDRfallback))
+        {
+          m_mime = "video/dolby-vision";
+          m_formatname = "amc-dav1";
+          profile = CJNIBase::GetSDKVersion() >= 30
+                        ? CJNIMediaCodecInfoCodecProfileLevel::DolbyVisionProfileDvav110
+                        : 1024;
+        }
+      }
+
+      m_hints.extradata = {};
       break;
     }
     default:
@@ -628,6 +739,8 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
       uuid = CJNIUUID(0x9A04F07998404286LL, 0xAB92E65BE0885F95LL);
     else if (m_hints.cryptoSession->keySystem == CRYPTO_SESSION_SYSTEM_WISEPLAY)
       uuid = CJNIUUID(0X3D5E6D359B9A41E8LL, 0XB843DD3C6E72C42CLL);
+    else if (m_hints.cryptoSession->keySystem == CRYPTO_SESSION_SYSTEM_CLEARKEY)
+      uuid = CJNIUUID(0XE2719D58A985B3C9LL, 0X781AB030AF78D30ELL);
     else
     {
       CLog::Log(LOGERROR, "CDVDVideoCodecAndroidMediaCodec::Open Unsupported crypto-keysystem {}",
@@ -642,12 +755,11 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
 
     CLog::Log(
         LOGINFO,
-        "CDVDVideoCodecAndroidMediaCodec::Open: Secure decoder requested: {} (stream flags: {})",
+        "CDVDVideoCodecAndroidMediaCodec::Open Secure decoder requested: {} (stream flags: {})",
         m_needSecureDecoder ? "true" : "false", m_hints.cryptoSession->flags);
   }
 
   m_codec = nullptr;
-  m_colorFormat = -1;
   codecInfos = CJNIMediaCodecList(CJNIMediaCodecList::REGULAR_CODECS).getCodecInfos();
 
   for (const CJNIMediaCodecInfo& codec_info : codecInfos)
@@ -659,7 +771,7 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
     if (!CServiceBroker::GetDecoderFilterManager()->isValid(m_codecname, m_hints))
       continue;
 
-    CLog::Log(LOGINFO, "CDVDVideoCodecAndroidMediaCodec::Open Testing codec:{}", m_codecname);
+    CLog::Log(LOGINFO, "CDVDVideoCodecAndroidMediaCodec::Open Testing codec: {}", m_codecname);
 
     CJNIMediaCodecInfoCodecCapabilities codec_caps = codec_info.getCapabilitiesForType(m_mime);
     if (xbmc_jnienv()->ExceptionCheck())
@@ -667,7 +779,40 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
       // Unsupported type?
       xbmc_jnienv()->ExceptionDescribe();
       xbmc_jnienv()->ExceptionClear();
-      continue;
+
+      if (m_mime == "video/wvc1")
+      {
+        // There is some confusion for video/VC1 vs. video/wvc1 especially on Sony devices, while
+        // IANA defines VC-1 as video/vc1, Android API defines it as video/wvc1 - be nice and test it
+        const bool isVC1 = StringUtils::Contains(m_codecname, "vc1", true);
+        if (!isVC1)
+          continue;
+
+        const std::array<const std::string, 2> mimes = {"video/VC1", "video/vc1"};
+        bool success = false;
+        for (const auto& v : mimes)
+        {
+          codec_caps = codec_info.getCapabilitiesForType(v);
+          if (xbmc_jnienv()->ExceptionCheck())
+          {
+            xbmc_jnienv()->ExceptionDescribe();
+            xbmc_jnienv()->ExceptionClear();
+          }
+          else
+          {
+            m_mime = v;
+            CLog::Log(LOGDEBUG, "Succesfully replaced VC1 mime type to {}", m_mime);
+            success = true;
+            break;
+          }
+        }
+        if (!success)
+          continue;
+      }
+      else
+      {
+        continue;
+      }
     }
 
     bool codecIsSecure(
@@ -680,13 +825,11 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
     }
     else if (codecIsSecure)
     {
-      CLog::Log(LOGINFO, "CDVDVideoCodecAndroidMediaCodec::Open: skipping insecure decoder while "
+      CLog::Log(LOGINFO, "CDVDVideoCodecAndroidMediaCodec::Open skipping insecure decoder while "
                          "secure decoding is required");
       continue;
     }
 
-    std::vector<int> color_formats = codec_caps.colorFormats();
-
     if (profile)
     {
       std::vector<CJNIMediaCodecInfoCodecProfileLevel> profileLevels = codec_caps.profileLevels();
@@ -695,7 +838,7 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
                          return profileLevel.profile() == profile;
                        }) == profileLevels.cend())
       {
-        CLog::Log(LOGERROR, "CDVDVideoCodecAndroidMediaCodec::Open: profile not supported: {}",
+        CLog::Log(LOGERROR, "CDVDVideoCodecAndroidMediaCodec::Open profile not supported: {}",
                   profile);
         continue;
       }
@@ -720,16 +863,6 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
           CLog::Log(LOGERROR, "CDVDVideoCodecAndroidMediaCodec::Open cannot create codec");
           continue;
         }
-
-        for (size_t k = 0; k < color_formats.size(); ++k)
-        {
-          CLog::Log(LOGDEBUG,
-                    "CDVDVideoCodecAndroidMediaCodec::Open "
-                    "m_codecname({}), colorFormat({})",
-                    m_codecname, color_formats[k]);
-          if (IsSupportedColorFormat(color_formats[k]))
-            m_colorFormat = color_formats[k]; // Save color format for initial output configuration
-        }
         break;
       }
     }
@@ -738,7 +871,8 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
   }
   if (!m_codec)
   {
-    CLog::Log(LOGERROR, "CDVDVideoCodecAndroidMediaCodec:: Failed to create Android MediaCodec");
+    CLog::Log(LOGERROR,
+              "CDVDVideoCodecAndroidMediaCodec::Open Failed to create Android MediaCodec");
     goto FAIL;
   }
 
@@ -752,17 +886,17 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
 
     if (!m_crypto)
     {
-      CLog::Log(LOGERROR, "CDVDVideoCodecAndroidMediaCodec::Open: MediaCrypto creation failed");
+      CLog::Log(LOGERROR, "CDVDVideoCodecAndroidMediaCodec::Open MediaCrypto creation failed");
       goto FAIL;
     }
   }
 
   if (m_render_surface)
   {
-    m_jnivideoview.reset(CJNIXBMCVideoView::createVideoView(this));
+    m_jnivideoview.reset(jni::CJNIXBMCVideoView::createVideoView(this));
     if (!m_jnivideoview || !m_jnivideoview->waitForSurface(2000))
     {
-      CLog::Log(LOGERROR, "CDVDVideoCodecAndroidMediaCodec: VideoView creation failed!!");
+      CLog::Log(LOGERROR, "CDVDVideoCodecAndroidMediaCodec::Open VideoView creation failed!!");
       goto FAIL;
     }
   }
@@ -787,10 +921,7 @@ bool CDVDVideoCodecAndroidMediaCodec::Open(CDVDStreamInfo &hints, CDVDCodecOptio
   else
     m_invalidPTSValue = 0;
 
-  CLog::Log(LOGINFO,
-            "CDVDVideoCodecAndroidMediaCodec:: "
-            "Open Android MediaCodec {}",
-            m_codecname);
+  CLog::Log(LOGINFO, "CDVDVideoCodecAndroidMediaCodec::Open Using codec: {}", m_codecname);
 
   m_opened = true;
 
@@ -1275,12 +1406,12 @@ void CDVDVideoCodecAndroidMediaCodec::SignalEndOfStream()
 
 void CDVDVideoCodecAndroidMediaCodec::InjectExtraData(CJNIMediaFormat& mediaformat)
 {
-  if (!m_hints.extrasize)
+  if (!m_hints.extradata)
     return;
 
   CLog::Log(LOGDEBUG, "CDVDVideoCodecAndroidMediaCodec::{}", __func__);
-  size_t size = m_hints.extrasize;
-  void* src_ptr = m_hints.extradata;
+  size_t size = m_hints.extradata.GetSize();
+  void* src_ptr = m_hints.extradata.GetData();
   if (m_bitstream)
   {
     size = m_bitstream->GetExtraSize();
@@ -1358,48 +1489,79 @@ bool CDVDVideoCodecAndroidMediaCodec::ConfigureMediaCodec(void)
 
   if (CJNIBase::GetSDKVersion() >= 24)
   {
-    if (m_hints.colorRange != AVCOL_RANGE_UNSPECIFIED)
-      mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_RANGE, m_hints.colorRange);
-
-    if (m_hints.colorPrimaries != AVCOL_PRI_UNSPECIFIED)
+    switch (m_hints.colorRange)
     {
-      switch (m_hints.colorPrimaries)
-      {
-        case AVCOL_PRI_BT709:
-          mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_STANDARD,
-                                 CJNIMediaFormat::COLOR_STANDARD_BT709);
-          break;
-        case AVCOL_PRI_BT2020:
-          mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_STANDARD,
-                                 CJNIMediaFormat::COLOR_STANDARD_BT2020);
-          break;
-        default:; // do nothing
-      }
+      case AVCOL_RANGE_UNSPECIFIED:
+        CLog::Log(LOGDEBUG, "CDVDVideoCodecAndroidMediaCodec::ConfigureMediaCodec Color range: "
+                            "AVCOL_RANGE_UNSPECIFIED");
+        break;
+      case AVCOL_RANGE_MPEG:
+        mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_RANGE,
+                               CJNIMediaFormat::COLOR_RANGE_LIMITED);
+        break;
+      case AVCOL_RANGE_JPEG:
+        mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_RANGE, CJNIMediaFormat::COLOR_RANGE_FULL);
+        break;
+      default:
+        CLog::Log(LOGWARNING,
+                  "CDVDVideoCodecAndroidMediaCodec::ConfigureMediaCodec Unhandled Color range: {}",
+                  m_hints.colorRange);
+        break;
     }
 
-    if (m_hints.colorTransferCharacteristic != AVCOL_TRC_UNSPECIFIED)
+    switch (m_hints.colorPrimaries)
     {
-      switch (m_hints.colorTransferCharacteristic)
-      {
-        case AVCOL_TRC_LINEAR:
-          mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_TRANSFER,
-                                 CJNIMediaFormat::COLOR_TRANSFER_LINEAR);
-          break;
-        case AVCOL_TRC_SMPTE170M:
-          mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_TRANSFER,
-                                 CJNIMediaFormat::COLOR_TRANSFER_SDR_VIDEO);
-          break;
-        case AVCOL_TRC_SMPTE2084:
-          mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_TRANSFER,
-                                 CJNIMediaFormat::COLOR_TRANSFER_ST2084);
-          break;
-        case AVCOL_TRC_ARIB_STD_B67:
-          mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_TRANSFER,
-                                 CJNIMediaFormat::COLOR_TRANSFER_HLG);
-          break;
-        default:; // do nothing
-      }
+      case AVCOL_PRI_UNSPECIFIED:
+        CLog::Log(LOGDEBUG, "CDVDVideoCodecAndroidMediaCodec::ConfigureMediaCodec Color primaries: "
+                            "AVCOL_PRI_UNSPECIFIED");
+        break;
+      case AVCOL_PRI_BT709:
+        mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_STANDARD,
+                               CJNIMediaFormat::COLOR_STANDARD_BT709);
+        break;
+      case AVCOL_PRI_BT2020:
+        mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_STANDARD,
+                               CJNIMediaFormat::COLOR_STANDARD_BT2020);
+        break;
+      default:
+        CLog::Log(
+            LOGWARNING,
+            "CDVDVideoCodecAndroidMediaCodec::ConfigureMediaCodec Unhandled Color primaries: {}",
+            m_hints.colorPrimaries);
+        break;
     }
+
+    switch (m_hints.colorTransferCharacteristic)
+    {
+      case AVCOL_TRC_UNSPECIFIED:
+        CLog::Log(LOGDEBUG, "CDVDVideoCodecAndroidMediaCodec::ConfigureMediaCodec Transfer "
+                            "characteristic: AVCOL_TRC_UNSPECIFIED");
+        break;
+      case AVCOL_TRC_LINEAR:
+        mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_TRANSFER,
+                               CJNIMediaFormat::COLOR_TRANSFER_LINEAR);
+        break;
+      case AVCOL_TRC_BT709:
+      case AVCOL_TRC_SMPTE170M:
+        mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_TRANSFER,
+                               CJNIMediaFormat::COLOR_TRANSFER_SDR_VIDEO);
+        break;
+      case AVCOL_TRC_SMPTE2084:
+        mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_TRANSFER,
+                               CJNIMediaFormat::COLOR_TRANSFER_ST2084);
+        break;
+      case AVCOL_TRC_ARIB_STD_B67:
+        mediaformat.setInteger(CJNIMediaFormat::KEY_COLOR_TRANSFER,
+                               CJNIMediaFormat::COLOR_TRANSFER_HLG);
+        break;
+      default:
+        CLog::Log(LOGWARNING,
+                  "CDVDVideoCodecAndroidMediaCodec::ConfigureMediaCodec Unhandled Transfer "
+                  "characteristic: {}",
+                  m_hints.colorTransferCharacteristic);
+        break;
+    }
+
     std::vector<uint8_t> hdr_static_data = GetHDRStaticMetadata();
     if (!hdr_static_data.empty())
     {
@@ -1606,19 +1768,22 @@ void CDVDVideoCodecAndroidMediaCodec::ConfigureOutputFormat(CJNIMediaFormat& med
   if (xbmc_jnienv()->ExceptionCheck())
     xbmc_jnienv()->ExceptionClear();
 
-  CLog::Log(LOGDEBUG,
-            "CDVDVideoCodecAndroidMediaCodec:: "
-            "width({}), height({}), stride({}), slice-height({}), color-format({})",
-            width, height, stride, slice_height, color_format);
-  CLog::Log(LOGDEBUG,
-            "CDVDVideoCodecAndroidMediaCodec:: "
-            "crop-left({}), crop-top({}), crop-right({}), crop-bottom({})",
-            crop_left, crop_top, crop_right, crop_bottom);
+  if (CServiceBroker::GetLogging().CanLogComponent(LOGVIDEO))
+  {
+    CLog::Log(LOGDEBUG,
+              "CDVDVideoCodecAndroidMediaCodec:: "
+              "width({}), height({}), stride({}), slice-height({}), color-format({})",
+              width, height, stride, slice_height, color_format);
+    CLog::Log(LOGDEBUG,
+              "CDVDVideoCodecAndroidMediaCodec:: "
+              "crop-left({}), crop-top({}), crop-right({}), crop-bottom({})",
+              crop_left, crop_top, crop_right, crop_bottom);
 
-  if (m_render_surface)
-    CLog::Log(LOGDEBUG, "CDVDVideoCodecAndroidMediaCodec:: Multi-Surface Rendering");
-  else
-    CLog::Log(LOGDEBUG, "CDVDVideoCodecAndroidMediaCodec:: Direct Surface Rendering");
+    if (m_render_surface)
+      CLog::Log(LOGDEBUG, "CDVDVideoCodecAndroidMediaCodec:: Multi-Surface Rendering");
+    else
+      CLog::Log(LOGDEBUG, "CDVDVideoCodecAndroidMediaCodec:: Direct Surface Rendering");
+  }
 
   if (crop_right)
     width = crop_right  + 1 - crop_left;
@@ -1637,6 +1802,11 @@ void CDVDVideoCodecAndroidMediaCodec::ConfigureOutputFormat(CJNIMediaFormat& med
       m_videobuffer.iDisplayHeight = ((int)lrint(m_videobuffer.iWidth / m_hints.aspect)) & ~3;
     }
   }
+
+  m_videobuffer.hdrType = m_hints.hdrType;
+  m_videobuffer.color_space = m_hints.colorSpace;
+  m_videobuffer.color_primaries = m_hints.colorPrimaries;
+  m_videobuffer.color_transfer = m_hints.colorTransferCharacteristic;
 }
 
 void CDVDVideoCodecAndroidMediaCodec::CallbackInitSurfaceTexture(void *userdata)
