@@ -119,10 +119,11 @@ struct webvttCssStyle
   webvttCssStyle(WebvttSelector selectorType,
                  const std::string& selectorName,
                  const std::string& colorHexRGB)
-    : m_selectorType{selectorType}, m_selectorName{selectorName}
+    : m_selectorType{selectorType},
+      m_selectorName{selectorName},
+      // Color hex values need to be in BGR format
+      m_color(colorHexRGB.substr(4, 2) + colorHexRGB.substr(2, 2) + colorHexRGB.substr(0, 2))
   {
-    // Color hex values need to be in BGR format
-    m_color = colorHexRGB.substr(4, 2) + colorHexRGB.substr(2, 2) + colorHexRGB.substr(0, 2);
   }
 
   WebvttSelector m_selectorType = WebvttSelector::ANY;
@@ -192,7 +193,7 @@ private:
   void GetCueData(std::string& cueText);
   std::string GetCueSettingValue(const std::string& propName,
                                  std::string& text,
-                                 std::string defaultValue);
+                                 const std::string& defaultValue);
   std::string GetCueCssValue(const std::string& cssPropName, std::string& line);
   void AddDefaultCssClasses();
   void InsertCssStyleStartTag(const tagToken& tag,
