@@ -61,7 +61,8 @@ CVideoPlayerAudio::CVideoPlayerAudio(CDVDClock* pClock, CDVDMessageQueue& parent
   m_prevskipped = false;
   m_maxspeedadjust = 0.0;
 
-  m_messageQueue.SetMaxDataSize(6 * 1024 * 1024);
+  // 18 MB allows max bitrate of 18 Mbit/s (TrueHD max peak) during 8 seconds
+  m_messageQueue.SetMaxDataSize(18 * 1024 * 1024);
   m_messageQueue.SetMaxTimeSize(8.0);
   m_disconAdjustTimeMs = processInfo.GetMaxPassthroughOffSyncDuration();
 }
@@ -229,24 +230,13 @@ void CVideoPlayerAudio::Process()
   m_audioStats.Start();
   m_disconAdjustCounter = 0;
 
-  // Only enable "learning" if advancedsettings m_maxPassthroughOffSyncDuration
-  // not exists or has it's default 10 ms value, otherwise use advancedsettings value
-  if (m_disconAdjustTimeMs == 10)
-  {
-    m_disconTimer.Set(30s);
-    m_disconLearning = true;
-  }
-  else
-  {
-    m_disconLearning = false;
-  }
-
   bool onlyPrioMsgs = false;
 
   while (!m_bStop)
   {
     std::shared_ptr<CDVDMsg> pMsg;
-    int timeout = (int)(1000 * m_audioSink.GetCacheTime());
+    auto timeout = std::chrono::duration_cast<std::chrono::milliseconds>(
+        std::chrono::duration<double, std::ratio<1>>(m_audioSink.GetCacheTime()));
 
     // read next packet and return -1 on error
     int priority = 1;
@@ -266,7 +256,7 @@ void CVideoPlayerAudio::Process()
     if (onlyPrioMsgs)
     {
       priority = 1;
-      timeout = 0;
+      timeout = 0ms;
     }
 
     MsgQueueReturnCode ret = m_messageQueue.Get(pMsg, timeout, priority);
@@ -302,7 +292,7 @@ void CVideoPlayerAudio::Process()
           m_stalled = true;
         }
       }
-      if (timeout == 0)
+      if (timeout == 0ms)
         CThread::Sleep(10ms);
 
       continue;
@@ -547,23 +537,7 @@ bool CVideoPlayerAudio::ProcessDecoderOutput(DVDAudioFrame &audioframe)
   {
     double syncerror = m_audioSink.GetSyncError();
 
-    if (m_disconLearning)
-    {
-      const double syncErr = std::abs(syncerror);
-      if (syncErr > DVD_MSEC_TO_TIME(m_disconAdjustTimeMs))
-        m_disconAdjustTimeMs = DVD_TIME_TO_MSEC(syncErr);
-      if (m_disconTimer.IsTimePast())
-      {
-        m_disconLearning = false;
-        m_disconAdjustTimeMs = (static_cast<double>(m_disconAdjustTimeMs) * 1.15) + 5.0;
-        if (m_disconAdjustTimeMs > 100) // sanity check
-          m_disconAdjustTimeMs = 100;
-
-        CLog::LogF(LOGINFO, "Changed max allowed Out-Of-Sync value to {} ms due self-learning",
-                   m_disconAdjustTimeMs);
-      }
-    }
-    else if (std::abs(syncerror) > DVD_MSEC_TO_TIME(m_disconAdjustTimeMs))
+    if (std::abs(syncerror) > DVD_MSEC_TO_TIME(m_disconAdjustTimeMs))
     {
       double correction = m_pClock->ErrorAdjust(syncerror, "CVideoPlayerAudio::OutputPacket");
       if (correction != 0)
