@@ -29,6 +29,7 @@
 #include "utils/log.h"
 #include "video/Bookmark.h"
 
+#include <memory>
 #include <mutex>
 
 using namespace std::chrono_literals;
@@ -41,20 +42,8 @@ using namespace std::chrono_literals;
 // Supporting all open  audio codec standards.
 // First one being nullsoft's nsv audio decoder format
 
-PAPlayer::PAPlayer(IPlayerCallback& callback) :
-  IPlayer(callback),
-  CThread("PAPlayer"),
-  m_signalSpeedChange(false),
-  m_playbackSpeed(1    ),
-  m_isPlaying(false),
-  m_isPaused(false),
-  m_isFinished(false),
-  m_defaultCrossfadeMS (0),
-  m_upcomingCrossfadeMS(0),
-  m_audioCallback(NULL ),
-  m_jobCounter(0),
-  m_newForcedPlayerTime(-1),
-  m_newForcedTotalTime (-1)
+PAPlayer::PAPlayer(IPlayerCallback& callback)
+  : IPlayer(callback), CThread("PAPlayer"), m_playbackSpeed(1), m_audioCallback(NULL)
 {
   memset(&m_playerGUIData, 0, sizeof(m_playerGUIData));
   m_processInfo.reset(CProcessInfo::CreateInstance());
@@ -308,7 +297,7 @@ bool PAPlayer::QueueNextFileEx(const CFileItem &file, bool fadeIn)
         file.GetStartOffset() == m_currentStream->m_fileItem->GetEndOffset() && m_currentStream &&
         m_currentStream->m_prepareTriggered)
     {
-      m_currentStream->m_nextFileItem.reset(new CFileItem(file));
+      m_currentStream->m_nextFileItem = std::make_unique<CFileItem>(file);
       m_upcomingCrossfadeMS = 0;
       return true;
     }
@@ -554,7 +543,7 @@ bool PAPlayer::CloseFile(bool reopen)
       lock.lock();
     }
   }
-
+  CServiceBroker::GetDataCacheCore().Reset();
   return true;
 }
 
@@ -858,17 +847,8 @@ inline bool PAPlayer::ProcessStream(StreamInfo *si, double &freeBufferTime)
         free_space = (double)(si->m_stream->GetSpace() / si->m_bytesPerSample) / si->m_audioFormat.m_sampleRate;
       else
       {
-        if (si->m_audioFormat.m_streamInfo.m_type == CAEStreamInfo::STREAM_TYPE_TRUEHD &&
-            !m_processInfo->WantsRawPassthrough())
-        {
-          free_space = static_cast<double>(si->m_stream->GetSpace()) *
-                       si->m_audioFormat.m_streamInfo.GetDuration() / 1000 / 2;
-        }
-        else
-        {
-          free_space = static_cast<double>(si->m_stream->GetSpace()) *
-                       si->m_audioFormat.m_streamInfo.GetDuration() / 1000;
-        }
+        free_space = static_cast<double>(si->m_stream->GetSpace()) *
+                     si->m_audioFormat.m_streamInfo.GetDuration() / 1000;
       }
 
       freeBufferTime = std::max(freeBufferTime , free_space);
@@ -917,17 +897,9 @@ bool PAPlayer::QueueData(StreamInfo *si)
         CLog::Log(LOGERROR, "PAPlayer::QueueData - unknown error");
         return false;
       }
-      if (si->m_audioFormat.m_streamInfo.m_type == CAEStreamInfo::STREAM_TYPE_TRUEHD &&
-          !m_processInfo->WantsRawPassthrough())
-      {
-        si->m_framesSent += si->m_audioFormat.m_streamInfo.GetDuration() / 1000 / 2 *
-                            si->m_audioFormat.m_streamInfo.m_sampleRate;
-      }
-      else
-      {
-        si->m_framesSent += si->m_audioFormat.m_streamInfo.GetDuration() / 1000 *
-                            si->m_audioFormat.m_streamInfo.m_sampleRate;
-      }
+
+      si->m_framesSent += si->m_audioFormat.m_streamInfo.GetDuration() / 1000 *
+                          si->m_audioFormat.m_streamInfo.m_sampleRate;
     }
   }
 
