@@ -58,7 +58,6 @@ enum CONTEXT_BUTTON
   CONTEXT_BUTTON_CDDB,
   CONTEXT_BUTTON_SCAN,
   CONTEXT_BUTTON_SCAN_TO_LIBRARY,
-  CONTEXT_BUTTON_SET_ARTIST_THUMB,
   CONTEXT_BUTTON_SET_ART,
   CONTEXT_BUTTON_CANCEL_PARTYMODE,
   CONTEXT_BUTTON_MARK_WATCHED,
@@ -70,7 +69,6 @@ enum CONTEXT_BUTTON
   CONTEXT_BUTTON_GO_TO_ARTIST,
   CONTEXT_BUTTON_GO_TO_ALBUM,
   CONTEXT_BUTTON_PLAY_OTHER,
-  CONTEXT_BUTTON_SET_ACTOR_THUMB,
   CONTEXT_BUTTON_UNLINK_BOOKMARK,
   CONTEXT_BUTTON_ACTIVATE,
   CONTEXT_BUTTON_GROUP_MANAGER,
