@@ -10,6 +10,8 @@
 
 #include <memory>
 
+class CExecString;
+class CFavouritesURL;
 class CFileItem;
 class CFileItemList;
 
@@ -21,4 +23,7 @@ bool MoveItem(CFileItemList& items, const std::shared_ptr<CFileItem>& item, int
 bool RemoveItem(CFileItemList& items, const std::shared_ptr<CFileItem>& item);
 bool ShouldEnableMoveItems();
 
+bool ExecuteAction(const CExecString& execString);
+bool ExecuteAction(const CFavouritesURL& favURL);
+
 } // namespace FAVOURITES_UTILS
