@@ -12,7 +12,11 @@
 
 class CFileItem;
 class CFileItemList;
-class TiXmlElement;
+
+namespace tinyxml2
+{
+class XMLElement;
+}
 
 namespace XFILE
 {
@@ -28,6 +32,6 @@ namespace XFILE
       DIR_CACHE_TYPE GetCacheType(const CURL& url) const override { return DIR_CACHE_ONCE; }
 
     private:
-      void ParseResponse(const TiXmlElement *pElement, CFileItem &item);
+      void ParseResponse(const tinyxml2::XMLElement* element, CFileItem& item);
   };
 }
