@@ -56,6 +56,7 @@ constexpr auto IDLE_TIMEOUT = 30s; // close fast unused contexts when no active
 constexpr int NFS4ERR_EXPIRED = -11; // client session expired due idle time greater than lease_time
 
 constexpr auto SETTING_NFS_VERSION = "nfs.version";
+constexpr auto SETTING_NFS_CHUNKSIZE = "nfs.chunksize";
 } // unnamed namespace
 
 CNfsConnection::CNfsConnection()
@@ -334,15 +335,38 @@ bool CNfsConnection::Connect(const CURL& url, std::string &relativePath)
     m_readChunkSize = nfs_get_readmax(m_pNfsContext);
     m_writeChunkSize = nfs_get_writemax(m_pNfsContext);
 
+    const auto settings = CServiceBroker::GetSettingsComponent()->GetSettings();
+    const uint64_t chunkSize =
+        settings ? (settings->GetInt(SETTING_NFS_CHUNKSIZE) * 1024) : (128 * 1024);
+
     if (m_readChunkSize == 0)
     {
-      CLog::Log(LOGDEBUG, "NFS Server did not return max read chunksize - Using 128K default");
-      m_readChunkSize = 128 * 1024; // 128K
+      CLog::Log(LOGDEBUG, "NFS Server did not return max read chunksize - Using setting value {}",
+                chunkSize);
+      m_readChunkSize = chunkSize;
     }
+    else if (chunkSize < m_readChunkSize)
+    {
+      CLog::Log(LOGDEBUG,
+                "NFS Server max read chunksize ({}) is bigger than client setting - Using client "
+                "value {}",
+                m_readChunkSize, chunkSize);
+      m_readChunkSize = chunkSize;
+    }
+
     if (m_writeChunkSize == 0)
     {
-      CLog::Log(LOGDEBUG, "NFS Server did not return max write chunksize - Using 128K default");
-      m_writeChunkSize = 128 * 1024; // 128K
+      CLog::Log(LOGDEBUG, "NFS Server did not return max write chunksize - Using setting value {}",
+                chunkSize);
+      m_writeChunkSize = chunkSize;
+    }
+    else if (chunkSize < m_writeChunkSize)
+    {
+      CLog::Log(LOGDEBUG,
+                "NFS Server max write chunksize ({}) is bigger than client setting - Using client "
+                "value {}",
+                m_writeChunkSize, chunkSize);
+      m_writeChunkSize = chunkSize;
     }
 
     if (contextRet == CNfsConnection::ContextStatus::NEW)
@@ -453,7 +477,11 @@ void CNfsConnection::keepAlive(const std::string& _exportPath, struct nfsfh* _pF
 
   nfs_lseek(pContext, _pFileHandle, 0, SEEK_CUR, &offset);
 
-  int bytes = nfs_read(pContext, _pFileHandle, 32, buffer);
+#ifdef LIBNFS_API_V2
+  int bytes = nfs_read(pContext, _pFileHandle, buffer, sizeof(buffer));
+#else
+  int bytes = nfs_read(pContext, _pFileHandle, sizeof(buffer), buffer);
+#endif
   if (bytes < 0)
   {
     CLog::LogF(LOGERROR, "nfs_read - Error ({}, {})", bytes, nfs_get_error(pContext));
@@ -717,8 +745,11 @@ ssize_t CNFSFile::Read(void *lpBuf, size_t uiBufSize)
 
   if (m_pFileHandle == NULL || m_pNfsContext == NULL )
     return -1;
-
+#ifdef LIBNFS_API_V2
+  numberOfBytesRead = nfs_read(m_pNfsContext, m_pFileHandle, lpBuf, uiBufSize);
+#else
   numberOfBytesRead = nfs_read(m_pNfsContext, m_pFileHandle, uiBufSize, (char *)lpBuf);
+#endif
 
   lock.unlock(); //no need to keep the connection lock after that
 
@@ -817,12 +848,17 @@ ssize_t CNFSFile::Write(const void* lpBuf, size_t uiBufSize)
     {
       chunkSize = leftBytes;//write last chunk with correct size
     }
+#ifdef LIBNFS_API_V2
+    writtenBytes = nfs_write(m_pNfsContext, m_pFileHandle,
+                             static_cast<const char*>(lpBuf) + numberOfBytesWritten, chunkSize);
+#else
     //write chunk
     //! @bug libnfs < 2.0.0 isn't const correct
     writtenBytes = nfs_write(m_pNfsContext,
                                   m_pFileHandle,
                                   chunkSize,
                                   const_cast<char*>((const char *)lpBuf) + numberOfBytesWritten);
+#endif
     //decrease left bytes
     leftBytes-= writtenBytes;
     //increase overall written bytes
