@@ -356,3 +356,8 @@ failure:
     return false;
 }
 }
+
+bool CUPnPDirectory::Resolve(CFileItem& item) const
+{
+  return GetResource(item.GetURL(), item);
+}
