@@ -170,7 +170,7 @@ void CVirtualDirectory::GetSources(VECSOURCES &shares) const
   if (m_allowNonLocalSources)
     CServiceBroker::GetMediaManager().GetRemovableDrives(shares);
 
-#ifdef HAS_DVD_DRIVE
+#ifdef HAS_OPTICAL_DRIVE
   // and update our dvd share
   for (unsigned int i = 0; i < shares.size(); ++i)
   {
