@@ -10,6 +10,7 @@
 
 #include "controllers/ControllerTypes.h"
 
+#include <future>
 #include <memory>
 #include <string>
 
@@ -72,6 +73,14 @@ public:
 
   CAgentInput& AgentInput() { return *m_agentInput; }
 
+  /*!
+   * \brief Called when an add-on repo is installed
+   *
+   * If the repo contains game add-ons, it can introduce new file extensions
+   * to the list of known game extensions.
+   */
+  void OnAddonRepoInstalled();
+
 private:
   // Construction parameters
   CControllerManager& m_controllerManager;
@@ -81,6 +90,9 @@ private:
   // Game services
   std::unique_ptr<CGameSettings> m_gameSettings;
   std::unique_ptr<CAgentInput> m_agentInput;
+
+  // Game threads
+  std::future<void> m_initializationTask;
 };
 } // namespace GAME
 } // namespace KODI
