@@ -41,12 +41,12 @@
 #include <algorithm>
 #include <cstring>
 #include <iterator>
+#include <memory>
 #include <mutex>
 #include <utility>
 
 using namespace KODI;
 using namespace GAME;
-using namespace KODI::MESSAGING;
 
 #define EXTENSION_SEPARATOR "|"
 #define EXTENSION_WILDCARD "*"
@@ -83,10 +83,7 @@ std::string NormalizeExtension(const std::string& strExtension)
 CGameClient::CGameClient(const ADDON::AddonInfoPtr& addonInfo)
   : CAddonDll(addonInfo, ADDON::AddonType::GAMEDLL),
     m_subsystems(CGameClientSubsystem::CreateSubsystems(*this, *m_ifc.game, m_critSection)),
-    m_bSupportsAllExtensions(false),
-    m_bIsPlaying(false),
-    m_serializeSize(0),
-    m_region(GAME_REGION_UNKNOWN)
+    m_bIsPlaying(false)
 {
   using namespace ADDON;
 
@@ -209,7 +206,7 @@ bool CGameClient::OpenFile(const CFileItem& file,
 
     // Failed to play game
     // The required files can't be found.
-    HELPERS::ShowOKDialogText(CVariant{35210}, CVariant{g_localizeStrings.Get(35219)});
+    MESSAGING::HELPERS::ShowOKDialogText(CVariant{35210}, CVariant{g_localizeStrings.Get(35219)});
     return false;
   }
 
@@ -316,7 +313,7 @@ bool CGameClient::InitializeGameplay(const std::string& gamePath,
     m_gamePath = gamePath;
     m_input = input;
 
-    m_inGameSaves.reset(new CGameClientInGameSaves(this, m_ifc.game));
+    m_inGameSaves = std::make_unique<CGameClientInGameSaves>(this, m_ifc.game);
     m_inGameSaves->Load();
 
     return true;
@@ -409,15 +406,16 @@ void CGameClient::NotifyError(GAME_ERROR error)
   {
     // Failed to play game
     // This game requires the following add-on: %s
-    HELPERS::ShowOKDialogText(CVariant{35210}, CVariant{StringUtils::Format(
-                                                   g_localizeStrings.Get(35211), missingResource)});
+    MESSAGING::HELPERS::ShowOKDialogText(
+        CVariant{35210},
+        CVariant{StringUtils::Format(g_localizeStrings.Get(35211), missingResource)});
   }
   else
   {
     // Failed to play game
     // The emulator "%s" had an internal error.
-    HELPERS::ShowOKDialogText(CVariant{35210},
-                              CVariant{StringUtils::Format(g_localizeStrings.Get(35213), Name())});
+    MESSAGING::HELPERS::ShowOKDialogText(
+        CVariant{35210}, CVariant{StringUtils::Format(g_localizeStrings.Get(35213), Name())});
   }
 }
 
