@@ -28,6 +28,7 @@ class CPortInput;
 
 /*!
  * \ingroup games
+ *
  * \brief Handles game controller events for games.
  *
  * Listens to game controller events and forwards them to the games (as game_input_event).
@@ -75,10 +76,11 @@ public:
 
   // Input accessors
   const std::string& GetPortAddress() const { return m_portAddress; }
-  const ControllerPtr& GetController() const { return m_controller; }
+  ControllerPtr GetController() const { return m_controller; }
   std::string GetControllerAddress() const;
-  const PERIPHERALS::PeripheralPtr& GetSource() const { return m_sourcePeripheral; }
+  PERIPHERALS::PeripheralPtr GetSource() const { return m_sourcePeripheral; }
   std::string GetSourceLocation() const;
+  float GetActivation() const;
 
   // Input mutators
   void SetSource(PERIPHERALS::PeripheralPtr sourcePeripheral);
