@@ -105,13 +105,11 @@ void CAgentInput::Refresh()
 {
   if (m_gameClient)
   {
-    // Open keyboard
-    if (m_bHasKeyboard)
-      ProcessKeyboard();
+    // Process keyboard
+    ProcessKeyboard();
 
-    // Open mouse
-    if (m_bHasMouse)
-      ProcessMouse();
+    // Process mouse
+    ProcessMouse();
 
     // Open/close joysticks
     PERIPHERALS::EventLockHandlePtr inputHandlingLock;
@@ -323,7 +321,7 @@ void CAgentInput::ProcessJoysticks(PERIPHERALS::EventLockHandlePtr& inputHandlin
       joysticks.end());
 
   // Update agent controllers
-  ProcessAgentControllers(joysticks, inputHandlingLock);
+  ProcessAgentControllers(joysticks, inputHandlingLock, true);
 
   if (!m_gameClient)
     return;
@@ -363,7 +361,7 @@ void CAgentInput::ProcessKeyboard()
   {
     // Update agent controllers
     PERIPHERALS::EventLockHandlePtr inputHandlingLock;
-    ProcessAgentControllers(keyboards, inputHandlingLock);
+    ProcessAgentControllers(keyboards, inputHandlingLock, false);
 
     // Process keyboard input
     if (m_gameClient && m_gameClient->Input().SupportsKeyboard() &&
@@ -397,7 +395,7 @@ void CAgentInput::ProcessMouse()
   {
     // Update agent controllers
     PERIPHERALS::EventLockHandlePtr inputHandlingLock;
-    ProcessAgentControllers(mice, inputHandlingLock);
+    ProcessAgentControllers(mice, inputHandlingLock, false);
 
     // Process mouse input
     if (m_gameClient && m_gameClient->Input().SupportsMouse() &&
@@ -423,13 +421,18 @@ void CAgentInput::ProcessMouse()
 }
 
 void CAgentInput::ProcessAgentControllers(const PERIPHERALS::PeripheralVector& peripherals,
-                                          PERIPHERALS::EventLockHandlePtr& inputHandlingLock)
+                                          PERIPHERALS::EventLockHandlePtr& inputHandlingLock,
+                                          bool updateJoysticks)
 {
   std::lock_guard<std::mutex> lock(m_controllerMutex);
 
   // Handle new and existing controllers
   for (const auto& peripheral : peripherals)
   {
+    // Skip peripherals that have never been active
+    if (!peripheral->LastActive().IsValid())
+      continue;
+
     // Check if controller already exists
     auto it = std::find_if(m_controllers.begin(), m_controllers.end(),
                            [&peripheral](const std::shared_ptr<CAgentController>& controller) {
@@ -472,9 +475,7 @@ void CAgentInput::ProcessAgentControllers(const PERIPHERALS::PeripheralVector& p
   }
 
   // If we're processing joysticks, remove expired joysticks
-  if (std::any_of(peripherals.begin(), peripherals.end(),
-                  [](const PERIPHERALS::PeripheralPtr& peripheral)
-                  { return peripheral->Type() == PERIPHERALS::PERIPHERAL_JOYSTICK; }))
+  if (updateJoysticks)
   {
     std::vector<std::string> expiredJoysticks;
     for (const auto& agentController : m_controllers)
