@@ -11,13 +11,19 @@
 #include <string>
 #include <vector>
 
-class TiXmlElement;
+namespace tinyxml2
+{
+class XMLElement;
+}
 
 namespace KODI
 {
 namespace GAME
 {
 
+/*!
+ * \ingroup games
+ */
 class CPhysicalPort
 {
 public:
@@ -54,7 +60,7 @@ public:
    */
   bool IsCompatible(const std::string& controllerId) const;
 
-  bool Deserialize(const TiXmlElement* pElement);
+  bool Deserialize(const tinyxml2::XMLElement* pElement);
 
 private:
   std::string m_portId;
