@@ -20,3 +20,10 @@
 
 // Skin XML file
 #define PORT_DIALOG_XML "DialogGameControllers.xml"
+
+/*!
+ * \ingroup games
+ *
+ * \brief The maximum port count, chosen to allow for two Saturn 6 Player Adapters
+ */
+constexpr unsigned int MAX_PORT_COUNT = 12;
