@@ -59,6 +59,36 @@ constexpr int CHAR_CHUNK = 64; // 64 chars allocated at a time (2048 bytes)
 constexpr int GLYPH_STRENGTH_BOLD = 24;
 constexpr int GLYPH_STRENGTH_LIGHT = -48;
 constexpr int TAB_SPACE_LENGTH = 4;
+
+// \brief Check for conflicting alignments
+void ValidateAlignments(uint32_t& aligns)
+{
+  // Validate the horizontal alignment (XBFONT_LEFT is implicit unless otherwise specified)
+  {
+    const uint32_t hAligns = XBFONT_RIGHT | XBFONT_CENTER_X | XBFONT_JUSTIFIED;
+    const uint32_t commonFlags = hAligns & aligns;
+    // Check if at least 2 bits are set, it means multiple aligns
+    if ((commonFlags & (commonFlags - 1)) != 0)
+    {
+      CLog::LogF(LOGERROR, "Text with invalid multiple horizontal alignments");
+      aligns &= ~commonFlags;
+    }
+  }
+
+  // Validate truncate alignment
+  {
+    const uint32_t truncateAligns = XBFONT_TRUNCATED | XBFONT_TRUNCATED_LEFT;
+    const uint32_t commonFlags = truncateAligns & aligns;
+    // Check if at least 2 bits are set, it means multiple aligns
+    if ((commonFlags & (commonFlags - 1)) != 0)
+    {
+      CLog::LogF(LOGERROR, "Text with invalid multiple truncate alignments");
+      aligns &= ~commonFlags;
+      aligns |= XBFONT_TRUNCATED;
+    }
+  }
+}
+
 } /* namespace */
 
 class CFreeTypeLibrary
@@ -358,6 +388,7 @@ void CGUIFontTTF::DrawTextInternal(CGraphicContext& context,
         CGUIFontCacheDynamicPosition(context.ScaleFinalXCoord(x, y), context.ScaleFinalYCoord(x, y),
                                      context.ScaleFinalZCoord(x, y));
   }
+
   CVertexBuffer unusedVertexBuffer;
   CVertexBuffer& vertexBuffer =
       hardwareClipping
@@ -385,6 +416,13 @@ void CGUIFontTTF::DrawTextInternal(CGraphicContext& context,
 
   if (dirtyCache)
   {
+    // Try to validate any conflicting alignments
+    //! @todo: This validate is the last resort and can result in a bad rendered text
+    //! because the alignment it is used also by caller components for other operations
+    //! this inform the problem on the log, potentially can be improved
+    //! by add validating alignments from each parent caller component
+    ValidateAlignments(alignment);
+
     const std::vector<Glyph> glyphs = GetHarfBuzzShapedGlyphs(text);
     // save the origin, which is scaled separately
     m_originX = x;
@@ -399,12 +437,20 @@ void CGUIFontTTF::DrawTextInternal(CGraphicContext& context,
         m_ellipsesWidth = ellipse->m_advance;
     }
 
+    // Define the width of ellipses of three chars "..."
+    const float ellipsesWidth = 3 * m_ellipsesWidth;
+
     // Check if we will really need to truncate or justify the text
     if (alignment & XBFONT_TRUNCATED)
     {
       if (maxPixelWidth <= 0.0f || GetTextWidthInternal(text, glyphs) <= maxPixelWidth)
         alignment &= ~XBFONT_TRUNCATED;
     }
+    else if (alignment & XBFONT_TRUNCATED_LEFT)
+    {
+      if (maxPixelWidth <= 0.0f || GetTextWidthInternal(text, glyphs) <= maxPixelWidth)
+        alignment &= ~XBFONT_TRUNCATED_LEFT;
+    }
     else if (alignment & XBFONT_JUSTIFIED)
     {
       if (maxPixelWidth <= 0.0f)
@@ -415,18 +461,74 @@ void CGUIFontTTF::DrawTextInternal(CGraphicContext& context,
     float startX = 0;
     float startY = (alignment & XBFONT_CENTER_Y) ? -0.5f * m_cellHeight : 0; // vertical centering
 
-    if (alignment & (XBFONT_RIGHT | XBFONT_CENTER_X))
+    size_t startPosGlyph{0}; // Defines the index position where start rendering glyphs
+    float textWidth{0}; // The text width, by taking in account truncate (and ellipses)
+
+    if (alignment & XBFONT_TRUNCATED_LEFT)
     {
-      // Get the extent of this line
-      float w = GetTextWidthInternal(text, glyphs);
+      // To truncate to the left, we skip all characters that exceed the maximum width,
+      // so the rendering starts from the first character that falls within the maximum width,
+      // taking into account also the ellipses
+      textWidth = ellipsesWidth;
 
-      if (alignment & XBFONT_TRUNCATED && w > maxPixelWidth + 0.5f) // + 0.5f due to rounding issues
-        w = maxPixelWidth;
+      // We need to iterate from the end to the beginning
+      for (auto itRGlyph = glyphs.crbegin(); itRGlyph != glyphs.crend(); ++itRGlyph)
+      {
+        const character_t ch = text[itRGlyph->m_glyphInfo.cluster];
+        Character* c = GetCharacter(ch, itRGlyph->m_glyphInfo.codepoint);
+        if (!c)
+          continue;
 
-      if (alignment & XBFONT_CENTER_X)
-        w *= 0.5f;
-      // Offset this line's starting position
-      startX -= w;
+        float nextWidth = textWidth;
+        if ((ch & 0xffff) == static_cast<character_t>('\t'))
+          nextWidth += GetTabSpaceLength();
+        else
+          nextWidth += c->m_advance;
+
+        if (maxPixelWidth > 0 && nextWidth > maxPixelWidth)
+        {
+          // Start rendering from the glyph that does not exceed the maximum width
+          startPosGlyph = std::distance(itRGlyph, glyphs.crend());
+          break;
+        }
+        textWidth = nextWidth;
+      }
+    }
+    else
+    {
+      // Calculates the text width based on the characters that can be contained within the maximum width
+      if (alignment & XBFONT_TRUNCATED)
+        textWidth = ellipsesWidth;
+
+      for (const Glyph& glyph : glyphs)
+      {
+        const character_t ch = text[glyph.m_glyphInfo.cluster];
+        Character* c = GetCharacter(ch, glyph.m_glyphInfo.codepoint);
+        if (!c)
+          continue;
+
+        float nextWidth = textWidth;
+        if ((ch & 0xffff) == static_cast<character_t>('\t'))
+          nextWidth += GetTabSpaceLength();
+        else
+          nextWidth += c->m_advance;
+
+        if (maxPixelWidth > 0 && nextWidth > maxPixelWidth)
+          break;
+
+        textWidth = nextWidth;
+      }
+    }
+
+    if (alignment & XBFONT_RIGHT)
+    {
+      // Moves the x pos with the purpose of having the text effect aligned to the right
+      startX += maxPixelWidth - textWidth;
+    }
+    else if (alignment & XBFONT_CENTER_X)
+    {
+      textWidth *= 0.5f;
+      startX -= textWidth;
     }
 
     float spacePerSpaceCharacter = 0; // for justification effects
@@ -457,11 +559,16 @@ void CGUIFontTTF::DrawTextInternal(CGraphicContext& context,
     // are not currently cached and cause the texture to be enlarged, which
     // would invalidate the texture coordinates.
     std::queue<Character> characters;
-    if (alignment & XBFONT_TRUNCATED)
-      GetCharacter(L'.', 0);
-    for (const auto& glyph : glyphs)
+
+    if (alignment & XBFONT_TRUNCATED_LEFT)
+      cursorX += ellipsesWidth;
+
+    auto glyphBegin = glyphs.cbegin() + startPosGlyph;
+
+    for (auto itGlyph = glyphBegin; itGlyph != glyphs.cend(); ++itGlyph)
     {
-      Character* ch = GetCharacter(text[glyph.m_glyphInfo.cluster], glyph.m_glyphInfo.codepoint);
+      Character* ch =
+          GetCharacter(text[itGlyph->m_glyphInfo.cluster], itGlyph->m_glyphInfo.codepoint);
       if (!ch)
       {
         Character null = {};
@@ -470,10 +577,17 @@ void CGUIFontTTF::DrawTextInternal(CGraphicContext& context,
       }
       characters.push(*ch);
 
-      if (maxPixelWidth > 0 &&
-          cursorX + ((alignment & XBFONT_TRUNCATED) ? ch->m_advance + 3 * m_ellipsesWidth : 0) >
-              maxPixelWidth)
-        break;
+      if (maxPixelWidth > 0)
+      {
+        float nextCursorX = cursorX;
+
+        if (alignment & XBFONT_TRUNCATED)
+          nextCursorX += ch->m_advance + ellipsesWidth;
+
+        if (nextCursorX > maxPixelWidth)
+          break;
+      }
+
       cursorX += ch->m_advance;
     }
 
@@ -481,11 +595,11 @@ void CGUIFontTTF::DrawTextInternal(CGraphicContext& context,
     tempVertices->reserve(VERTEX_PER_GLYPH * glyphs.size());
     cursorX = 0;
 
-    for (const auto& glyph : glyphs)
+    for (auto itGlyph = glyphBegin; itGlyph != glyphs.cend(); ++itGlyph)
     {
       // If starting text on a new line, determine justification effects
       // Get the current letter in the CStdString
-      UTILS::COLOR::Color color = (text[glyph.m_glyphInfo.cluster] & 0xff0000) >> 16;
+      UTILS::COLOR::Color color = (text[itGlyph->m_glyphInfo.cluster] & 0xff0000) >> 16;
       if (color >= colors.size())
         color = 0;
       color = colors[color];
@@ -493,7 +607,7 @@ void CGUIFontTTF::DrawTextInternal(CGraphicContext& context,
       // grab the next character
       Character* ch = &characters.front();
 
-      if ((text[glyph.m_glyphInfo.cluster] & 0xffff) == static_cast<character_t>('\t'))
+      if ((text[itGlyph->m_glyphInfo.cluster] & 0xffff) == static_cast<character_t>('\t'))
       {
         const float tabwidth = GetTabSpaceLength();
         const float a = cursorX / tabwidth;
@@ -505,7 +619,7 @@ void CGUIFontTTF::DrawTextInternal(CGraphicContext& context,
       if (alignment & XBFONT_TRUNCATED)
       {
         // Check if we will be exceeded the max allowed width
-        if (cursorX + ch->m_advance + 3 * m_ellipsesWidth > maxPixelWidth)
+        if (cursorX + ch->m_advance + ellipsesWidth > maxPixelWidth)
         {
           // Yup. Let's draw the ellipses, then bail
           // Perhaps we should really bail to the next line in this case??
@@ -522,18 +636,32 @@ void CGUIFontTTF::DrawTextInternal(CGraphicContext& context,
           break;
         }
       }
+      else if (alignment & XBFONT_TRUNCATED_LEFT && itGlyph == glyphBegin)
+      {
+        // Add ellipsis only at the beginning of the text
+        Character* period = GetCharacter(L'.', 0);
+        if (!period)
+          break;
+
+        for (int i = 0; i < 3; i++)
+        {
+          RenderCharacter(context, startX + cursorX, startY, period, color, !scrolling,
+                          *tempVertices);
+          cursorX += period->m_advance;
+        }
+      }
       else if (maxPixelWidth > 0 && cursorX > maxPixelWidth)
         break; // exceeded max allowed width - stop rendering
 
       offsetX = static_cast<float>(
-          MathUtils::round_int(static_cast<double>(glyph.m_glyphPosition.x_offset) / 64));
+          MathUtils::round_int(static_cast<double>(itGlyph->m_glyphPosition.x_offset) / 64));
       offsetY = static_cast<float>(
-          MathUtils::round_int(static_cast<double>(glyph.m_glyphPosition.y_offset) / 64));
+          MathUtils::round_int(static_cast<double>(itGlyph->m_glyphPosition.y_offset) / 64));
       RenderCharacter(context, startX + cursorX + offsetX, startY - offsetY, ch, color, !scrolling,
                       *tempVertices);
       if (alignment & XBFONT_JUSTIFIED)
       {
-        if ((text[glyph.m_glyphInfo.cluster] & 0xffff) == L' ')
+        if ((text[itGlyph->m_glyphInfo.cluster] & 0xffff) == L' ')
           cursorX += ch->m_advance + spacePerSpaceCharacter;
         else
           cursorX += ch->m_advance;
@@ -653,10 +781,11 @@ std::vector<CGUIFontTTF::Glyph> CGUIFontTTF::GetHarfBuzzShapedGlyphs(const vecTe
   std::vector<hb_script_t> scripts;
   std::vector<RunInfo> runs;
   hb_unicode_funcs_t* ufuncs = hb_unicode_funcs_get_default();
-  hb_script_t lastScript;
+  hb_script_t lastScript{HB_SCRIPT_INVALID};
   int lastScriptIndex = -1;
   int lastSetIndex = -1;
 
+  scripts.reserve(text.size());
   for (const auto& character : text)
   {
     scripts.emplace_back(hb_unicode_script(ufuncs, static_cast<wchar_t>(0xffff & character)));
