@@ -167,6 +167,11 @@ bool CGUIMultiImage::OnMessage(CGUIMessage &message)
       FreeResources();
     return true;
   }
+  if (message.GetMessage() == GUI_MSG_RESET_MULTI_IMAGE)
+  {
+    ResetMultiImage();
+    return true;
+  }
   return CGUIControl::OnMessage(message);
 }
 
@@ -251,9 +256,7 @@ void CGUIMultiImage::OnDirectoryLoaded()
 
   // flag as loaded - no point in constantly reloading them
   m_directoryStatus = READY;
-  m_imageTimer.StartZero();
-  m_currentImage = 0;
-  m_image.SetFileName(m_files.empty() ? "" : m_files[0]);
+  ResetMultiImage();
 }
 
 void CGUIMultiImage::CancelLoading()
@@ -264,6 +267,13 @@ void CGUIMultiImage::CancelLoading()
   m_directoryStatus = UNLOADED;
 }
 
+void CGUIMultiImage::ResetMultiImage()
+{
+  m_imageTimer.StartZero();
+  m_currentImage = 0;
+  m_image.SetFileName(m_files.empty() ? "" : m_files[0]);
+}
+
 void CGUIMultiImage::OnJobComplete(unsigned int jobID, bool success, CJob *job)
 {
   std::unique_lock<CCriticalSection> lock(m_section);
