@@ -16,7 +16,6 @@
 class CFileItem;
 
 class CGUIListItem;
-typedef std::shared_ptr<CGUIListItem> CGUIListItemPtr;
 
 class CGUIControl;
 class CGUIMediaWindow;
@@ -34,7 +33,10 @@ std::string GetPlaylistLabel(int item, PLAYLIST::Id playlistid = PLAYLIST::TYPE_
 CGUIWindow* GetWindow(int contextWindow);
 CGUIControl* GetActiveContainer(int containerId, int contextWindow);
 CGUIMediaWindow* GetMediaWindow(int contextWindow);
-CGUIListItemPtr GetCurrentListItem(int contextWindow, int containerId = 0, int itemOffset = 0, unsigned int itemFlags = 0);
+std::shared_ptr<CGUIListItem> GetCurrentListItem(int contextWindow,
+                                                 int containerId = 0,
+                                                 int itemOffset = 0,
+                                                 unsigned int itemFlags = 0);
 
 std::string GetFileInfoLabelValueFromPath(int info, const std::string& filenameAndPath);
 
