@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005-2018 Team Kodi
+ *  Copyright (C) 2005-2024 Team Kodi
  *  This file is part of Kodi - https://kodi.tv
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
@@ -8,13 +8,7 @@
 
 #include "InputManager.h"
 
-#include "ButtonTranslator.h"
-#include "CustomControllerTranslator.h"
-#include "JoystickMapper.h"
-#include "KeymapEnvironment.h"
 #include "ServiceBroker.h"
-#include "TouchTranslator.h"
-#include "XBMC_vkeys.h"
 #include "application/AppInboundProtocol.h"
 #include "application/Application.h"
 #include "application/ApplicationComponents.h"
@@ -24,9 +18,18 @@
 #include "guilib/GUIControl.h"
 #include "guilib/GUIWindow.h"
 #include "guilib/GUIWindowManager.h"
-#include "input/Key.h"
+#include "input/actions/Action.h"
+#include "input/actions/ActionIDs.h"
+#include "input/keyboard/Key.h"
+#include "input/keyboard/KeyIDs.h"
 #include "input/keyboard/KeyboardEasterEgg.h"
+#include "input/keyboard/XBMC_vkeys.h"
 #include "input/keyboard/interfaces/IKeyboardDriverHandler.h"
+#include "input/keymaps/ButtonTranslator.h"
+#include "input/keymaps/KeymapEnvironment.h"
+#include "input/keymaps/joysticks/JoystickMapper.h"
+#include "input/keymaps/remote/CustomControllerTranslator.h"
+#include "input/keymaps/touch/TouchTranslator.h"
 #include "input/mouse/MouseTranslator.h"
 #include "input/mouse/interfaces/IMouseDriverHandler.h"
 #include "messaging/ApplicationMessenger.h"
@@ -43,6 +46,7 @@
 #include <algorithm>
 #include <math.h>
 #include <mutex>
+#include <unordered_map>
 
 using EVENTSERVER::CEventServer;
 
@@ -50,12 +54,20 @@ using namespace KODI;
 
 const std::string CInputManager::SETTING_INPUT_ENABLE_CONTROLLER = "input.enablejoystick";
 
+namespace
+{
+const std::unordered_map<uint8_t, int> keyComposeactionEventMap = {
+    {XBMC_KEYCOMPOSING_COMPOSING, ACTION_KEYBOARD_COMPOSING_KEY},
+    {XBMC_KEYCOMPOSING_CANCELLED, ACTION_KEYBOARD_COMPOSING_KEY_CANCELLED},
+    {XBMC_KEYCOMPOSING_FINISHED, ACTION_KEYBOARD_COMPOSING_KEY_FINISHED}};
+}
+
 CInputManager::CInputManager()
-  : m_keymapEnvironment(new CKeymapEnvironment),
-    m_buttonTranslator(new CButtonTranslator),
-    m_customControllerTranslator(new CCustomControllerTranslator),
-    m_touchTranslator(new CTouchTranslator),
-    m_joystickTranslator(new CJoystickMapper),
+  : m_keymapEnvironment(new KEYMAP::CKeymapEnvironment),
+    m_buttonTranslator(new KEYMAP::CButtonTranslator),
+    m_customControllerTranslator(new KEYMAP::CCustomControllerTranslator),
+    m_touchTranslator(new KEYMAP::CTouchTranslator),
+    m_joystickTranslator(new KEYMAP::CJoystickMapper),
     m_keyboardEasterEgg(new KEYBOARD::CKeyboardEasterEgg)
 {
   m_buttonTranslator->RegisterMapper("touch", m_touchTranslator.get());
@@ -230,7 +242,7 @@ bool CInputManager::ProcessEventServer(int windowId, float frameTime)
 
           CLog::Log(LOGDEBUG, "EventServer: key {} translated to action {}", wKeyID, actionName);
 
-          return ExecuteInputAction(CAction(actionID, fAmount, 0.0f, actionName));
+          return ExecuteInputAction(CAction(actionID, fAmount, 0.0f, actionName, 0, wKeyID));
         }
         else
         {
@@ -312,9 +324,8 @@ void CInputManager::QueueAction(const CAction& action)
   if (action.IsAnalog())
   {
     m_queuedActions.erase(std::remove_if(m_queuedActions.begin(), m_queuedActions.end(),
-                                         [&action](const CAction& queuedAction) {
-                                           return action.GetID() == queuedAction.GetID();
-                                         }),
+                                         [&action](const CAction& queuedAction)
+                                         { return action.GetID() == queuedAction.GetID(); }),
                           m_queuedActions.end());
   }
 
@@ -349,6 +360,15 @@ bool CInputManager::OnEvent(XBMC_Event& newEvent)
       m_Keyboard.ProcessKeyUp();
       OnKeyUp(m_Keyboard.TranslateKey(newEvent.key.keysym));
       break;
+    case XBMC_KEYCOMPOSING_COMPOSING:
+    case XBMC_KEYCOMPOSING_CANCELLED:
+    case XBMC_KEYCOMPOSING_FINISHED:
+    {
+      const CAction action = CAction(keyComposeactionEventMap.find(newEvent.type)->second,
+                                     static_cast<wchar_t>(newEvent.key.keysym.unicode));
+      ExecuteInputAction(action);
+      break;
+    }
     case XBMC_MOUSEBUTTONDOWN:
     case XBMC_MOUSEBUTTONUP:
     case XBMC_MOUSEMOTION:
@@ -884,6 +904,11 @@ void CInputManager::RemoveKeymap(const std::string& keymap)
   }
 }
 
+const KEYMAP::IKeymapEnvironment* CInputManager::KeymapEnvironment() const
+{
+  return m_keymapEnvironment.get();
+}
+
 CAction CInputManager::GetAction(int window, const CKey& key, bool fallback /* = true */)
 {
   return m_buttonTranslator->GetAction(window, key, fallback);
@@ -906,7 +931,7 @@ bool CInputManager::TranslateTouchAction(
                                                  actionString);
 }
 
-std::vector<std::shared_ptr<const IWindowKeymap>> CInputManager::GetJoystickKeymaps() const
+std::vector<std::shared_ptr<const KEYMAP::IWindowKeymap>> CInputManager::GetJoystickKeymaps() const
 {
   return m_joystickTranslator->GetJoystickKeymaps();
 }
