@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2017-2018 Team Kodi
+ *  Copyright (C) 2017-2024 Team Kodi
  *  This file is part of Kodi - https://kodi.tv
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
@@ -8,8 +8,8 @@
 
 #include "input/keyboard/KeyboardEasterEgg.h"
 
-#include "input/Key.h"
 #include "input/joysticks/JoystickEasterEgg.h"
+#include "input/keyboard/Key.h"
 
 using namespace KODI;
 using namespace KEYBOARD;
