@@ -29,6 +29,8 @@
 #include "utils/URIUtils.h"
 #include "utils/Variant.h"
 
+#include <memory>
+
 using namespace MUSIC_INFO;
 using namespace JSONRPC;
 using namespace XFILE;
@@ -495,7 +497,7 @@ JSONRPC_STATUS CAudioLibrary::GetSongDetails(const std::string &method, ITranspo
     return InvalidParams;
 
   CFileItemList items;
-  CFileItemPtr item = CFileItemPtr(new CFileItem(song));
+  CFileItemPtr item = std::make_shared<CFileItem>(song);
   FillItemArtistIDs(song.GetArtistIDArray(), item);
   items.Add(item);
 
@@ -991,6 +993,8 @@ JSONRPC_STATUS CAudioLibrary::SetSongDetails(const std::string &method, ITranspo
     song.strOrigReleaseDate = parameterObject["originaldate"].asString();
   if (ParameterNotNull(parameterObject, "albumreleasedate"))
     song.strReleaseDate = parameterObject["albumreleasedate"].asString();
+  if (ParameterNotNull(parameterObject, "songvideourl"))
+    song.songVideoURL = parameterObject["songvideourl"].asString();
 
   // Update existing art. Any existing artwork that isn't specified in this request stays as is.
   // If the value is null then the existing art with that type is removed.
@@ -1022,7 +1026,8 @@ JSONRPC_STATUS CAudioLibrary::SetSongDetails(const std::string &method, ITranspo
   if (!musicdatabase.UpdateSong(song, updateartists))
     return InternalError;
 
-  CJSONRPCUtils::NotifyItemUpdated();
+  const auto item = std::make_shared<CFileItem>(song);
+  CJSONRPCUtils::NotifyItemUpdated(item);
   return ACK;
 }
 
@@ -1148,7 +1153,7 @@ bool CAudioLibrary::FillFileItemList(const CVariant &parameterObject, CFileItemL
     CSong song;
     if (musicdatabase.GetSong(songID, song))
     {
-      list.Add(CFileItemPtr(new CFileItem(song)));
+      list.Add(std::make_shared<CFileItem>(song));
       success = true;
     }
   }
@@ -1187,7 +1192,7 @@ void CAudioLibrary::FillAlbumItem(const CAlbum& album,
                                   const std::string& path,
                                   std::shared_ptr<CFileItem>& item)
 {
-  item = CFileItemPtr(new CFileItem(path, album));
+  item = std::make_shared<CFileItem>(path, album);
   // Add album artistIds as separate property as not part of CMusicInfoTag
   std::vector<int> artistids = album.GetArtistIDArray();
   FillItemArtistIDs(artistids, item);
