@@ -27,6 +27,8 @@
 #include "pvr/timers/PVRTimers.h"
 #include "utils/Variant.h"
 
+#include <memory>
+
 using namespace JSONRPC;
 using namespace PVR;
 using namespace KODI::MESSAGING;
@@ -217,7 +219,8 @@ JSONRPC_STATUS CPVROperations::GetBroadcastDetails(const std::string &method, IT
   if (!epgTag)
     return InvalidParams;
 
-  HandleFileItem("broadcastid", false, "broadcastdetails", CFileItemPtr(new CFileItem(epgTag)), parameterObject, parameterObject["properties"], result, false);
+  HandleFileItem("broadcastid", false, "broadcastdetails", std::make_shared<CFileItem>(epgTag),
+                 parameterObject, parameterObject["properties"], result, false);
 
   return OK;
 }
@@ -231,7 +234,7 @@ JSONRPC_STATUS CPVROperations::GetBroadcastIsPlayable(const std::string& method,
   if (!CServiceBroker::GetPVRManager().IsStarted())
     return FailedToExecute;
 
-  const std::shared_ptr<CPVREpgInfoTag> epgTag =
+  const std::shared_ptr<const CPVREpgInfoTag> epgTag =
       CServiceBroker::GetPVRManager().EpgContainer().GetTagByDatabaseId(
           parameterObject["broadcastid"].asInteger());
 
@@ -334,7 +337,11 @@ JSONRPC_STATUS CPVROperations::GetPropertyValue(const std::string &property, CVa
   return OK;
 }
 
-void CPVROperations::FillChannelGroupDetails(const std::shared_ptr<CPVRChannelGroup> &channelGroup, const CVariant &parameterObject, CVariant &result, bool append /* = false */)
+void CPVROperations::FillChannelGroupDetails(
+    const std::shared_ptr<const CPVRChannelGroup>& channelGroup,
+    const CVariant& parameterObject,
+    CVariant& result,
+    bool append /* = false */)
 {
   if (channelGroup == NULL)
     return;
@@ -396,7 +403,8 @@ JSONRPC_STATUS CPVROperations::GetTimerDetails(const std::string &method, ITrans
   if (!timer)
     return InvalidParams;
 
-  HandleFileItem("timerid", false, "timerdetails", CFileItemPtr(new CFileItem(timer)), parameterObject, parameterObject["properties"], result, false);
+  HandleFileItem("timerid", false, "timerdetails", std::make_shared<CFileItem>(timer),
+                 parameterObject, parameterObject["properties"], result, false);
 
   return OK;
 }
