@@ -27,7 +27,7 @@
 #include "guilib/GUISliderControl.h"
 #include "guilib/GUITextBox.h"
 #include "guilib/GUIWindowManager.h"
-#include "listproviders/StaticProvider.h"
+#include "guilib/listproviders/StaticProvider.h"
 #include "utils/StringUtils.h"
 #include "utils/XBMCTinyXML.h"
 
@@ -447,10 +447,16 @@ namespace XBMCAddon
 
     // ============================================================
     // ============================================================
-    ControlSlider::ControlSlider(long x, long y, long width, long height,
+    ControlSlider::ControlSlider(long x,
+                                 long y,
+                                 long width,
+                                 long height,
                                  const char* textureback,
                                  const char* texture,
-                                 const char* texturefocus, int orientation)
+                                 const char* texturefocus,
+                                 int orientation,
+                                 const char* texturebackdisabled,
+                                 const char* texturedisabled)
     {
       dwPosX = x;
       dwPosY = y;
@@ -461,10 +467,12 @@ namespace XBMCAddon
       // if texture is supplied use it, else get default ones
       strTextureBack = textureback ? textureback :
         XBMCAddonUtils::getDefaultImage("slider", "texturesliderbar");
+      strTextureBackDisabled = texturebackdisabled ? texturebackdisabled : strTextureBack;
       strTexture = texture ? texture :
         XBMCAddonUtils::getDefaultImage("slider", "textureslidernib");
       strTextureFoc = texturefocus ? texturefocus :
         XBMCAddonUtils::getDefaultImage("slider", "textureslidernibfocus");
+      strTextureDisabled = texturedisabled ? texturedisabled : strTexture;
     }
 
     float ControlSlider::getPercent()
@@ -510,12 +518,13 @@ namespace XBMCAddon
       }
     }
 
-    CGUIControl* ControlSlider::Create ()
+    CGUIControl* ControlSlider::Create()
     {
-      pGUIControl = new CGUISliderControl(iParentId, iControlId,(float)dwPosX, (float)dwPosY,
-                                          (float)dwWidth,(float)dwHeight,
-                                          CTextureInfo(strTextureBack),CTextureInfo(strTexture),
-                                          CTextureInfo(strTextureFoc), 0, ORIENTATION(iOrientation));
+      pGUIControl = new CGUISliderControl(
+          iParentId, iControlId, (float)dwPosX, (float)dwPosY, (float)dwWidth, (float)dwHeight,
+          CTextureInfo(strTextureBack), CTextureInfo(strTextureBackDisabled),
+          CTextureInfo(strTexture), CTextureInfo(strTextureFoc), CTextureInfo(strTextureDisabled),
+          0, ORIENTATION(iOrientation));
 
       return pGUIControl;
     }
@@ -956,22 +965,30 @@ namespace XBMCAddon
     // ============================================================
     //  ControlLabel
     // ============================================================
-    ControlLabel::ControlLabel(long x, long y, long width, long height,
+    ControlLabel::ControlLabel(long x,
+                               long y,
+                               long width,
+                               long height,
                                const String& label,
-                               const char* font, const char* p_textColor,
+                               const char* font,
+                               const char* p_textColor,
                                const char* p_disabledColor,
                                long p_alignment,
-                               bool hasPath, long angle) :
-      strFont("font13"),
-      textColor(0xffffffff), disabledColor(0x60ffffff),
-      align(p_alignment), bHasPath(hasPath), iAngle(angle)
+                               bool hasPath,
+                               long angle)
+      : strFont("font13"),
+        strText(label),
+        textColor(0xffffffff),
+        disabledColor(0x60ffffff),
+        align(p_alignment),
+        bHasPath(hasPath),
+        iAngle(angle)
     {
       dwPosX = x;
       dwPosY = y;
       dwWidth = width;
       dwHeight = height;
 
-      strText = label;
       if (font)
         strFont = font;
 
@@ -1027,26 +1044,32 @@ namespace XBMCAddon
     // ============================================================
     //  ControlEdit
     // ============================================================
-    ControlEdit::ControlEdit(long x, long y, long width, long height, const String& label,
-                             const char* font, const char* _textColor,
+    ControlEdit::ControlEdit(long x,
+                             long y,
+                             long width,
+                             long height,
+                             const String& label,
+                             const char* font,
+                             const char* _textColor,
                              const char* _disabledColor,
-                             long _alignment, const char* focusTexture,
-                             const char* noFocusTexture) :
-      strFont("font13"), textColor(0xffffffff), disabledColor(0x60ffffff),
-      align(_alignment)
-
+                             long _alignment,
+                             const char* focusTexture,
+                             const char* noFocusTexture)
+      : strFont("font13"),
+        strTextureFocus(focusTexture ? focusTexture
+                                     : XBMCAddonUtils::getDefaultImage("edit", "texturefocus")),
+        strTextureNoFocus(noFocusTexture
+                              ? noFocusTexture
+                              : XBMCAddonUtils::getDefaultImage("edit", "texturenofocus")),
+        textColor(0xffffffff),
+        disabledColor(0x60ffffff),
+        align(_alignment)
     {
       dwPosX = x;
       dwPosY = y;
       dwWidth = width;
       dwHeight = height;
 
-      strTextureFocus = focusTexture ? focusTexture :
-        XBMCAddonUtils::getDefaultImage("edit", "texturefocus");
-
-      strTextureNoFocus = noFocusTexture ? noFocusTexture :
-        XBMCAddonUtils::getDefaultImage("edit", "texturenofocus");
-
       if (!label.empty())
       {
         strText = label;
@@ -1243,7 +1266,7 @@ namespace XBMCAddon
     void ControlList::sendLabelBind(int tail)
     {
       // construct a CFileItemList to pass 'em on to the list
-      CGUIListItemPtr items(new CFileItemList());
+      std::shared_ptr<CGUIListItem> items(new CFileItemList());
       for (unsigned int i = vecItems.size() - tail; i < vecItems.size(); i++)
         static_cast<CFileItemList*>(items.get())->Add(vecItems[i]->item);
 
