@@ -22,6 +22,7 @@
 #include "commons/Exception.h"
 
 #include <map>
+#include <memory>
 #include <utility>
 #include <vector>
 
@@ -110,7 +111,7 @@ namespace XBMCAddon
       static inline AddonClass::Ref<ListItem> fromString(const String& str)
       {
         AddonClass::Ref<ListItem> ret = AddonClass::Ref<ListItem>(new ListItem());
-        ret->item.reset(new CFileItem(str));
+        ret->item = std::make_shared<CFileItem>(str);
         return ret;
       }
 #endif
@@ -710,6 +711,7 @@ namespace XBMCAddon
       /// | set           | string (Batman Collection) - name of the collection
       /// | setoverview   | string (All Batman movies) - overview of the collection
       /// | tag           | string (cult) or list of strings (["cult", "documentary", "best movies"]) - movie tag
+      /// | videoversion  | string (Video version)
       /// | imdbnumber    | string (tt0110293) - IMDb code
       /// | code          | string (101) - Production code
       /// | aired         | string (2008-12-07)
@@ -780,6 +782,7 @@ namespace XBMCAddon
       /// Added labels **dbid** (music), **setoverview**, **tag**, **sortepisode**, **sortseason**, **episodeguide**, **showlink**.
       /// Extended labels **genre**, **country**, **director**, **studio**, **writer**, **tag**, **credits** to also use a list of strings.
       /// @python_v20 Partially deprecated. Use explicit setters in **InfoTagVideo**, **InfoTagMusic**, **InfoTagPicture** or **InfoTagGame** instead.
+      /// @python_v21 Added videoversion infolabel for movies
       ///
       /// **Example:**
       /// ~~~~~~~~~~~~~{.py}
