@@ -62,7 +62,7 @@ bool Xcddb::openSocket()
   hints.ai_family   = AF_UNSPEC;
   hints.ai_socktype = SOCK_STREAM;
   hints.ai_protocol = IPPROTO_TCP;
-  sprintf(service, "%d", CDDB_PORT);
+  snprintf(service, sizeof(service), "%d", CDDB_PORT);
 
   res = getaddrinfo(m_cddb_ip_address.c_str(), service, &hints, &result);
   if(res)
@@ -126,11 +126,10 @@ bool Xcddb::Send( const void *buffer, int bytes )
 {
   std::unique_ptr<char[]> tmp_buffer(new char[bytes + 10]);
   strcpy(tmp_buffer.get(), (const char*)buffer);
-  tmp_buffer.get()[bytes] = '.';
-  tmp_buffer.get()[bytes + 1] = 0x0d;
-  tmp_buffer.get()[bytes + 2] = 0x0a;
-  tmp_buffer.get()[bytes + 3] = 0x00;
-  int iErr = send((SOCKET)m_cddb_socket, (const char*)tmp_buffer.get(), bytes + 3, 0);
+  tmp_buffer.get()[bytes] = 0x0d;
+  tmp_buffer.get()[bytes + 1] = 0x0a;
+  tmp_buffer.get()[bytes + 2] = 0x00;
+  int iErr = send((SOCKET)m_cddb_socket, (const char*)tmp_buffer.get(), bytes + 2, 0);
   if (iErr <= 0)
   {
     return false;
@@ -711,7 +710,7 @@ void Xcddb::addInexactListLine(int line_cnt, const char *line, int len)
       break;
     }
   }
-  sprintf(cddb_command, "cddb read %s %s", genre, discid);
+  snprintf(cddb_command, sizeof(cddb_command), "cddb read %s %s", genre, discid);
 
   m_mapInexact_cddb_command_list[line_cnt] = cddb_command;
 
@@ -725,7 +724,7 @@ void Xcddb::addInexactListLine(int line_cnt, const char *line, int len)
   g_charsetConverter.unknownToUTF8(title, strTitle);
   m_mapInexact_title_list[line_cnt] = strTitle;
   // char log_string[1024];
-  // sprintf(log_string,"%u: %s - %s",line_cnt,artist,title);
+  // snprintf(log_string, sizeof(log_string), "%u: %s - %s",line_cnt,artist,title);
   // //writeLog(log_string);
   // //writeLog("addInexactListLine End");
 }
@@ -870,7 +869,7 @@ bool Xcddb::queryCDinfo(CCdInfo* pInfo)
   std::string lcAppName = CCompileInfo::GetAppName();
   StringUtils::ToLower(lcAppName);
   if (version.find(' ') != std::string::npos)
-    version = version.substr(0, version.find(' '));
+    version.resize(version.find(' '));
   std::string strGreeting = "cddb hello " + lcAppName + " kodi.tv " + CCompileInfo::GetAppName() + " " + version;
   if ( ! Send(strGreeting.c_str()) )
   {
@@ -924,23 +923,23 @@ bool Xcddb::queryCDinfo(CCdInfo* pInfo)
   strcat(query_buffer, "cddb query");
   {
     char tmp_buffer[256];
-    sprintf(tmp_buffer, " %08x", discid);
+    snprintf(tmp_buffer, sizeof(tmp_buffer), " %08x", discid);
     strcat(query_buffer, tmp_buffer);
   }
   {
     char tmp_buffer[256];
-    sprintf(tmp_buffer, " %i", real_track_count);
+    snprintf(tmp_buffer, sizeof(tmp_buffer), " %i", real_track_count);
     strcat(query_buffer, tmp_buffer);
   }
   for (int i = 0;i < lead_out;i++)
   {
     char tmp_buffer[256];
-    sprintf(tmp_buffer, " %lu", frames[i]);
+    snprintf(tmp_buffer, sizeof(tmp_buffer), " %lu", frames[i]);
     strcat(query_buffer, tmp_buffer);
   }
   {
     char tmp_buffer[256];
-    sprintf(tmp_buffer, " %lu", complete_length);
+    snprintf(tmp_buffer, sizeof(tmp_buffer), " %lu", complete_length);
     strcat(query_buffer, tmp_buffer);
   }
 
