@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2014-2018 Team Kodi
+ *  Copyright (C) 2014-2024 Team Kodi
  *  This file is part of Kodi - https://kodi.tv
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
@@ -21,25 +21,30 @@
 #include <string>
 #include <vector>
 
-#define JOYSTICK_PORT_UNKNOWN (-1)
-
 namespace KODI
 {
 namespace JOYSTICK
 {
 class CDeadzoneFilter;
-class CKeymapHandling;
 class CRumbleGenerator;
 class IButtonMap;
 class IDriverHandler;
 class IInputHandler;
 } // namespace JOYSTICK
+
+namespace KEYMAP
+{
+class CKeymapHandling;
+} // namespace KEYMAP
 } // namespace KODI
 
 namespace PERIPHERALS
 {
 class CPeripherals;
 
+/*!
+ * \ingroup peripherals
+ */
 class CPeripheralJoystick : public CPeripheral, //! @todo extend CPeripheralHID
                             public KODI::JOYSTICK::IDriverReceiver
 {
@@ -58,8 +63,9 @@ public:
                                      bool bPromiscuous) override;
   void UnregisterJoystickDriverHandler(KODI::JOYSTICK::IDriverHandler* handler) override;
   KODI::JOYSTICK::IDriverReceiver* GetDriverReceiver() override { return this; }
-  IKeymap* GetKeymap(const std::string& controllerId) override;
-  CDateTime LastActive() override { return m_lastActive; }
+  KODI::KEYMAP::IKeymap* GetKeymap(const std::string& controllerId) override;
+  CDateTime LastActive() const override { return m_lastActive; }
+  void SetLastActive(const CDateTime& lastActive) override;
   KODI::GAME::ControllerPtr ControllerProfile() const override;
   void SetControllerProfile(const KODI::GAME::ControllerPtr& controller) override;
 
@@ -125,18 +131,18 @@ protected:
 
   // State parameters
   std::string m_strProvider;
-  int m_requestedPort;
-  unsigned int m_buttonCount;
-  unsigned int m_hatCount;
-  unsigned int m_axisCount;
-  unsigned int m_motorCount;
-  bool m_supportsPowerOff;
+  int m_requestedPort{JOYSTICK_NO_PORT_REQUESTED};
+  unsigned int m_buttonCount = 0;
+  unsigned int m_hatCount = 0;
+  unsigned int m_axisCount = 0;
+  unsigned int m_motorCount = 0;
+  bool m_supportsPowerOff = false;
   CDateTime m_lastActive;
   std::queue<std::string> m_controllersToInstall;
   std::vector<std::future<void>> m_installTasks;
 
   // Input clients
-  std::unique_ptr<KODI::JOYSTICK::CKeymapHandling> m_appInput;
+  std::unique_ptr<KODI::KEYMAP::CKeymapHandling> m_appInput;
   std::unique_ptr<KODI::JOYSTICK::CRumbleGenerator> m_rumbleGenerator;
   std::unique_ptr<KODI::JOYSTICK::IInputHandler> m_joystickMonitor;
   std::unique_ptr<KODI::JOYSTICK::IButtonMap> m_buttonMap;
