@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2017-2018 Team Kodi
+ *  Copyright (C) 2017-2024 Team Kodi
  *  This file is part of Kodi - https://kodi.tv
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
@@ -54,8 +54,6 @@ bool CPeripheralMouse::InitialiseFeature(const PeripheralFeature feature)
 void CPeripheralMouse::RegisterMouseDriverHandler(MOUSE::IMouseDriverHandler* handler,
                                                   bool bPromiscuous)
 {
-  using namespace KEYBOARD;
-
   std::unique_lock<CCriticalSection> lock(m_mutex);
 
   MouseHandle handle{handler, bPromiscuous};
@@ -74,6 +72,15 @@ void CPeripheralMouse::UnregisterMouseDriverHandler(MOUSE::IMouseDriverHandler*
     m_mouseHandlers.erase(it);
 }
 
+void CPeripheralMouse::SetLastActive(const CDateTime& lastActive)
+{
+  // Update state
+  m_lastActive = lastActive;
+
+  // Update ancestor
+  CPeripheral::SetLastActive(lastActive);
+}
+
 GAME::ControllerPtr CPeripheralMouse::ControllerProfile() const
 {
   if (m_controllerProfile)
@@ -106,18 +113,20 @@ bool CPeripheralMouse::OnPosition(int x, int y)
     }
   }
 
+  // Update state
   if (bHandled)
-    m_lastActive = CDateTime::GetCurrentDateTime();
+    SetLastActive(CDateTime::GetCurrentDateTime());
 
   return bHandled;
 }
 
 bool CPeripheralMouse::OnButtonPress(MOUSE::BUTTON_ID button)
 {
-  m_lastActive = CDateTime::GetCurrentDateTime();
-
   std::unique_lock<CCriticalSection> lock(m_mutex);
 
+  // Update state
+  SetLastActive(CDateTime::GetCurrentDateTime());
+
   bool bHandled = false;
 
   // Process promiscuous handlers
