@@ -8,13 +8,21 @@
 
 #pragma once
 
-#include "input/IRTranslator.h"
 #include "threads/CriticalSection.h"
 #include "threads/Thread.h"
 
 #include <chrono>
+#include <memory>
 #include <string>
 
+namespace KODI
+{
+namespace KEYMAP
+{
+class CIRTranslator;
+} // namespace KEYMAP
+} // namespace KODI
+
 class CLirc : CThread
 {
 public:
@@ -30,6 +38,6 @@ protected:
   int m_fd = -1;
   std::chrono::time_point<std::chrono::steady_clock> m_firstClickTime;
   CCriticalSection m_critSection;
-  CIRTranslator m_irTranslator;
+  std::unique_ptr<KODI::KEYMAP::CIRTranslator> m_irTranslator;
   int m_profileId;
 };
