@@ -27,16 +27,38 @@
 #include "utils/URIUtils.h"
 #include "utils/log.h"
 
+#include <cstring>
 #include <inttypes.h>
 #include <mutex>
+#include <regex>
 
 #include <libsmbclient.h>
 
 using namespace XFILE;
 
-void xb_smbc_log(const char* msg)
+void xb_smbc_log(void* private_ptr, int level, const char* msg)
 {
-  CLog::Log(LOGINFO, "{}{}", "smb: ", msg);
+  const int logLevel = [level]()
+  {
+    switch (level)
+    {
+      case 0:
+        return LOGWARNING;
+      case 1:
+        return LOGINFO;
+      default:
+        return LOGDEBUG;
+    }
+  }();
+
+  if (std::strchr(msg, '@'))
+  {
+    // redact User/pass in URLs
+    static const std::regex redact("(\\w+://)\\S+:\\S+@");
+    CLog::Log(logLevel, "smb: {}", std::regex_replace(msg, redact, "$1USERNAME:PASSWORD@"));
+  }
+  else
+    CLog::Log(logLevel, "smb: {}", msg);
 }
 
 void xb_smbc_auth(const char *srv, const char *shr, char *wg, int wglen,
@@ -175,6 +197,7 @@ void CSMB::Init()
 
 #ifdef DEPRECATED_SMBC_INTERFACE
     smbc_setDebug(m_context, CServiceBroker::GetLogging().CanLogComponent(LOGSAMBA) ? 10 : 0);
+    smbc_setLogCallback(m_context, this, xb_smbc_log);
     smbc_setFunctionAuthData(m_context, xb_smbc_auth);
     orig_cache = smbc_getFunctionGetCachedServer(m_context);
     smbc_setFunctionGetCachedServer(m_context, xb_smbc_cache);
@@ -391,7 +414,7 @@ bool CSMBFile::Open(const CURL& url)
   if (m_fd == -1)
   {
     // write error to logfile
-    CLog::Log(LOGINFO, "SMBFile->Open: Unable to open file : '{}'\nunix_err:'{:x}' error : '{}'",
+    CLog::Log(LOGERROR, "SMBFile->Open: Unable to open file : '{}'\nunix_err:'{:x}' error : '{}'",
               CURL::GetRedacted(strFileName), errno, strerror(errno));
     return false;
   }
@@ -719,3 +742,21 @@ int CSMBFile::IoControl(EIoControl request, void* param)
   return -1;
 }
 
+int CSMBFile::GetChunkSize()
+{
+  const auto settings = CServiceBroker::GetSettingsComponent()->GetSettings();
+
+  if (!settings)
+    return (64 * 1024);
+
+  int chunkSize = settings->GetInt(CSettings::SETTING_SMB_CHUNKSIZE) * 1024;
+
+  if (settings->GetInt(CSettings::SETTING_SMB_MINPROTOCOL) == 1 &&
+      settings->GetInt(CSettings::SETTING_SMB_MAXPROTOCOL) == 1)
+  {
+    if (chunkSize > 64 * 1024)
+      chunkSize = 64 * 1024;
+  }
+
+  return chunkSize;
+}
