@@ -20,9 +20,11 @@
 #include "pvr/addons/PVRClients.h"
 #include "pvr/channels/PVRChannel.h"
 #include "pvr/channels/PVRChannelGroup.h"
-#include "pvr/channels/PVRChannelGroupInternal.h"
+#include "pvr/channels/PVRChannelGroupAllChannels.h"
 #include "pvr/channels/PVRChannelGroups.h"
 #include "pvr/channels/PVRChannelGroupsContainer.h"
+#include "pvr/channels/PVRChannelsPath.h"
+#include "pvr/epg/EpgContainer.h"
 #include "pvr/epg/EpgInfoTag.h"
 #include "pvr/guilib/PVRGUIActionsChannels.h"
 #include "pvr/guilib/PVRGUIActionsPlayback.h"
@@ -198,7 +200,7 @@ CPVRManager::CPVRManager()
     m_addons(new CPVRClients),
     m_guiInfo(new CPVRGUIInfo),
     m_components(new CPVRComponentRegistration),
-    m_epgContainer(m_events),
+    m_epgContainer(new CPVREpgContainer(m_events)),
     m_pendingUpdates(new CPVRManagerJobQueue),
     m_database(new CPVRDatabase),
     m_parentalTimer(new CStopWatch),
@@ -291,13 +293,18 @@ std::shared_ptr<CPVRClient> CPVRManager::GetClient(const CFileItem& item) const
     iClientID = item.GetEPGInfoTag()->ClientID();
   else if (URIUtils::IsPVRChannel(item.GetPath()))
   {
-    const std::shared_ptr<CPVRChannel> channel = m_channelGroups->GetByPath(item.GetPath());
+    const std::shared_ptr<const CPVRChannel> channel = m_channelGroups->GetByPath(item.GetPath());
     if (channel)
       iClientID = channel->ClientID();
   }
+  else if (URIUtils::IsPVRChannelGroup(item.GetPath()))
+  {
+    const CPVRChannelsPath path(item.GetPath());
+    iClientID = path.GetGroupClientID();
+  }
   else if (URIUtils::IsPVRRecording(item.GetPath()))
   {
-    const std::shared_ptr<CPVRRecording> recording = m_recordings->GetByPath(item.GetPath());
+    const std::shared_ptr<const CPVRRecording> recording = m_recordings->GetByPath(item.GetPath());
     if (recording)
       iClientID = recording->ClientID();
   }
@@ -318,7 +325,7 @@ std::shared_ptr<CPVRPlaybackState> CPVRManager::PlaybackState() const
 CPVREpgContainer& CPVRManager::EpgContainer()
 {
   // note: m_epgContainer is const (only set/reset in ctor/dtor). no need for a lock here.
-  return m_epgContainer;
+  return *m_epgContainer;
 }
 
 void CPVRManager::Clear()
@@ -335,8 +342,6 @@ void CPVRManager::Clear()
   m_channelGroups.reset();
   m_parentalTimer.reset();
   m_database.reset();
-
-  m_bEpgsCreated = false;
 }
 
 void CPVRManager::ResetProperties()
@@ -344,13 +349,13 @@ void CPVRManager::ResetProperties()
   std::unique_lock<CCriticalSection> lock(m_critSection);
   Clear();
 
-  m_database.reset(new CPVRDatabase);
-  m_providers.reset(new CPVRProviders);
-  m_channelGroups.reset(new CPVRChannelGroupsContainer);
-  m_recordings.reset(new CPVRRecordings);
-  m_timers.reset(new CPVRTimers);
-  m_guiInfo.reset(new CPVRGUIInfo);
-  m_parentalTimer.reset(new CStopWatch);
+  m_database = std::make_shared<CPVRDatabase>();
+  m_providers = std::make_shared<CPVRProviders>();
+  m_channelGroups = std::make_shared<CPVRChannelGroupsContainer>();
+  m_recordings = std::make_shared<CPVRRecordings>();
+  m_timers = std::make_shared<CPVRTimers>();
+  m_guiInfo = std::make_unique<CPVRGUIInfo>();
+  m_parentalTimer = std::make_unique<CStopWatch>();
   m_knownClients.clear();
 }
 
@@ -405,7 +410,7 @@ void CPVRManager::Stop(bool bRestart /* = false */)
   }
 
   CLog::Log(LOGINFO, "PVR Manager: Stopping");
-  SetState(ManagerState::STATE_SSTOPPING);
+  SetState(ManagerState::STATE_STOPPING);
 
   StopThread();
 }
@@ -454,7 +459,7 @@ void CPVRManager::SetState(CPVRManager::ManagerState state)
     case ManagerState::STATE_STARTING:
       event = PVREvent::ManagerStarting;
       break;
-    case ManagerState::STATE_SSTOPPING:
+    case ManagerState::STATE_STOPPING:
       event = PVREvent::ManagerStopped;
       break;
     case ManagerState::STATE_INTERRUPTED:
@@ -504,13 +509,13 @@ void CPVRManager::Process()
   }
 
   // Load EPGs from database.
-  m_epgContainer.Load();
+  m_epgContainer->Load();
 
   // Reinit playbackstate
   m_playbackState->ReInit();
 
   m_guiInfo->Start();
-  m_epgContainer.Start();
+  m_epgContainer->Start();
   m_timers->Start();
   m_pendingUpdates->Start();
 
@@ -578,7 +583,7 @@ void CPVRManager::Process()
   m_addons->Stop();
   m_pendingUpdates->Stop();
   m_timers->Stop();
-  m_epgContainer.Stop();
+  m_epgContainer->Stop();
   m_guiInfo->Stop();
 
   SetState(ManagerState::STATE_INTERRUPTED);
@@ -628,16 +633,14 @@ void CPVRManager::OnSleep()
 
   SetWakeupCommand();
 
-  m_epgContainer.OnSystemSleep();
-
+  m_epgContainer->OnSystemSleep();
   m_addons->OnSystemSleep();
 }
 
 void CPVRManager::OnWake()
 {
   m_addons->OnSystemWake();
-
-  m_epgContainer.OnSystemWake();
+  m_epgContainer->OnSystemWake();
 
   PublishEvent(PVREvent::SystemWake);
 
@@ -652,7 +655,6 @@ void CPVRManager::OnWake()
   TriggerProvidersUpdate();
   TriggerChannelsUpdate();
   TriggerRecordingsUpdate();
-  TriggerEpgsCreate();
   TriggerTimersUpdate();
 }
 
@@ -692,8 +694,8 @@ bool CPVRManager::UpdateComponents(ManagerState stateToCheck,
     // skip not (yet) connected clients
     if (entry.second->IgnoreClient())
     {
-      CLog::LogFC(LOGDEBUG, LOGPVR, "Skipping not (yet) connected PVR client '{}'",
-                  entry.second->ID());
+      CLog::LogFC(LOGDEBUG, LOGPVR, "Skipping not (yet) connected PVR client {}",
+                  entry.second->GetID());
       continue;
     }
 
@@ -702,8 +704,8 @@ bool CPVRManager::UpdateComponents(ManagerState stateToCheck,
       m_knownClients.emplace_back(entry.second);
       newClients.emplace_back(entry.second);
 
-      CLog::LogFC(LOGDEBUG, LOGPVR, "Adding new PVR client '{}' to list of known clients",
-                  entry.second->ID());
+      CLog::LogFC(LOGDEBUG, LOGPVR, "Adding new PVR client {} to list of known clients",
+                  entry.second->GetID());
     }
   }
 
@@ -767,7 +769,7 @@ void CPVRManager::UnloadComponents()
   m_timers->Unload();
   m_channelGroups->Unload();
   m_providers->Unload();
-  m_epgContainer.Unload();
+  m_epgContainer->Unload();
 }
 
 bool CPVRManager::IsKnownClient(int clientID) const
@@ -791,7 +793,7 @@ void CPVRManager::RestartParentalTimer()
     m_parentalTimer->StartZero();
 }
 
-bool CPVRManager::IsParentalLocked(const std::shared_ptr<CPVREpgInfoTag>& epgTag) const
+bool CPVRManager::IsParentalLocked(const std::shared_ptr<const CPVREpgInfoTag>& epgTag) const
 {
   return m_channelGroups && epgTag &&
          IsCurrentlyParentalLocked(
@@ -799,12 +801,12 @@ bool CPVRManager::IsParentalLocked(const std::shared_ptr<CPVREpgInfoTag>& epgTag
              epgTag->IsParentalLocked());
 }
 
-bool CPVRManager::IsParentalLocked(const std::shared_ptr<CPVRChannel>& channel) const
+bool CPVRManager::IsParentalLocked(const std::shared_ptr<const CPVRChannel>& channel) const
 {
   return channel && IsCurrentlyParentalLocked(channel, channel->IsLocked());
 }
 
-bool CPVRManager::IsCurrentlyParentalLocked(const std::shared_ptr<CPVRChannel>& channel,
+bool CPVRManager::IsCurrentlyParentalLocked(const std::shared_ptr<const CPVRChannel>& channel,
                                             bool bGenerallyLocked) const
 {
   bool bReturn = false;
@@ -812,7 +814,7 @@ bool CPVRManager::IsCurrentlyParentalLocked(const std::shared_ptr<CPVRChannel>&
   if (!channel || !bGenerallyLocked)
     return bReturn;
 
-  const std::shared_ptr<CPVRChannel> currentChannel = m_playbackState->GetPlayingChannel();
+  const std::shared_ptr<const CPVRChannel> currentChannel = m_playbackState->GetPlayingChannel();
 
   if ( // if channel in question is currently playing it must be currently unlocked.
       (!currentChannel || channel != currentChannel) &&
@@ -832,7 +834,7 @@ void CPVRManager::OnPlaybackStarted(const CFileItem& item)
 {
   m_playbackState->OnPlaybackStarted(item);
   Get<PVR::GUI::Channels>().OnPlaybackStarted(item);
-  m_epgContainer.OnPlaybackStarted();
+  m_epgContainer->OnPlaybackStarted();
 }
 
 void CPVRManager::OnPlaybackStopped(const CFileItem& item)
@@ -842,13 +844,17 @@ void CPVRManager::OnPlaybackStopped(const CFileItem& item)
     PublishEvent(PVREvent::ChannelPlaybackStopped);
 
   Get<PVR::GUI::Channels>().OnPlaybackStopped(item);
-  m_epgContainer.OnPlaybackStopped();
+  m_epgContainer->OnPlaybackStopped();
 }
 
 void CPVRManager::OnPlaybackEnded(const CFileItem& item)
 {
   // Playback ended, but not due to user interaction
-  OnPlaybackStopped(item);
+  if (m_playbackState->OnPlaybackEnded(item))
+    PublishEvent(PVREvent::ChannelPlaybackStopped);
+
+  Get<PVR::GUI::Channels>().OnPlaybackStopped(item);
+  m_epgContainer->OnPlaybackStopped();
 }
 
 void CPVRManager::LocalizationChanged()
@@ -856,24 +862,13 @@ void CPVRManager::LocalizationChanged()
   std::unique_lock<CCriticalSection> lock(m_critSection);
   if (IsStarted())
   {
-    static_cast<CPVRChannelGroupInternal*>(m_channelGroups->GetGroupAllRadio().get())
+    static_cast<CPVRChannelGroupAllChannels*>(m_channelGroups->GetGroupAllRadio().get())
         ->CheckGroupName();
-    static_cast<CPVRChannelGroupInternal*>(m_channelGroups->GetGroupAllTV().get())
+    static_cast<CPVRChannelGroupAllChannels*>(m_channelGroups->GetGroupAllTV().get())
         ->CheckGroupName();
   }
 }
 
-bool CPVRManager::EpgsCreated() const
-{
-  std::unique_lock<CCriticalSection> lock(m_critSection);
-  return m_bEpgsCreated;
-}
-
-void CPVRManager::TriggerEpgsCreate()
-{
-  m_pendingUpdates->Append("pvr-create-epgs", [this]() { return CreateChannelEpgs(); });
-}
-
 void CPVRManager::TriggerRecordingsSizeInProgressUpdate()
 {
   m_pendingUpdates->Append("pvr-update-recordings-size",
@@ -1015,15 +1010,3 @@ void CPVRManager::ConnectionStateChange(CPVRClient* client,
     return true;
   });
 }
-
-bool CPVRManager::CreateChannelEpgs()
-{
-  if (EpgsCreated())
-    return true;
-
-  bool bEpgsCreated = m_channelGroups->CreateChannelEpgs();
-
-  std::unique_lock<CCriticalSection> lock(m_critSection);
-  m_bEpgsCreated = bEpgsCreated;
-  return m_bEpgsCreated;
-}
