@@ -136,7 +136,7 @@ bool CPVRChannel::QueueDelete()
   if (!database)
     return bReturn;
 
-  const std::shared_ptr<CPVREpg> epg = GetEPG();
+  const std::shared_ptr<const CPVREpg> epg = GetEPG();
   if (epg)
     ResetEPG();
 
@@ -164,6 +164,9 @@ bool CPVRChannel::CreateEPG()
         m_iEpgId, m_strEPGScraper, std::make_shared<CPVREpgChannelData>(*this));
     if (m_epg)
     {
+      CLog::LogFC(LOGDEBUG, LOGPVR, "Created EPG for {} channel '{}'", IsRadio() ? "radio" : "TV",
+                  m_strChannelName);
+
       if (m_epg->EpgID() != m_iEpgId)
       {
         m_iEpgId = m_epg->EpgID();
@@ -202,7 +205,7 @@ void CPVRChannel::ResetEPG()
     epgToUnsubscribe->Events().Unsubscribe(this);
 }
 
-bool CPVRChannel::UpdateFromClient(const std::shared_ptr<CPVRChannel>& channel)
+bool CPVRChannel::UpdateFromClient(const std::shared_ptr<const CPVRChannel>& channel)
 {
   std::unique_lock<CCriticalSection> lock(m_critSection);
 
@@ -259,7 +262,7 @@ bool CPVRChannel::SetChannelID(int iChannelId)
   {
     m_iChannelId = iChannelId;
 
-    const std::shared_ptr<CPVREpg> epg = GetEPG();
+    const std::shared_ptr<const CPVREpg> epg = GetEPG();
     if (epg)
       epg->GetChannelData()->SetChannelId(m_iChannelId);
 
@@ -274,7 +277,7 @@ bool CPVRChannel::SetHidden(bool bIsHidden, bool bIsUserSetHidden /*= false*/)
 {
   std::unique_lock<CCriticalSection> lock(m_critSection);
 
-  if (m_bIsHidden != bIsHidden)
+  if (m_bIsHidden != bIsHidden || m_bIsUserSetHidden != bIsUserSetHidden)
   {
     m_bIsHidden = bIsHidden;
     m_bIsUserSetHidden = bIsUserSetHidden;
@@ -297,7 +300,7 @@ bool CPVRChannel::SetLocked(bool bIsLocked)
   {
     m_bIsLocked = bIsLocked;
 
-    const std::shared_ptr<CPVREpg> epg = GetEPG();
+    const std::shared_ptr<const CPVREpg> epg = GetEPG();
     if (epg)
       epg->GetChannelData()->SetLocked(m_bIsLocked);
 
@@ -354,7 +357,7 @@ bool CPVRChannel::SetIconPath(const std::string& strIconPath, bool bIsUserSetIco
 
   m_iconPath.SetClientImage(strIconPath);
 
-  const std::shared_ptr<CPVREpg> epg = GetEPG();
+  const std::shared_ptr<const CPVREpg> epg = GetEPG();
   if (epg)
     epg->GetChannelData()->SetChannelIconPath(strIconPath);
 
@@ -372,20 +375,12 @@ bool CPVRChannel::SetChannelName(const std::string& strChannelName, bool bIsUser
                                   m_clientChannelNumber.FormattedChannelNumber());
 
   std::unique_lock<CCriticalSection> lock(m_critSection);
-  if (m_strChannelName != strName)
+  if (m_strChannelName != strName || m_bIsUserSetName != bIsUserSetName)
   {
     m_strChannelName = strName;
     m_bIsUserSetName = bIsUserSetName;
 
-    /* if the user changes the name manually to an empty string we reset the
-       flag and use the name from the client instead */
-    if (bIsUserSetName && strChannelName.empty())
-    {
-      m_bIsUserSetName = false;
-      m_strChannelName = ClientChannelName();
-    }
-
-    const std::shared_ptr<CPVREpg> epg = GetEPG();
+    const std::shared_ptr<const CPVREpg> epg = GetEPG();
     if (epg)
       epg->GetChannelData()->SetChannelName(m_strChannelName);
 
@@ -396,16 +391,17 @@ bool CPVRChannel::SetChannelName(const std::string& strChannelName, bool bIsUser
   return false;
 }
 
-bool CPVRChannel::SetLastWatched(time_t iLastWatched)
+bool CPVRChannel::SetLastWatched(time_t lastWatched, int groupId)
 {
   {
     std::unique_lock<CCriticalSection> lock(m_critSection);
-    m_iLastWatched = iLastWatched;
+    m_iLastWatched = lastWatched;
+    m_lastWatchedGroupId = groupId;
   }
 
   const std::shared_ptr<CPVRDatabase> database = CServiceBroker::GetPVRManager().GetTVDatabase();
   if (database)
-    return database->UpdateLastWatched(*this);
+    return database->UpdateLastWatched(*this, groupId);
 
   return false;
 }
@@ -539,7 +535,7 @@ bool CPVRChannel::SetClientProviderUid(int iClientProviderUid)
 
 std::vector<std::shared_ptr<CPVREpgInfoTag>> CPVRChannel::GetEpgTags() const
 {
-  const std::shared_ptr<CPVREpg> epg = GetEPG();
+  const std::shared_ptr<const CPVREpg> epg = GetEPG();
   if (!epg)
   {
     CLog::LogFC(LOGDEBUG, LOGPVR, "Cannot get EPG for channel '{}'", m_strChannelName);
@@ -555,7 +551,7 @@ std::vector<std::shared_ptr<CPVREpgInfoTag>> CPVRChannel::GetEPGTimeline(
     const CDateTime& minEventEnd,
     const CDateTime& maxEventStart) const
 {
-  const std::shared_ptr<CPVREpg> epg = GetEPG();
+  const std::shared_ptr<const CPVREpg> epg = GetEPG();
   if (epg)
   {
     return epg->GetTimeline(timelineStart, timelineEnd, minEventEnd, maxEventStart);
@@ -571,7 +567,7 @@ std::vector<std::shared_ptr<CPVREpgInfoTag>> CPVRChannel::GetEPGTimeline(
 std::shared_ptr<CPVREpgInfoTag> CPVRChannel::CreateEPGGapTag(const CDateTime& start,
                                                              const CDateTime& end) const
 {
-  const std::shared_ptr<CPVREpg> epg = GetEPG();
+  const std::shared_ptr<const CPVREpg> epg = GetEPG();
   if (epg)
     return std::make_shared<CPVREpgInfoTag>(epg->GetChannelData(), epg->EpgID(), start, end, true);
   else
@@ -582,7 +578,7 @@ std::shared_ptr<CPVREpgInfoTag> CPVRChannel::CreateEPGGapTag(const CDateTime& st
 std::shared_ptr<CPVREpgInfoTag> CPVRChannel::GetEPGNow() const
 {
   std::shared_ptr<CPVREpgInfoTag> tag;
-  const std::shared_ptr<CPVREpg> epg = GetEPG();
+  const std::shared_ptr<const CPVREpg> epg = GetEPG();
   if (epg)
     tag = epg->GetTagNow();
 
@@ -592,7 +588,7 @@ std::shared_ptr<CPVREpgInfoTag> CPVRChannel::GetEPGNow() const
 std::shared_ptr<CPVREpgInfoTag> CPVRChannel::GetEPGNext() const
 {
   std::shared_ptr<CPVREpgInfoTag> tag;
-  const std::shared_ptr<CPVREpg> epg = GetEPG();
+  const std::shared_ptr<const CPVREpg> epg = GetEPG();
   if (epg)
     tag = epg->GetTagNext();
 
@@ -602,7 +598,7 @@ std::shared_ptr<CPVREpgInfoTag> CPVRChannel::GetEPGNext() const
 std::shared_ptr<CPVREpgInfoTag> CPVRChannel::GetEPGPrevious() const
 {
   std::shared_ptr<CPVREpgInfoTag> tag;
-  const std::shared_ptr<CPVREpg> epg = GetEPG();
+  const std::shared_ptr<const CPVREpg> epg = GetEPG();
   if (epg)
     tag = epg->GetTagPrevious();
 
@@ -723,6 +719,12 @@ bool CPVRChannel::IsUserSetHidden() const
   return m_bIsUserSetHidden;
 }
 
+int CPVRChannel::LastWatchedGroupId() const
+{
+  std::unique_lock<CCriticalSection> lock(m_critSection);
+  return m_lastWatchedGroupId;
+}
+
 std::string CPVRChannel::ChannelName() const
 {
   std::unique_lock<CCriticalSection> lock(m_critSection);
@@ -814,7 +816,8 @@ std::string CPVRChannel::EPGScraper() const
 
 bool CPVRChannel::CanRecord() const
 {
-  const std::shared_ptr<CPVRClient> client = CServiceBroker::GetPVRManager().GetClient(m_iClientId);
+  const std::shared_ptr<const CPVRClient> client =
+      CServiceBroker::GetPVRManager().GetClient(m_iClientId);
   return client && client->GetClientCapabilities().SupportsRecordings() &&
          client->GetClientCapabilities().SupportsTimers();
 }
