@@ -15,6 +15,7 @@
 
 #include <map>
 #include <memory>
+#include <optional>
 #include <string>
 #include <utility>
 #include <vector>
@@ -23,9 +24,14 @@ struct PVR_CHANNEL_GROUP;
 
 namespace PVR
 {
-#define PVR_GROUP_TYPE_DEFAULT 0
-#define PVR_GROUP_TYPE_INTERNAL 1
-#define PVR_GROUP_TYPE_USER_DEFINED 2
+static constexpr int PVR_GROUP_TYPE_REMOTE = 0;
+static constexpr int PVR_GROUP_TYPE_ALL_CHANNELS = 1;
+static constexpr int PVR_GROUP_TYPE_LOCAL = 2;
+
+static constexpr int PVR_GROUP_CLIENT_ID_UNKNOWN = -2;
+static constexpr int PVR_GROUP_CLIENT_ID_LOCAL = -1;
+
+static constexpr int PVR_GROUP_ID_UNNKOWN{-1};
 
 enum class PVREvent;
 
@@ -45,7 +51,8 @@ using GroupMemberPair =
 
 class CPVRChannelGroup : public IChannelGroupSettingsCallback
 {
-  friend class CPVRDatabase;
+  friend class CPVRChannelGroups; // for GroupType()
+  friend class CPVRDatabase; // for GroupType()
 
 public:
   static const int INVALID_GROUP_ID = -1;
@@ -56,15 +63,7 @@ public:
    * @param allChannelsGroup The channel group containing all TV or radio channels.
    */
   CPVRChannelGroup(const CPVRChannelsPath& path,
-                   const std::shared_ptr<CPVRChannelGroup>& allChannelsGroup);
-
-  /*!
-   * @brief Create a new channel group instance from a channel group provided by an add-on.
-   * @param group The channel group provided by the add-on.
-   * @param allChannelsGroup The channel group containing all TV or radio channels.
-   */
-  CPVRChannelGroup(const PVR_CHANNEL_GROUP& group,
-                   const std::shared_ptr<CPVRChannelGroup>& allChannelsGroup);
+                   const std::shared_ptr<const CPVRChannelGroup>& allChannelsGroup);
 
   ~CPVRChannelGroup() override;
 
@@ -88,14 +87,13 @@ public:
    * @param clients The PVR clients data should be loaded for. Leave empty for all clients.
    * @return True when loaded successfully, false otherwise.
    */
-  virtual bool LoadFromDatabase(
-      const std::map<std::pair<int, int>, std::shared_ptr<CPVRChannel>>& channels,
-      const std::vector<std::shared_ptr<CPVRClient>>& clients);
+  bool LoadFromDatabase(const std::map<std::pair<int, int>, std::shared_ptr<CPVRChannel>>& channels,
+                        const std::vector<std::shared_ptr<CPVRClient>>& clients);
 
   /*!
    * @brief Clear all data.
    */
-  virtual void Unload();
+  void Unload();
 
   /*!
    * @return The amount of group members
@@ -107,7 +105,19 @@ public:
    * @param clients The clients to fetch data from. Leave empty to fetch data from all created clients.
    * @return True on success, false otherwise.
    */
-  virtual bool UpdateFromClients(const std::vector<std::shared_ptr<CPVRClient>>& clients);
+  virtual bool UpdateFromClients(const std::vector<std::shared_ptr<CPVRClient>>& clients) = 0;
+
+  /*!
+   * @brief Get the identifier of the client that serves this channel group.
+   * @return The identifier or PVR_GROUP_CLIENT_ID_LOCAL for local groups.
+   */
+  int GetClientID() const;
+
+  /*!
+   * @brief Set the identifier of the client that serves this channel group.
+   * @param clientID The identifier; must be PVR_GROUP_CLIENT_ID_LOCAL for local groups.
+   */
+  void SetClientID(int clientID);
 
   /*!
    * @brief Get the path of this group.
@@ -122,33 +132,45 @@ public:
   void SetPath(const CPVRChannelsPath& path);
 
   /*!
-   * @brief Change the channelnumber of a group. Used by CGUIDialogPVRChannelManager.
-   * Call SortByChannelNumber() and Renumber() after all changes are done.
-   * @param channel The channel to change the channel number for.
-   * @param channelNumber The new channel number.
+   * @brief Remove a channel group member from this container.
+   * @param groupMember The channel group member to remove.
+   * @return True if the channel group member was removed, false otherwise.
    */
-  bool SetChannelNumber(const std::shared_ptr<CPVRChannel>& channel,
-                        const CPVRChannelNumber& channelNumber);
+  virtual bool RemoveFromGroup(const std::shared_ptr<const CPVRChannelGroupMember>& groupMember);
 
   /*!
-   * @brief Remove a channel from this container.
-   * @param channel The channel to remove.
-   * @return True if the channel was found and removed, false otherwise.
+   * @brief Append a channel group member to this container.
+   * @param groupMember The channel group member to append.
+   * @return True if the channel group member was appended, false otherwise.
    */
-  virtual bool RemoveFromGroup(const std::shared_ptr<CPVRChannel>& channel);
+  virtual bool AppendToGroup(const std::shared_ptr<const CPVRChannelGroupMember>& groupMember);
 
   /*!
-   * @brief Append a channel to this container.
-   * @param channel The channel to append.
-   * @return True if the channel was appended, false otherwise.
+   * @brief Check whether a channel group member is in this container.
+   * @param groupMember The channel group member to check.
+   * @return True if the channel group member was found, false otherwise.
    */
-  virtual bool AppendToGroup(const std::shared_ptr<CPVRChannel>& channel);
+  virtual bool IsGroupMember(
+      const std::shared_ptr<const CPVRChannelGroupMember>& groupMember) const;
 
   /*!
    * @brief Change the name of this group.
    * @param strGroupName The new group name.
+   * @param isUserSetName Whether the name was set by the user.
    */
-  void SetGroupName(const std::string& strGroupName);
+  void SetGroupName(const std::string& strGroupName, bool isUserSetName = false);
+
+  /*!
+   * @brief Set the name this group has on the client.
+   * @param groupName The client group name.
+   */
+  void SetClientGroupName(const std::string& groupName);
+
+  /*!
+   * @brief Check whether the group name was set by the user.
+   * @return True if set by user, false otherwise;
+   */
+  bool IsUserSetName() const { return m_isUserSetName; }
 
   /*!
    * @brief Persist changed or new data.
@@ -156,19 +178,6 @@ public:
    */
   bool Persist();
 
-  /*!
-   * @brief Check whether a channel is in this container.
-   * @param channel The channel to find.
-   * @return True if the channel was found, false otherwise.
-   */
-  virtual bool IsGroupMember(const std::shared_ptr<CPVRChannel>& channel) const;
-
-  /*!
-   * @brief Check if this group is the internal group containing all channels.
-   * @return True if it's the internal group, false otherwise.
-   */
-  bool IsInternalGroup() const { return m_iGroupType == PVR_GROUP_TYPE_INTERNAL; }
-
   /*!
    * @brief True if this group holds radio channels, false if it holds TV channels.
    * @return True if this group holds radio channels, false if it holds TV channels.
@@ -187,17 +196,6 @@ public:
    */
   void SetGroupID(int iGroupId);
 
-  /*!
-   * @brief Set the type of this group.
-   * @param the new type for this group.
-   */
-  void SetGroupType(int iGroupType);
-
-  /*!
-   * @brief Return the type of this group.
-   */
-  int GroupType() const;
-
   /*!
    * @return Time group has been watched last.
    */
@@ -226,6 +224,12 @@ public:
    */
   std::string GroupName() const;
 
+  /*!
+   * @brief Get the name of this group on the client.
+   * @return The group's name.
+   */
+  std::string ClientGroupName() const;
+
   /*! @name Sort methods
    */
   //@{
@@ -282,14 +286,14 @@ public:
    * @param channel The channel to get the channel number for.
    * @return The channel number in this group.
    */
-  CPVRChannelNumber GetChannelNumber(const std::shared_ptr<CPVRChannel>& channel) const;
+  CPVRChannelNumber GetChannelNumber(const std::shared_ptr<const CPVRChannel>& channel) const;
 
   /*!
    * @brief Get the client channel number in this group of the given channel.
    * @param channel The channel to get the channel number for.
    * @return The client channel number in this group.
    */
-  CPVRChannelNumber GetClientChannelNumber(const std::shared_ptr<CPVRChannel>& channel) const;
+  CPVRChannelNumber GetClientChannelNumber(const std::shared_ptr<const CPVRChannel>& channel) const;
 
   /*!
    * @brief Get the next channel group member in this group.
@@ -297,7 +301,7 @@ public:
    * @return The channel group member or nullptr if it wasn't found.
    */
   std::shared_ptr<CPVRChannelGroupMember> GetNextChannelGroupMember(
-      const std::shared_ptr<CPVRChannelGroupMember>& groupMember) const;
+      const std::shared_ptr<const CPVRChannelGroupMember>& groupMember) const;
 
   /*!
    * @brief Get the previous channel group member in this group.
@@ -305,7 +309,7 @@ public:
    * @return The channel group member or nullptr if it wasn't found.
    */
   std::shared_ptr<CPVRChannelGroupMember> GetPreviousChannelGroupMember(
-      const std::shared_ptr<CPVRChannelGroupMember>& groupMember) const;
+      const std::shared_ptr<const CPVRChannelGroupMember>& groupMember) const;
 
   /*!
    * @brief Get a channel given it's channel ID.
@@ -336,22 +340,23 @@ public:
   void GetChannelNumbers(std::vector<std::string>& channelNumbers) const;
 
   /*!
-   * @brief The amount of hidden channels in this container.
-   * @return The amount of hidden channels in this container.
-   */
-  virtual size_t GetNumHiddenChannels() const { return 0; }
-
-  /*!
-   * @brief Does this container holds channels.
+   * @brief Check whether this container has any channels.
    * @return True if there is at least one channel in this container, otherwise false.
    */
   bool HasChannels() const;
 
   /*!
+   * @brief Check whether this container has any new channels.
    * @return True if there is at least one new channel in this group that hasn't been persisted, false otherwise.
    */
   bool HasNewChannels() const;
 
+  /*!
+  * @brief Check whether this container has any hidden channels.
+  * @return True if at least one hidden channel is present, false otherwise.
+  */
+  bool HasHiddenChannels() const;
+
   /*!
    * @return True if anything changed in this group that hasn't been persisted, false otherwise.
    */
@@ -362,38 +367,6 @@ public:
    */
   bool IsNew() const;
 
-  /*!
-   * @brief Create an EPG table for each channel.
-   * @brief bForce Create the tables, even if they already have been created before.
-   * @return True if all tables were created successfully, false otherwise.
-   */
-  virtual bool CreateChannelEpgs(bool bForce = false);
-
-  /*!
-   * @brief Update a channel group member with given data.
-   * @param storageId The storage id of the channel.
-   * @param strChannelName The channel name to set.
-   * @param strIconPath The icon path to set.
-   * @param iEPGSource The EPG id.
-   * @param iChannelNumber The channel number to set.
-   * @param bHidden Set/Remove hidden flag for the channel group member identified by storage id.
-   * @param bEPGEnabled Set/Remove EPG enabled flag for the channel group member identified by storage id.
-   * @param bParentalLocked Set/Remove parental locked flag for the channel group member identified by storage id.
-   * @param bUserSetIcon Set/Remove user set icon flag for the channel group member identified by storage id.
-   * @param bUserSetHidden Set/Remove user set hidden flag for the channel group member identified by storage id.
-   * @return True on success, false otherwise.
-   */
-  bool UpdateChannel(const std::pair<int, int>& storageId,
-                     const std::string& strChannelName,
-                     const std::string& strIconPath,
-                     int iEPGSource,
-                     int iChannelNumber,
-                     bool bHidden,
-                     bool bEPGEnabled,
-                     bool bParentalLocked,
-                     bool bUserSetIcon,
-                     bool bUserSetHidden);
-
   /*!
    * @brief Get a channel given the channel number on the client.
    * @param iUniqueChannelId The unique channel id on the client.
@@ -412,9 +385,30 @@ public:
   bool SetHidden(bool bHidden);
   bool IsHidden() const;
 
+  /*!
+   * @brief Get the local position of this group.
+   * @return The local group position.
+   */
   int GetPosition() const;
+
+  /*!
+   * @brief Set the local position of this group.
+   * @param iPosition The new local group position.
+   */
   void SetPosition(int iPosition);
 
+  /*!
+   * @brief Get the position of this group as supplied by the PVR client.
+   * @return The client-supplied group position.
+   */
+  int GetClientPosition() const;
+
+  /*!
+   * @brief Set the client-supplied position of this group.
+   * @param iPosition The new client-supplied group position.
+   */
+  void SetClientPosition(int iPosition);
+
   /*!
    * @brief Check, whether data for a given pvr client are currently valid. For instance, data
    * can be invalid because the client's backend was offline when data was last queried.
@@ -454,6 +448,41 @@ public:
    */
   int CleanupCachedImages();
 
+  /*!
+   * @brief Get the priority of the client that provides this group.
+   * @return the priority, as set by the user or 0. Always 0 for non-backend-supplied groups.
+   */
+  int GetClientPriority() const;
+
+  /*!
+   * @brief Update the client priority for this group and all members of this group.
+   */
+  void UpdateClientPriorities();
+
+  /*!
+   * @brief Check whether this group could be deleted by the user.
+   * @return True if the group could be deleted, false otherwise.
+   */
+  virtual bool SupportsDelete() const = 0;
+
+  /*!
+   * @brief Check whether members could be added to this group by the user.
+   * @return True if members could be added, false otherwise.
+   */
+  virtual bool SupportsMemberAdd() const = 0;
+
+  /*!
+   * @brief Check whether members could be removed from this group by the user.
+   * @return True if members could be removed, false otherwise.
+   */
+  virtual bool SupportsMemberRemove() const = 0;
+
+  /*!
+   * @brief Check whether this group is owner of the channel instances it contains.
+   * @return True if owner, false otherwise.
+   */
+  virtual bool IsChannelsOwner() const = 0;
+
 protected:
   /*!
    * @brief Remove deleted group members from this group.
@@ -481,13 +510,12 @@ protected:
   void SortByChannelNumber();
 
   /*!
-   * @brief Update the priority for all members of all channel groups.
+   * @brief Update the client priority for all members of this group.
    */
-  bool UpdateClientPriorities();
+  bool UpdateMembersClientPriority();
 
   std::shared_ptr<CPVRChannelGroupSettings> GetSettings() const;
 
-  int m_iGroupType = PVR_GROUP_TYPE_DEFAULT; /*!< The type of this group */
   int m_iGroupId = INVALID_GROUP_ID; /*!< The ID of this group in the database */
   bool m_bLoaded = false; /*!< True if this container is loaded, false otherwise */
   bool m_bChanged =
@@ -495,7 +523,7 @@ protected:
   time_t m_iLastWatched = 0; /*!< last time group has been watched */
   uint64_t m_iLastOpened = 0; /*!< time in milliseconds from epoch this group was last opened */
   bool m_bHidden = false; /*!< true if this group is hidden, false otherwise */
-  int m_iPosition = 0; /*!< the position of this group within the group list */
+  int m_iPosition = 0; /*!< the local position of this group within the group list */
   std::vector<std::shared_ptr<CPVRChannelGroupMember>>
       m_sortedMembers; /*!< members sorted by channel number */
   std::map<std::pair<int, int>, std::shared_ptr<CPVRChannelGroupMember>>
@@ -510,6 +538,11 @@ protected:
   static std::weak_ptr<CPVRChannelGroupSettings> m_settingsSingleton;
 
 private:
+  /*!
+   * @brief Return the type of this group.
+   */
+  virtual int GroupType() const = 0;
+
   /*!
    * @brief Load the channel group members stored in the database.
    * @param clients The PVR clients to load data for. Leave empty for all clients.
@@ -541,8 +574,12 @@ private:
 
   void OnSettingChanged();
 
-  std::shared_ptr<CPVRChannelGroup> m_allChannelsGroup;
+  std::shared_ptr<const CPVRChannelGroup> m_allChannelsGroup;
   CPVRChannelsPath m_path;
   bool m_bDeleted = false;
+  mutable std::optional<int> m_clientPriority;
+  bool m_isUserSetName{false};
+  std::string m_clientGroupName;
+  int m_iClientPosition{0};
 };
 } // namespace PVR
