@@ -10,6 +10,7 @@
 
 #include "FileItem.h"
 #include "ServiceBroker.h"
+#include "dialogs/GUIDialogContextMenu.h"
 #include "dialogs/GUIDialogYesNo.h"
 #include "guilib/GUIComponent.h"
 #include "guilib/GUIKeyboardFactory.h"
@@ -22,11 +23,14 @@
 #include "messaging/helpers//DialogOKHelper.h"
 #include "pvr/PVRManager.h"
 #include "pvr/PVRPlaybackState.h"
+#include "pvr/addons/PVRClient.h"
 #include "pvr/channels/PVRChannel.h"
 #include "pvr/channels/PVRChannelGroupMember.h"
 #include "pvr/channels/PVRChannelGroups.h"
 #include "pvr/channels/PVRChannelGroupsContainer.h"
 #include "pvr/filesystem/PVRGUIDirectory.h"
+#include "settings/Settings.h"
+#include "settings/SettingsComponent.h"
 #include "utils/StringUtils.h"
 #include "utils/Variant.h"
 
@@ -51,6 +55,12 @@ using namespace PVR;
 #define BUTTON_TOGGLE_RADIO_TV        34
 #define BUTTON_RECREATE_GROUP_THUMB   35
 
+namespace
+{
+constexpr const char* PROPERTY_CLIENT_NAME = "ClientName";
+
+} // namespace
+
 CGUIDialogPVRGroupManager::CGUIDialogPVRGroupManager() :
     CGUIDialog(WINDOW_DIALOG_PVR_GROUP_MANAGER, "DialogPVRGroupManager.xml")
 {
@@ -79,6 +89,53 @@ bool CGUIDialogPVRGroupManager::PersistChanges()
   return CServiceBroker::GetPVRManager().ChannelGroups()->Get(m_bIsRadio)->PersistAll();
 }
 
+bool CGUIDialogPVRGroupManager::OnPopupMenu(int itemNumber)
+{
+  // Currently, the only context menu item is "move".
+  if (!m_allowReorder)
+    return false;
+
+  CContextButtons buttons;
+
+  if (itemNumber < 0 || itemNumber >= m_channelGroups->Size())
+    return false;
+
+  const auto item = m_channelGroups->Get(itemNumber);
+  if (!item)
+    return false;
+
+  item->Select(true);
+
+  buttons.Add(CONTEXT_BUTTON_MOVE, 116); // Move
+
+  const int choice = CGUIDialogContextMenu::ShowAndGetChoice(buttons);
+
+  item->Select(false);
+
+  if (choice < 0)
+    return false;
+
+  return OnContextButton(itemNumber, choice);
+}
+
+bool CGUIDialogPVRGroupManager::OnContextButton(int itemNumber, int button)
+{
+  if (itemNumber < 0 || itemNumber >= m_channelGroups->Size())
+    return false;
+
+  const auto item = m_channelGroups->Get(itemNumber);
+  if (!item)
+    return false;
+
+  if (button == CONTEXT_BUTTON_MOVE)
+  {
+    // begin moving item
+    m_movingItem = true;
+    item->Select(true);
+  }
+  return true;
+}
+
 bool CGUIDialogPVRGroupManager::ActionButtonOk(const CGUIMessage& message)
 {
   bool bReturn = false;
@@ -101,18 +158,18 @@ bool CGUIDialogPVRGroupManager::ActionButtonNewGroup(const CGUIMessage& message)
 
   if (iControl == BUTTON_NEWGROUP)
   {
-    std::string strGroupName = "";
-    /* prompt for a group name */
+    std::string strGroupName;
     if (CGUIKeyboardFactory::ShowAndGetInput(strGroupName, CVariant{g_localizeStrings.Get(19139)}, false))
     {
-      if (strGroupName != "")
+      if (!strGroupName.empty())
       {
-        /* add the group if it doesn't already exist */
-        CPVRChannelGroups* groups = CServiceBroker::GetPVRManager().ChannelGroups()->Get(m_bIsRadio);
-        if (groups->AddGroup(strGroupName))
+        // add the group if it doesn't already exist
+        auto groups = CServiceBroker::GetPVRManager().ChannelGroups()->Get(m_bIsRadio);
+        const auto group = groups->AddGroup(strGroupName);
+        if (group)
         {
-          CServiceBroker::GetPVRManager().ChannelGroups()->Get(m_bIsRadio)->GetByName(strGroupName)->SetGroupType(PVR_GROUP_TYPE_USER_DEFINED);
-          m_iSelectedChannelGroup = groups->Size() - 1;
+          m_selectedGroup = group;
+          m_iSelectedChannelGroup = -1; // recalc index in Update()
           Update();
         }
       }
@@ -170,12 +227,18 @@ bool CGUIDialogPVRGroupManager::ActionButtonRenameGroup(const CGUIMessage& messa
       return bReturn;
 
     std::string strGroupName(m_selectedGroup->GroupName());
-    if (CGUIKeyboardFactory::ShowAndGetInput(strGroupName, CVariant{g_localizeStrings.Get(19139)}, false))
+    if (CGUIKeyboardFactory::ShowAndGetInput(strGroupName, CVariant{g_localizeStrings.Get(19139)},
+                                             true /* allow empty result */))
     {
+      // if an empty string was given we reset the name to the client-supplied name, if available
+      const bool resetName = strGroupName.empty() && !m_selectedGroup->ClientGroupName().empty();
+      if (resetName)
+        strGroupName = m_selectedGroup->ClientGroupName();
+
       if (!strGroupName.empty())
       {
         ClearSelectedGroupsThumbnail();
-        m_selectedGroup->SetGroupName(strGroupName);
+        m_selectedGroup->SetGroupName(strGroupName, !resetName);
         Update();
       }
     }
@@ -194,22 +257,25 @@ bool CGUIDialogPVRGroupManager::ActionButtonUngroupedChannels(const CGUIMessage&
   if (m_viewUngroupedChannels.HasControl(iControl)) // list/thumb control
   {
     m_iSelectedUngroupedChannel = m_viewUngroupedChannels.GetSelectedItem();
-    int iAction = message.GetParam1();
-
-    if (iAction == ACTION_SELECT_ITEM || iAction == ACTION_MOUSE_LEFT_CLICK)
+    if (m_selectedGroup->SupportsMemberAdd())
     {
-      if (m_channelGroups->GetFolderCount() == 0)
-      {
-        HELPERS::ShowOKDialogText(CVariant{19033}, CVariant{19137});
-      }
-      else if (m_ungroupedChannels->GetFileCount() > 0)
-      {
-        CFileItemPtr pItemChannel = m_ungroupedChannels->Get(m_iSelectedUngroupedChannel);
+      const int actionID = message.GetParam1();
 
-        if (m_selectedGroup->AppendToGroup(pItemChannel->GetPVRChannelInfoTag()))
+      if (actionID == ACTION_SELECT_ITEM || actionID == ACTION_MOUSE_LEFT_CLICK)
+      {
+        if (m_channelGroups->GetFolderCount() == 0)
         {
-          ClearSelectedGroupsThumbnail();
-          Update();
+          HELPERS::ShowOKDialogText(CVariant{19033}, CVariant{19137});
+        }
+        else if (m_ungroupedChannels->GetFileCount() > 0)
+        {
+          const auto itemChannel = m_ungroupedChannels->Get(m_iSelectedUngroupedChannel);
+
+          if (m_selectedGroup->AppendToGroup(itemChannel->GetPVRChannelGroupMemberInfoTag()))
+          {
+            ClearSelectedGroupsThumbnail();
+            Update();
+          }
         }
       }
     }
@@ -227,16 +293,19 @@ bool CGUIDialogPVRGroupManager::ActionButtonGroupMembers(const CGUIMessage& mess
   if (m_viewGroupMembers.HasControl(iControl)) // list/thumb control
   {
     m_iSelectedGroupMember = m_viewGroupMembers.GetSelectedItem();
-    int iAction = message.GetParam1();
-
-    if (iAction == ACTION_SELECT_ITEM || iAction == ACTION_MOUSE_LEFT_CLICK)
+    if (m_selectedGroup->SupportsMemberRemove())
     {
-      if (m_selectedGroup && m_groupMembers->GetFileCount() > 0)
+      const int actionID = message.GetParam1();
+
+      if (actionID == ACTION_SELECT_ITEM || actionID == ACTION_MOUSE_LEFT_CLICK)
       {
-        CFileItemPtr pItemChannel = m_groupMembers->Get(m_iSelectedGroupMember);
-        m_selectedGroup->RemoveFromGroup(pItemChannel->GetPVRChannelInfoTag());
-        ClearSelectedGroupsThumbnail();
-        Update();
+        if (m_selectedGroup && m_groupMembers->GetFileCount() > 0)
+        {
+          const auto itemChannel = m_groupMembers->Get(m_iSelectedGroupMember);
+          m_selectedGroup->RemoveFromGroup(itemChannel->GetPVRChannelGroupMemberInfoTag());
+          ClearSelectedGroupsThumbnail();
+          Update();
+        }
       }
     }
     bReturn = true;
@@ -252,14 +321,44 @@ bool CGUIDialogPVRGroupManager::ActionButtonChannelGroups(const CGUIMessage& mes
 
   if (m_viewChannelGroups.HasControl(iControl)) // list/thumb control
   {
-    int iAction = message.GetParam1();
-
-    if (iAction == ACTION_SELECT_ITEM || iAction == ACTION_MOUSE_LEFT_CLICK)
+    if (!m_movingItem)
     {
-      m_iSelectedChannelGroup = m_viewChannelGroups.GetSelectedItem();
-      Update();
+      const int iAction = message.GetParam1();
+
+      if (iAction == ACTION_SELECT_ITEM || iAction == ACTION_MOUSE_LEFT_CLICK)
+      {
+        m_iSelectedChannelGroup = m_viewChannelGroups.GetSelectedItem();
+        Update();
+      }
+      else if (iAction == ACTION_CONTEXT_MENU || iAction == ACTION_MOUSE_RIGHT_CLICK)
+      {
+        m_iSelectedChannelGroup = m_viewChannelGroups.GetSelectedItem();
+        OnPopupMenu(m_iSelectedChannelGroup);
+      }
+      bReturn = true;
+    }
+    else
+    {
+      const auto item = m_channelGroups->Get(m_iSelectedChannelGroup);
+      if (item)
+      {
+        // end moving item
+        item->Select(false);
+        m_movingItem = false;
+
+        // reset group positions
+        auto* groups = CServiceBroker::GetPVRManager().ChannelGroups()->Get(m_bIsRadio);
+        int pos = 1;
+        for (auto& groupItem : *m_channelGroups)
+        {
+          const auto group = groups->GetGroupByPath(groupItem->GetPath());
+          if (group)
+            group->SetPosition(pos++);
+        }
+        groups->SortGroups();
+        bReturn = true;
+      }
     }
-    bReturn = true;
   }
 
   return bReturn;
@@ -378,10 +477,38 @@ bool CGUIDialogPVRGroupManager::OnActionMove(const CAction& action)
       int iSelected = m_viewChannelGroups.GetSelectedItem();
 
       bReturn = true;
-      if (iSelected != m_iSelectedChannelGroup)
+      if (!m_movingItem)
       {
-        m_iSelectedChannelGroup = iSelected;
-        Update();
+        if (iSelected != m_iSelectedChannelGroup)
+        {
+          m_iSelectedChannelGroup = iSelected;
+          Update();
+        }
+      }
+      else
+      {
+        bool moveUp = iActionId == ACTION_PAGE_UP || iActionId == ACTION_MOVE_UP ||
+                      iActionId == ACTION_FIRST_PAGE;
+        unsigned int lines = moveUp ? std::abs(m_iSelectedChannelGroup - iSelected) : 1;
+        bool outOfBounds = moveUp ? m_iSelectedChannelGroup <= 0
+                                  : m_iSelectedChannelGroup >= m_channelGroups->Size() - 1;
+        if (outOfBounds)
+        {
+          moveUp = !moveUp;
+          lines = m_channelGroups->Size() - 1;
+        }
+        for (unsigned int line = 0; line < lines; ++line)
+        {
+          const unsigned int newSelect =
+              moveUp ? m_iSelectedChannelGroup - 1 : m_iSelectedChannelGroup + 1;
+
+          // swap items
+          m_channelGroups->Swap(newSelect, m_iSelectedChannelGroup);
+          m_iSelectedChannelGroup = newSelect;
+        }
+
+        m_viewChannelGroups.SetItems(*m_channelGroups);
+        m_viewChannelGroups.SetSelectedItem(m_iSelectedChannelGroup);
       }
     }
   }
@@ -401,6 +528,12 @@ void CGUIDialogPVRGroupManager::OnInitWindow()
   m_iSelectedUngroupedChannel = 0;
   m_iSelectedGroupMember = 0;
   m_iSelectedChannelGroup = 0;
+  m_movingItem = false;
+
+  // prevent resorting groups if backend group order shall be used
+  const std::shared_ptr<CSettings> settings = CServiceBroker::GetSettingsComponent()->GetSettings();
+  m_allowReorder = !settings->GetBool(CSettings::SETTING_PVRMANAGER_BACKENDCHANNELGROUPSORDER);
+
   Update();
 }
 
@@ -446,15 +579,36 @@ void CGUIDialogPVRGroupManager::Update()
   // get the groups list
   CPVRGUIDirectory::GetChannelGroupsDirectory(m_bIsRadio, false, *m_channelGroups);
 
+  for (auto& group : *m_channelGroups)
+  {
+    const std::shared_ptr<const CPVRClient> client =
+        CServiceBroker::GetPVRManager().GetClient(*group);
+    if (client)
+      group->SetProperty(PROPERTY_CLIENT_NAME, client->GetFriendlyName());
+  }
+
   // Load group thumbnails
   m_thumbLoader.Load(*m_channelGroups);
 
   m_viewChannelGroups.SetItems(*m_channelGroups);
-  m_viewChannelGroups.SetSelectedItem(m_iSelectedChannelGroup);
 
-  /* select a group or select the default group if no group was selected */
-  CFileItemPtr pItem = m_channelGroups->Get(m_viewChannelGroups.GetSelectedItem());
-  m_selectedGroup = CServiceBroker::GetPVRManager().ChannelGroups()->Get(m_bIsRadio)->GetByName(pItem->m_strTitle);
+  if (m_iSelectedChannelGroup >= 0)
+  {
+    m_viewChannelGroups.SetSelectedItem(m_iSelectedChannelGroup);
+
+    // select a group or select the default group if no group was selected
+    const auto item = m_channelGroups->Get(m_viewChannelGroups.GetSelectedItem());
+    m_selectedGroup = CServiceBroker::GetPVRManager()
+                          .ChannelGroups()
+                          ->Get(m_bIsRadio)
+                          ->GetGroupByPath(item->GetPath());
+  }
+  else if (m_selectedGroup)
+  {
+    m_viewChannelGroups.SetSelectedItem(m_selectedGroup->GetPath());
+    m_iSelectedChannelGroup = m_viewChannelGroups.GetSelectedItem();
+  }
+
   if (m_selectedGroup)
   {
     /* set this group in the pvrmanager, so it becomes the selected group in other dialogs too */
@@ -462,62 +616,28 @@ void CGUIDialogPVRGroupManager::Update()
     SET_CONTROL_LABEL(CONTROL_CURRENT_GROUP_LABEL, m_selectedGroup->GroupName());
     SET_CONTROL_SELECTED(GetID(), BUTTON_HIDE_GROUP, m_selectedGroup->IsHidden());
 
-    CONTROL_ENABLE_ON_CONDITION(BUTTON_DELGROUP, !m_selectedGroup->IsInternalGroup());
+    CONTROL_ENABLE_ON_CONDITION(BUTTON_DELGROUP, m_selectedGroup->SupportsDelete());
 
-    if (m_selectedGroup->IsInternalGroup())
+    SET_CONTROL_LABEL(CONTROL_UNGROUPED_LABEL, g_localizeStrings.Get(19219));
+    SET_CONTROL_LABEL(
+        CONTROL_IN_GROUP_LABEL,
+        StringUtils::Format("{} {}", g_localizeStrings.Get(19220), m_selectedGroup->GroupName()));
+
+    const std::vector<std::shared_ptr<CPVRChannelGroupMember>> groupMembers =
+        m_selectedGroup->GetMembers(CPVRChannelGroup::Include::ONLY_VISIBLE);
+    for (const auto& groupMember : groupMembers)
     {
-      std::string strNewLabel = StringUtils::Format("{} {}", g_localizeStrings.Get(19022),
-                                                    m_bIsRadio ? g_localizeStrings.Get(19024)
-                                                               : g_localizeStrings.Get(19023));
-      SET_CONTROL_LABEL(CONTROL_UNGROUPED_LABEL, strNewLabel);
-
-      strNewLabel = StringUtils::Format("{} {}", g_localizeStrings.Get(19218),
-                                        m_bIsRadio ? g_localizeStrings.Get(19024)
-                                                   : g_localizeStrings.Get(19023));
-      SET_CONTROL_LABEL(CONTROL_IN_GROUP_LABEL, strNewLabel);
-    }
-    else
-    {
-      std::string strNewLabel = g_localizeStrings.Get(19219);
-      SET_CONTROL_LABEL(CONTROL_UNGROUPED_LABEL, strNewLabel);
-
-      strNewLabel =
-          StringUtils::Format("{} {}", g_localizeStrings.Get(19220), m_selectedGroup->GroupName());
-      SET_CONTROL_LABEL(CONTROL_IN_GROUP_LABEL, strNewLabel);
+      m_groupMembers->Add(std::make_shared<CFileItem>(groupMember));
     }
 
-    // Slightly different handling for "all" group...
-    if (m_selectedGroup->IsInternalGroup())
-    {
-      const std::vector<std::shared_ptr<CPVRChannelGroupMember>> groupMembers =
-          m_selectedGroup->GetMembers(CPVRChannelGroup::Include::ALL);
-      for (const auto& groupMember : groupMembers)
-      {
-        if (groupMember->Channel()->IsHidden())
-          m_ungroupedChannels->Add(std::make_shared<CFileItem>(groupMember));
-        else
-          m_groupMembers->Add(std::make_shared<CFileItem>(groupMember));
-      }
-    }
-    else
-    {
-      const std::vector<std::shared_ptr<CPVRChannelGroupMember>> groupMembers =
-          m_selectedGroup->GetMembers(CPVRChannelGroup::Include::ONLY_VISIBLE);
-      for (const auto& groupMember : groupMembers)
-      {
-        m_groupMembers->Add(std::make_shared<CFileItem>(groupMember));
-      }
+    const auto groups = CServiceBroker::GetPVRManager().ChannelGroups()->Get(m_bIsRadio);
+    const auto availableMembers = groups->GetMembersAvailableForGroup(m_selectedGroup);
 
-      /* for the center part, get all channels of the "all" channels group that are not in this group */
-      const std::shared_ptr<CPVRChannelGroup> allGroup = CServiceBroker::GetPVRManager().ChannelGroups()->GetGroupAll(m_bIsRadio);
-      const std::vector<std::shared_ptr<CPVRChannelGroupMember>> allGroupMembers =
-          allGroup->GetMembers(CPVRChannelGroup::Include::ONLY_VISIBLE);
-      for (const auto& groupMember : allGroupMembers)
-      {
-        if (!m_selectedGroup->IsGroupMember(groupMember->Channel()))
-          m_ungroupedChannels->Add(std::make_shared<CFileItem>(groupMember));
-      }
+    for (const auto& groupMember : availableMembers)
+    {
+      m_ungroupedChannels->Add(std::make_shared<CFileItem>(groupMember));
     }
+
     m_viewGroupMembers.SetItems(*m_groupMembers);
     m_viewGroupMembers.SetSelectedItem(m_iSelectedGroupMember);
 
