@@ -10,6 +10,8 @@
 
 #include "pvr/IPVRComponent.h"
 
+#include <memory>
+
 class CFileItem;
 
 namespace PVR
@@ -20,12 +22,27 @@ public:
   CPVRGUIActionsUtils() = default;
   ~CPVRGUIActionsUtils() override = default;
 
+  /*!
+     * @brief Check whether OnInfo supports the given item.
+     * @param item The item.
+     * @return True if supported, false otherwise.
+     */
+  bool HasInfoForItem(const CFileItem& item) const;
+
   /*!
      * @brief Process info action for the given item.
      * @param item The item.
+     * @return True on success, false otherwise.
      */
   bool OnInfo(const CFileItem& item);
 
+  /*!
+   * @brief Load item details (create recording info tag etc.).
+   * @param item The item.
+   * @return Loaded item on success, nullptr otherwise.
+   */
+  std::shared_ptr<CFileItem> LoadItem(const CFileItem& item);
+
 private:
   CPVRGUIActionsUtils(const CPVRGUIActionsUtils&) = delete;
   CPVRGUIActionsUtils const& operator=(CPVRGUIActionsUtils const&) = delete;
