@@ -29,21 +29,22 @@
 #include "utils/URIUtils.h"
 #include "video/VideoLibraryQueue.h"
 #include "video/VideoUtils.h"
+#include "video/guilib/VideoPlayActionProcessor.h"
+#include "video/guilib/VideoSelectActionProcessor.h"
 #include "video/windows/GUIWindowVideoBase.h"
-#include "video/windows/GUIWindowVideoNav.h"
 
 #include <memory>
 #include <mutex>
 #include <string>
 
 using namespace PVR;
+using namespace VIDEO::GUILIB;
 
 CGUIWindowPVRRecordingsBase::CGUIWindowPVRRecordingsBase(bool bRadio,
                                                          int id,
                                                          const std::string& xmlFile)
   : CGUIWindowPVRBase(bRadio, id, xmlFile),
-    m_settings(
-        {CSettings::SETTING_PVRRECORD_GROUPRECORDINGS, CSettings::SETTING_MYVIDEOS_SELECTACTION})
+    m_settings({CSettings::SETTING_PVRRECORD_GROUPRECORDINGS})
 {
 }
 
@@ -123,6 +124,17 @@ bool CGUIWindowPVRRecordingsBase::OnAction(const CAction& action)
   return CGUIWindowPVRBase::OnAction(action);
 }
 
+bool CGUIWindowPVRRecordingsBase::OnPopupMenu(int iItem)
+{
+  if (iItem >= 0 && iItem < m_vecItems->Size())
+  {
+    const auto item = m_vecItems->Get(iItem);
+    item->SetProperty("CheckAutoPlayNextItem", true);
+  }
+
+  return CGUIWindowPVRBase::OnPopupMenu(iItem);
+}
+
 bool CGUIWindowPVRRecordingsBase::OnContextButton(int itemNumber, CONTEXT_BUTTON button)
 {
   if (itemNumber < 0 || itemNumber >= m_vecItems->Size())
@@ -210,6 +222,105 @@ void CGUIWindowPVRRecordingsBase::UpdateButtons()
                     bGroupRecordings && path.IsValid() ? path.GetUnescapedDirectoryPath() : "");
 }
 
+namespace
+{
+class CVideoSelectActionProcessor : public VIDEO::GUILIB::CVideoSelectActionProcessorBase
+{
+public:
+  CVideoSelectActionProcessor(CGUIWindowPVRRecordingsBase& window,
+                              const std::shared_ptr<CFileItem>& item,
+                              int itemIndex)
+    : CVideoSelectActionProcessorBase(item), m_window(window), m_itemIndex(itemIndex)
+  {
+  }
+
+protected:
+  bool OnPlayPartSelected(unsigned int part) override
+  {
+    //! @todo pvr recordings do not support video stacking (yet).
+    return false;
+  }
+
+  bool OnResumeSelected() override
+  {
+    CServiceBroker::GetPVRManager().Get<PVR::GUI::Playback>().ResumePlayRecording(
+        *m_item, true /* fall back to play if no resume possible */);
+    return true;
+  }
+
+  bool OnPlaySelected() override
+  {
+    CServiceBroker::GetPVRManager().Get<PVR::GUI::Playback>().PlayRecording(
+        *m_item, false /* no resume check */);
+    return true;
+  }
+
+  bool OnQueueSelected() override
+  {
+    VIDEO_UTILS::QueueItem(m_item, VIDEO_UTILS::QueuePosition::POSITION_END);
+    return true;
+  }
+
+  bool OnInfoSelected() override
+  {
+    CServiceBroker::GetPVRManager().Get<PVR::GUI::Recordings>().ShowRecordingInfo(*m_item);
+    return true;
+  }
+
+  bool OnChooseSelected() override
+  {
+    m_window.OnPopupMenu(m_itemIndex);
+    return true;
+  }
+
+private:
+  CGUIWindowPVRRecordingsBase& m_window;
+  const int m_itemIndex{-1};
+};
+
+class CVideoPlayActionProcessor : public CVideoPlayActionProcessorBase
+{
+public:
+  explicit CVideoPlayActionProcessor(const std::shared_ptr<CFileItem>& item)
+    : CVideoPlayActionProcessorBase(item)
+  {
+  }
+
+protected:
+  bool OnResumeSelected() override
+  {
+    if (m_item->m_bIsFolder)
+    {
+      m_item->SetStartOffset(STARTOFFSET_RESUME);
+      CServiceBroker::GetPVRManager().Get<PVR::GUI::Playback>().PlayRecordingFolder(
+          *m_item, false /* no resume check */);
+    }
+    else
+    {
+      CServiceBroker::GetPVRManager().Get<PVR::GUI::Playback>().ResumePlayRecording(
+          *m_item, true /* fall back to play if no resume possible */);
+    }
+    return true;
+  }
+
+  bool OnPlaySelected() override
+  {
+    if (m_item->m_bIsFolder)
+    {
+      m_item->SetStartOffset(0);
+      CServiceBroker::GetPVRManager().Get<PVR::GUI::Playback>().PlayRecordingFolder(
+          *m_item, false /* no resume check */);
+    }
+    else
+    {
+      CServiceBroker::GetPVRManager().Get<PVR::GUI::Playback>().PlayRecording(
+          *m_item, false /* no resume check */);
+    }
+    return true;
+  }
+};
+} // namespace
+
 bool CGUIWindowPVRRecordingsBase::OnMessage(CGUIMessage& message)
 {
   bool bReturn = false;
@@ -231,7 +342,7 @@ bool CGUIWindowPVRRecordingsBase::OnMessage(CGUIMessage& message)
               const CPVRRecordingsPath path(m_vecItems->GetPath());
               if (path.IsValid() && path.IsRecordingsRoot() && item->IsParentFolder())
               {
-                // handle special 'go home' item.
+                // handle .. item, which is only visible if list of recordings is empty.
                 CServiceBroker::GetGUI()->GetWindowManager().ActivateWindow(WINDOW_HOME);
                 bReturn = true;
                 break;
@@ -239,16 +350,8 @@ bool CGUIWindowPVRRecordingsBase::OnMessage(CGUIMessage& message)
 
               if (!item->IsParentFolder() && message.GetParam1() == ACTION_PLAYER_PLAY)
               {
-                if (item->m_bIsFolder)
-                {
-                  if (CGUIWindowVideoNav::ShowResumeMenu(*item))
-                    VIDEO_UTILS::PlayItem(item);
-                }
-                else
-                  CServiceBroker::GetPVRManager().Get<PVR::GUI::Playback>().PlayRecording(
-                      *item, true /* check resume */);
-
-                bReturn = true;
+                CVideoPlayActionProcessor proc{item};
+                bReturn = proc.ProcessDefaultAction();
               }
               else if (item->m_bIsFolder)
               {
@@ -257,31 +360,8 @@ bool CGUIWindowPVRRecordingsBase::OnMessage(CGUIMessage& message)
               }
               else
               {
-                switch (m_settings.GetIntValue(CSettings::SETTING_MYVIDEOS_SELECTACTION))
-                {
-                  case SELECT_ACTION_CHOOSE:
-                    OnPopupMenu(iItem);
-                    bReturn = true;
-                    break;
-                  case SELECT_ACTION_PLAY_OR_RESUME:
-                    CServiceBroker::GetPVRManager().Get<PVR::GUI::Playback>().PlayRecording(
-                        *item, true /* check resume */);
-                    bReturn = true;
-                    break;
-                  case SELECT_ACTION_RESUME:
-                    CServiceBroker::GetPVRManager().Get<PVR::GUI::Playback>().ResumePlayRecording(
-                        *item, true /* fall back to play if no resume possible */);
-                    bReturn = true;
-                    break;
-                  case SELECT_ACTION_INFO:
-                    CServiceBroker::GetPVRManager().Get<PVR::GUI::Recordings>().ShowRecordingInfo(
-                        *item);
-                    bReturn = true;
-                    break;
-                  default:
-                    bReturn = false;
-                    break;
-                }
+                CVideoSelectActionProcessor proc(*this, item, iItem);
+                bReturn = proc.ProcessDefaultAction();
               }
               break;
             }
