@@ -303,11 +303,19 @@ bool CDisplaySettings::OnSettingChanging(const std::shared_ptr<const CSetting>&
   }
   else if (settingId == CSettings::SETTING_VIDEOSCREEN_MONITOR)
   {
-    CServiceBroker::GetWinSystem()->UpdateResolutions();
+    auto winSystem = CServiceBroker::GetWinSystem();
+    if (winSystem->SupportsScreenMove())
+    {
+      const std::string screen =
+          std::static_pointer_cast<const CSettingString>(setting)->GetValue();
+      const unsigned int screenIdx = winSystem->GetScreenId(screen);
+      winSystem->MoveToScreen(screenIdx);
+    }
+    winSystem->UpdateResolutions();
     RESOLUTION newRes = GetResolutionForScreen();
 
     SetCurrentResolution(newRes, false);
-    CServiceBroker::GetWinSystem()->GetGfxContext().SetVideoResolution(newRes, true);
+    winSystem->GetGfxContext().SetVideoResolution(newRes, true);
 
     if (!m_resolutionChangeAborted)
     {
@@ -420,7 +428,8 @@ void CDisplaySettings::SetCurrentResolution(RESOLUTION resolution, bool save /*
   {
     // Save videoscreen.screenmode setting
     std::string mode = GetStringFromResolution(resolution);
-    CServiceBroker::GetSettingsComponent()->GetSettings()->SetString(CSettings::SETTING_VIDEOSCREEN_SCREENMODE, mode.c_str());
+    CServiceBroker::GetSettingsComponent()->GetSettings()->SetString(
+        CSettings::SETTING_VIDEOSCREEN_SCREENMODE, mode);
 
     // Check if videoscreen.screen setting also needs to be saved
     // e.g. if ToggleFullscreen is called
@@ -786,16 +795,36 @@ void CDisplaySettings::SettingOptionsResolutionsFiller(const SettingConstPtr& se
     std::vector<RESOLUTION_WHR> resolutions = CServiceBroker::GetWinSystem()->ScreenResolutions(info.fRefreshRate);
     for (std::vector<RESOLUTION_WHR>::const_iterator resolution = resolutions.begin(); resolution != resolutions.end(); ++resolution)
     {
-      list.emplace_back(StringUtils::Format("{}x{}{}", resolution->width, resolution->height,
-                                            ModeFlagsToString(resolution->flags, false)),
-                        resolution->ResInfo_Index);
+      const std::string resLabel =
+          StringUtils::Format("{}x{}{}{}", resolution->m_screenWidth, resolution->m_screenHeight,
+                              ModeFlagsToString(resolution->flags, false),
+                              resolution->width > resolution->m_screenWidth &&
+                                      resolution->height > resolution->m_screenHeight
+                                  ? " (HiDPI)"
+                                  : "");
+      list.emplace_back(resLabel, resolution->ResInfo_Index);
 
       resolutionInfos.insert(std::make_pair((RESOLUTION)resolution->ResInfo_Index, CDisplaySettings::GetInstance().GetResolutionInfo(resolution->ResInfo_Index)));
     }
 
-    current = FindBestMatchingResolution(resolutionInfos,
-                                         info.iScreenWidth, info.iScreenHeight,
-                                         info.fRefreshRate, info.dwFlags);
+    // ids are unique, so try to find a match by id first. Then resort to best matching resolution.
+    if (!info.strId.empty())
+    {
+      const auto it = std::find_if(resolutionInfos.begin(), resolutionInfos.end(),
+                                   [&](const std::pair<RESOLUTION, RESOLUTION_INFO>& resItem) {
+                                     return info.strId == resItem.second.strId;
+                                   });
+      current =
+          it != resolutionInfos.end()
+              ? it->first
+              : FindBestMatchingResolution(resolutionInfos, info.iScreenWidth, info.iScreenHeight,
+                                           info.fRefreshRate, info.dwFlags);
+    }
+    else
+    {
+      current = FindBestMatchingResolution(resolutionInfos, info.iScreenWidth, info.iScreenHeight,
+                                           info.fRefreshRate, info.dwFlags);
+    }
   }
 }
 
