@@ -80,6 +80,92 @@ std::string GetFamilyNameFromSfnt(FT_Face face)
 }
 } // unnamed namespace
 
+bool UTILS::FONT::GetFontFamilyNames(const std::vector<uint8_t>& buffer,
+                                     std::set<std::string>& familyNames)
+{
+  FT_Library m_library{nullptr};
+  FT_Init_FreeType(&m_library);
+  if (!m_library)
+  {
+    CLog::LogF(LOGERROR, "Unable to initialize freetype library");
+    return false;
+  }
+
+  FT_Open_Args args{};
+  args.flags = FT_OPEN_MEMORY;
+  args.memory_base = reinterpret_cast<const FT_Byte*>(buffer.data());
+  args.memory_size = static_cast<FT_Long>(buffer.size());
+
+  FT_Long numFaces{0};
+  FT_Long numInstances{0};
+  FT_Long faceIndex{0};
+  FT_Long instanceIndex{0};
+
+  // Iterate over all font faces, files like .ttc (TrueType Collection) contains multiple fonts
+  do
+  {
+    FT_Long idx = (instanceIndex << 16) + faceIndex;
+    FT_Face face{nullptr};
+
+    FT_Error error = FT_Open_Face(m_library, &args, idx, &face);
+    if (error)
+    {
+      CLog::LogF(LOGERROR, "Failed to open font face at index {} error code {}", idx, error);
+      break;
+    }
+
+    std::string familyName = GetFamilyNameFromSfnt(face);
+    if (familyName.empty())
+    {
+      CLog::LogF(LOGWARNING, "Failed to get the unicode family name for \"{}\", fallback to ASCII",
+                 face->family_name);
+      // ASCII font family name may differ from the unicode one, use this as fallback only
+      familyName = std::string{face->family_name};
+      if (familyName.empty())
+      {
+        CLog::LogF(LOGERROR, "Family name missing in the font");
+        return false;
+      }
+    }
+
+    // We use the "set" container to avoid duplicate names that can happens
+    // for example when a font have each style on different files
+    familyNames.insert(familyName);
+
+    numFaces = face->num_faces;
+    numInstances = face->style_flags >> 16;
+
+    FT_Done_Face(face);
+
+    if (instanceIndex < numInstances)
+      instanceIndex++;
+    else
+    {
+      faceIndex++;
+      instanceIndex = 0;
+    }
+
+  } while (faceIndex < numFaces);
+
+  FT_Done_FreeType(m_library);
+  return true;
+}
+
+bool UTILS::FONT::GetFontFamilyNames(const std::string& filepath,
+                                     std::set<std::string>& familyNames)
+{
+  std::vector<uint8_t> buffer;
+  if (filepath.empty())
+    return false;
+
+  if (XFILE::CFile().LoadFile(filepath, buffer) <= 0)
+  {
+    CLog::LogF(LOGERROR, "Failed to load file {}", filepath);
+    return false;
+  }
+  return GetFontFamilyNames(buffer, familyNames);
+}
+
 std::string UTILS::FONT::GetFontFamily(std::vector<uint8_t>& buffer)
 {
   FT_Library m_library{nullptr};
