@@ -25,7 +25,7 @@ typedef enum
   // Used for example when the subtitle alignment position change
   ObservableMessagePositionChanged,
   ObservableMessageGamePortsChanged,
-  ObservableMessageGameAgentsChanged,
+  ObservableMessageAgentControllersChanged,
 } ObservableMessage;
 
 class Observer
