@@ -36,12 +36,12 @@
 namespace CONTEXTMENU
 {
 
-CVideoInfo::CVideoInfo(MediaType mediaType)
+CVideoInfoBase::CVideoInfoBase(MediaType mediaType)
   : CStaticContextMenuAction(19033), m_mediaType(std::move(mediaType))
 {
 }
 
-bool CVideoInfo::IsVisible(const CFileItem& item) const
+bool CVideoInfoBase::IsVisible(const CFileItem& item) const
 {
   if (!item.HasVideoInfoTag())
     return false;
@@ -52,12 +52,27 @@ bool CVideoInfo::IsVisible(const CFileItem& item) const
   return item.GetVideoInfoTag()->m_type == m_mediaType;
 }
 
-bool CVideoInfo::Execute(const std::shared_ptr<CFileItem>& item) const
+bool CVideoInfoBase::Execute(const std::shared_ptr<CFileItem>& item) const
 {
   CGUIDialogVideoInfo::ShowFor(*item);
   return true;
 }
 
+bool CVideoInfo::IsVisible(const CFileItem& item) const
+{
+  if (CVideoInfoBase::IsVisible(item))
+    return true;
+
+  if (item.m_bIsFolder)
+    return false;
+
+  if (item.IsPVRRecording())
+    return false; // pvr recordings have its own implementation for this
+
+  const auto* tag{item.GetVideoInfoTag()};
+  return tag && tag->m_type == MediaTypeNone && !tag->IsEmpty() && item.IsVideo();
+}
+
 bool CVideoRemoveResumePoint::IsVisible(const CFileItem& itemIn) const
 {
   CFileItem item(itemIn.GetItemToPlay());
@@ -82,10 +97,21 @@ bool CVideoMarkWatched::IsVisible(const CFileItem& item) const
   if (item.m_bIsFolder && item.IsPlugin()) // we cannot manage plugin folder's watched state
     return false;
 
-  if (item.m_bIsFolder) // Only allow video db content, video and recording folders to be updated recursively
+  if (item.m_bIsFolder)
   {
-    if (item.HasVideoInfoTag())
-      return item.IsVideoDb();
+    if (item.HasProperty("watchedepisodes") && item.HasProperty("totalepisodes"))
+    {
+      return item.GetProperty("watchedepisodes").asInteger() <
+             item.GetProperty("totalepisodes").asInteger();
+    }
+    else if (item.HasProperty("watched") && item.HasProperty("total"))
+    {
+      return item.GetProperty("watched").asInteger() < item.GetProperty("total").asInteger();
+    }
+    else if (item.IsVideoDb())
+      return true;
+    else if (StringUtils::StartsWithNoCase(item.GetPath(), "library://video/"))
+      return true;
     else if (item.GetProperty("IsVideoFolder").asBoolean())
       return true;
     else
@@ -111,10 +137,20 @@ bool CVideoMarkUnWatched::IsVisible(const CFileItem& item) const
   if (item.m_bIsFolder && item.IsPlugin()) // we cannot manage plugin folder's watched state
     return false;
 
-  if (item.m_bIsFolder) // Only allow video db content, video and recording folders to be updated recursively
+  if (item.m_bIsFolder)
   {
-    if (item.HasVideoInfoTag())
-      return item.IsVideoDb();
+    if (item.HasProperty("watchedepisodes"))
+    {
+      return item.GetProperty("watchedepisodes").asInteger() > 0;
+    }
+    else if (item.HasProperty("watched"))
+    {
+      return item.GetProperty("watched").asInteger() > 0;
+    }
+    else if (item.IsVideoDb())
+      return true;
+    else if (StringUtils::StartsWithNoCase(item.GetPath(), "library://video/"))
+      return true;
     else if (item.GetProperty("IsVideoFolder").asBoolean())
       return true;
     else
