@@ -11,49 +11,33 @@
 #include "playlists/PlayListTypes.h"
 #include "video/VideoDatabase.h"
 #include "video/VideoThumbLoader.h"
+#include "video/guilib/VideoAction.h"
 #include "windows/GUIMediaWindow.h"
 
-enum VideoSelectAction
+namespace
 {
-  SELECT_ACTION_CHOOSE          = 0,
-  SELECT_ACTION_PLAY_OR_RESUME,
-  SELECT_ACTION_RESUME,
-  SELECT_ACTION_INFO,
-  SELECT_ACTION_MORE,
-  SELECT_ACTION_PLAY,
-  SELECT_ACTION_PLAYPART,
-  SELECT_ACTION_QUEUE
-};
+class CVideoSelectActionProcessor;
+class CVideoPlayActionProcessor;
+} // unnamed namespace
 
 class CGUIWindowVideoBase : public CGUIMediaWindow, public IBackgroundLoaderObserver
 {
+  friend class ::CVideoSelectActionProcessor;
+  friend class ::CVideoPlayActionProcessor;
+
 public:
   CGUIWindowVideoBase(int id, const std::string &xmlFile);
   ~CGUIWindowVideoBase(void) override;
   bool OnMessage(CGUIMessage& message) override;
   bool OnAction(const CAction &action) override;
 
-  void PlayMovie(const CFileItem* item, const std::string& player = "");
-
   /*! \brief Gets called to process the "info" action for the given file item
    Default implementation shows a dialog containing information for the movie/episode/...
    represented by the file item.
    \param fileItem the item for which information is to be presented.
-   \param scraper a scraper addon instance that can be used to obtain additional information for
-   the given item
    \return true if information was presented, false otherwise.
    */
-  virtual bool OnItemInfo(const CFileItem& fileItem, ADDON::ScraperPtr& scraper);
-
-  /*! \brief Show the resume menu for this item (if it has a resume bookmark)
-   If a resume bookmark is found, we set the item's m_lStartOffset to STARTOFFSET_RESUME.
-   Note that we do this in favour of setting the resume point, as we need additional
-   information from the database (in particular, the playerState) when resuming some items
-   (eg ISO/VIDEO_TS).
-   \param item item to check for a resume bookmark
-   \return true if an option was chosen, false if the resume menu was cancelled.
-   */
-  static bool ShowResumeMenu(CFileItem &item);
+  bool OnItemInfo(const CFileItem& fileItem);
 
   /*! \brief Append a set of search items to a results list using a specific prepend label
    Sorts the search items first, then appends with the given prependLabel to the results list.
@@ -72,12 +56,6 @@ public:
    */
   static void OnAssignContent(const std::string &path);
 
-  /*! \brief checks the database for a resume position and puts together a string
-   \param item selected item
-   \return string containing the resume position or an empty string if there is no resume position
-   */
-  static std::string GetResumeString(const CFileItem &item);
-
   /*! \brief Load video information from the database for these items (public static version)
    Useful for grabbing information for file listings, from watched status to full metadata
    \param items the items to load information for.
@@ -101,12 +79,12 @@ protected:
   void GetContextButtons(int itemNumber, CContextButtons &buttons) override;
   bool OnContextButton(int itemNumber, CONTEXT_BUTTON button) override;
   virtual void OnQueueItem(int iItem, bool first = false);
+  void OnQueueItem(const std::shared_ptr<CFileItem>& item, int iItem, bool first = false);
   virtual void OnDeleteItem(const CFileItemPtr& pItem);
   void OnDeleteItem(int iItem) override;
   virtual void DoSearch(const std::string& strSearch, CFileItemList& items) {}
   std::string GetStartFolder(const std::string &dir) override;
 
-  bool OnClick(int iItem, const std::string &player = "") override;
   bool OnSelect(int iItem) override;
   /*! \brief react to an Info action on a view item
    \param item the selected item
@@ -118,17 +96,25 @@ protected:
    \param action the action to perform
    \return true if the action is performed, false otherwise
    */
-  bool OnFileAction(int item, int action, const std::string& player);
+  bool OnFileAction(int item, VIDEO::GUILIB::Action action, const std::string& player);
 
   void OnRestartItem(int iItem, const std::string &player = "");
-  bool OnResumeItem(int iItem, const std::string &player = "");
-  void PlayItem(int iItem, const std::string &player = "");
+  bool OnPlayOrResumeItem(int iItem, const std::string& player = "");
   bool OnPlayMedia(int iItem, const std::string &player = "") override;
+  bool OnPlayMedia(const std::shared_ptr<CFileItem>& item, const std::string& player);
   bool OnPlayAndQueueMedia(const CFileItemPtr& item, const std::string& player = "") override;
   using CGUIMediaWindow::LoadPlayList;
   void LoadPlayList(const std::string& strPlayList, PLAYLIST::Id playlistId = PLAYLIST::TYPE_VIDEO);
+  bool PlayItem(const std::shared_ptr<CFileItem>& item, const std::string& player);
 
-  bool ShowIMDB(CFileItemPtr item, const ADDON::ScraperPtr& content, bool fromDB);
+  /*!
+   \brief Lookup the information of an item and display an Info dialog
+   If item has changed then refresh the active underlying list
+   \param item the item to lookup
+   \param content
+   \return true: the information of the item was modified. false: no change.
+   */
+  bool ShowInfoAndRefresh(const CFileItemPtr& item, const ADDON::ScraperPtr& content);
 
   void OnSearch();
   void OnSearchItemFound(const CFileItem* pSelItem);
@@ -138,11 +124,23 @@ protected:
 
   static bool StackingAvailable(const CFileItemList &items);
 
-  bool OnPlayStackPart(int item);
+  bool OnPlayStackPart(const std::shared_ptr<CFileItem>& item, unsigned int partNumber);
+
+  void UpdateVideoVersionItems();
+  void UpdateVideoVersionItemsLabel(const std::string& directory);
 
   CGUIDialogProgress* m_dlgProgress;
   CVideoDatabase m_database;
 
   CVideoThumbLoader m_thumbLoader;
   bool m_stackingAvailable;
+
+private:
+  /*!
+   \brief Lookup the information of an item and display an Info dialog
+   \param item the item to lookup
+   \param content
+   \return true: the information of the item was modified. false: no change.
+   */
+  bool ShowInfo(const CFileItemPtr& item, const ADDON::ScraperPtr& content);
 };
