@@ -8,12 +8,8 @@
 
 #pragma once
 
-#if defined(HAS_SDL)
-#include "windowing/osx/SDL/WinSystemOSXSDL.h"
-#else
-#include "windowing/osx/WinSystemOSX.h"
-#endif
 #include "rendering/gl/RenderSystemGL.h"
+#include "windowing/osx/WinSystemOSX.h"
 
 class CWinSystemOSXGL : public CWinSystemOSX, public CRenderSystemGL
 {
