@@ -52,3 +52,18 @@ void CWinEventsOSX::disableInputEvents()
 {
   return [m_eventsImplWrapper->callbackClass disableInputEvents];
 }
+
+void CWinEventsOSX::signalMouseEntered()
+{
+  return [m_eventsImplWrapper->callbackClass signalMouseEntered];
+}
+
+void CWinEventsOSX::signalMouseExited()
+{
+  return [m_eventsImplWrapper->callbackClass signalMouseExited];
+}
+
+void CWinEventsOSX::SendInputEvent(NSEvent* nsEvent)
+{
+  [m_eventsImplWrapper->callbackClass ProcessInputEvent:nsEvent];
+}
