@@ -10,8 +10,8 @@
 
 #include "ServiceBroker.h"
 #include "Util.h"
-#include "input/XBMC_keysym.h"
-#include "input/XBMC_vkeys.h"
+#include "input/keyboard/XBMC_keysym.h"
+#include "input/keyboard/XBMC_vkeys.h"
 #include "settings/AdvancedSettings.h"
 #include "settings/SettingsComponent.h"
 
