@@ -36,6 +36,7 @@
 #include "platform/win32/input/IRServerSuite.h"
 
 #include <algorithm>
+#include <cmath>
 #include <mutex>
 
 #include <tpcshrd.h>
@@ -47,10 +48,6 @@ const char* CWinSystemWin32::SETTING_WINDOW_LEFT = "window.left";
 
 CWinSystemWin32::CWinSystemWin32()
   : CWinSystemBase()
-  , PtrGetGestureInfo(nullptr)
-  , PtrSetGestureConfig(nullptr)
-  , PtrCloseGestureInfoHandle(nullptr)
-  , PtrEnableNonClientDpiScaling(nullptr)
   , m_hWnd(nullptr)
   , m_hMonitor(nullptr)
   , m_hInstance(nullptr)
@@ -125,17 +122,6 @@ bool CWinSystemWin32::CreateNewWindow(const std::string& name, bool fullScreen,
   if(m_hInstance == nullptr)
     CLog::LogF(LOGDEBUG, " GetModuleHandle failed with {}", GetLastError());
 
-  // Load Win32 procs if available
-  HMODULE hUser32 = GetModuleHandle(L"user32");
-  if (hUser32)
-  {
-    PtrGetGestureInfo = reinterpret_cast<pGetGestureInfo>(GetProcAddress(hUser32, "GetGestureInfo"));
-    PtrSetGestureConfig = reinterpret_cast<pSetGestureConfig>(GetProcAddress(hUser32, "SetGestureConfig"));
-    PtrCloseGestureInfoHandle = reinterpret_cast<pCloseGestureInfoHandle>(GetProcAddress(hUser32, "CloseGestureInfoHandle"));
-    // if available, enable automatic DPI scaling of the non-client area portions of the window.
-    PtrEnableNonClientDpiScaling = reinterpret_cast<pEnableNonClientDpiScaling>(GetProcAddress(hUser32, "EnableNonClientDpiScaling"));
-  }
-
   UpdateStates(fullScreen);
   // initialize the state
   WINDOW_STATE state = GetState(fullScreen);
@@ -194,9 +180,6 @@ bool CWinSystemWin32::CreateNewWindow(const std::string& name, bool fullScreen,
       // are for the client part of the window.
       RECT rcWorkArea = GetScreenWorkArea(m_hMonitor);
 
-      int workAreaWidth = rcWorkArea.right - rcWorkArea.left;
-      int workAreaHeight = rcWorkArea.bottom - rcWorkArea.top;
-
       RECT rcNcArea = GetNcAreaOffsets(m_windowStyle, false, m_windowExStyle);
       int maxClientWidth = (rcWorkArea.right - rcNcArea.right) - (rcWorkArea.left - rcNcArea.left);
       int maxClientHeight = (rcWorkArea.bottom - rcNcArea.bottom) - (rcWorkArea.top - rcNcArea.top);
@@ -382,6 +365,11 @@ void CWinSystemWin32::FinishWindowResize(int newWidth, int newHeight)
   m_nHeight = newHeight;
 }
 
+void CWinSystemWin32::ForceFullScreen(const RESOLUTION_INFO& resInfo)
+{
+  ResizeWindow(resInfo.iScreenWidth, resInfo.iScreenHeight, 0, 0);
+}
+
 void CWinSystemWin32::AdjustWindow(bool forceResize)
 {
   CLog::LogF(LOGDEBUG, "adjusting window if required.");
@@ -420,9 +408,6 @@ void CWinSystemWin32::AdjustWindow(bool forceResize)
         // are for the client part of the window.
         RECT rcWorkArea = GetScreenWorkArea(m_hMonitor);
 
-        int workAreaWidth = rcWorkArea.right - rcWorkArea.left;
-        int workAreaHeight = rcWorkArea.bottom - rcWorkArea.top;
-
         RECT rcNcArea = GetNcAreaOffsets(m_windowStyle, false, m_windowExStyle);
         int maxClientWidth =
             (rcWorkArea.right - rcNcArea.right) - (rcWorkArea.left - rcNcArea.left);
@@ -524,6 +509,10 @@ void CWinSystemWin32::CenterCursor() const
 
 bool CWinSystemWin32::SetFullScreen(bool fullScreen, RESOLUTION_INFO& res, bool blankOtherDisplays)
 {
+  // Initialisation not finished, pretend the function succeeded
+  if (!m_hWnd)
+    return true;
+
   CWinSystemWin32::UpdateStates(fullScreen);
   WINDOW_STATE state = GetState(fullScreen);
 
@@ -767,7 +756,11 @@ MONITOR_DETAILS* CWinSystemWin32::GetDisplayDetails(const std::string& name)
     {
       if (nameW[0] == '\\') // name is device name
         return m.DeviceNameW == nameW;
-      return m.MonitorNameW == nameW;
+      else if (m.MonitorNameW == nameW)
+        return true;
+      else if (m.DeviceStringW == nameW)
+        return true;
+      return false;
     });
     if (it != m_displays.end())
       return &(*it);
@@ -824,9 +817,6 @@ void CWinSystemWin32::GetConnectedDisplays(std::vector<MONITOR_DETAILS>& outputs
 {
   using KODI::PLATFORM::WINDOWS::FromW;
 
-  const POINT ptZero = { 0, 0 };
-  HMONITOR hmPrimary = MonitorFromPoint(ptZero, MONITOR_DEFAULTTOPRIMARY);
-
   DISPLAY_DEVICEW ddAdapter = {};
   ddAdapter.cb = sizeof(ddAdapter);
 
@@ -876,9 +866,21 @@ void CWinSystemWin32::GetConnectedDisplays(std::vector<MONITOR_DETAILS>& outputs
       do
       {
         // `Monitor #N`
-        md.MonitorNameW = std::wstring(ddMon.DeviceString) + L" #" + std::to_wstring(num++);
-      }
-      while(std::any_of(outputs.begin(), outputs.end(), [&](MONITOR_DETAILS& m) { return m.MonitorNameW == md.MonitorNameW; }));
+        md.DeviceStringW = std::wstring(ddMon.DeviceString) + L" #" + std::to_wstring(num++);
+      } while (std::any_of(outputs.begin(), outputs.end(), [&](MONITOR_DETAILS& m) {
+        return m.DeviceStringW == md.DeviceStringW;
+      }));
+
+      std::wstring displayName = CWIN32Util::GetDisplayFriendlyName(ddAdapter.DeviceName);
+      if (displayName.empty())
+        displayName = std::wstring(ddMon.DeviceString);
+      num = 1;
+      do
+      {
+        // `Pretty Monitor Name #N`
+        md.MonitorNameW = displayName + L" #" + std::to_wstring(num++);
+      } while (std::any_of(outputs.begin(), outputs.end(),
+                           [&](MONITOR_DETAILS& m) { return m.MonitorNameW == md.MonitorNameW; }));
 
       md.CardNameW = ddAdapter.DeviceString;
       md.DeviceNameW = ddAdapter.DeviceName;
@@ -928,8 +930,7 @@ bool CWinSystemWin32::ChangeResolution(const RESOLUTION_INFO& res, bool forceCha
     bool bResChanged = false;
 
     // Windows 8 refresh rate workaround for 24.0, 48.0 and 60.0 Hz
-    if ( CSysInfo::IsWindowsVersionAtLeast(CSysInfo::WindowsVersionWin8)
-      && (res.fRefreshRate == 24.0 || res.fRefreshRate == 48.0 || res.fRefreshRate == 60.0))
+    if (res.fRefreshRate == 24.0 || res.fRefreshRate == 48.0 || res.fRefreshRate == 60.0)
     {
       CLog::LogF(LOGDEBUG, "Using Windows 8+ workaround for refresh rate {} Hz",
                  static_cast<int>(res.fRefreshRate));
@@ -1002,9 +1003,17 @@ void CWinSystemWin32::UpdateResolutions()
   CWinSystemBase::UpdateResolutions();
   GetConnectedDisplays(m_displays);
 
-  MONITOR_DETAILS* details = GetDisplayDetails(CServiceBroker::GetSettingsComponent()->GetSettings()->GetString(CSettings::SETTING_VIDEOSCREEN_MONITOR));
+  const auto settings = CServiceBroker::GetSettingsComponent()->GetSettings();
+  std::string settingsMonitor = settings->GetString(CSettings::SETTING_VIDEOSCREEN_MONITOR);
+  MONITOR_DETAILS* details = GetDisplayDetails(settingsMonitor);
   if (!details)
     return;
+  // Migrate the setting to EDID-based name for connected and recognized screens.
+  // Other screens may be temporarily turned off, ignore so they're used once available again
+  if (settingsMonitor != FromW(details->MonitorNameW) &&
+      (settingsMonitor == FromW(details->DeviceStringW) ||
+       settingsMonitor == FromW(details->DeviceNameW)))
+    CDisplaySettings::GetInstance().SetMonitor(FromW(details->MonitorNameW));
 
   float refreshRate;
   int w = details->ScreenWidth;
@@ -1226,7 +1235,7 @@ void CWinSystemWin32::SetForegroundWindowInternal(HWND hWnd)
   }
 }
 
-std::unique_ptr<CVideoSync> CWinSystemWin32::GetVideoSync(void *clock)
+std::unique_ptr<CVideoSync> CWinSystemWin32::GetVideoSync(CVideoReferenceClock* clock)
 {
   std::unique_ptr<CVideoSync> pVSync(new CVideoSyncD3D(clock));
   return pVSync;
@@ -1335,11 +1344,51 @@ RECT CWinSystemWin32::GetVirtualScreenRect()
   return rect;
 }
 
-int CWinSystemWin32::GetGuiSdrPeakLuminance() const
+/*!
+ * \brief Max luminance for GUI SDR content in HDR mode.
+ * \return Max luminance in nits, lower than 10000.
+*/
+float CWinSystemWin32::GetGuiSdrPeakLuminance() const
 {
   const auto settings = CServiceBroker::GetSettingsComponent()->GetSettings();
 
-  return settings->GetInt(CSettings::SETTING_VIDEOSCREEN_GUISDRPEAKLUMINANCE);
+  // use cached system value as this is called for each frame
+  if (settings->GetBool(CSettings::SETTING_VIDEOSCREEN_USESYSTEMSDRPEAKLUMINANCE) &&
+      m_validSystemSdrPeakLuminance)
+    return m_systemSdrPeakLuminance;
+
+  // Max nits for 100% UI setting = 1000 nits, < 10000 nits, min 80 nits for 0%
+  const int guiSdrPeak = settings->GetInt(CSettings::SETTING_VIDEOSCREEN_GUISDRPEAKLUMINANCE);
+  return (80.0f * std::pow(std::exp(1.0f), 0.025257f * guiSdrPeak));
+}
+
+/*!
+ * \brief Test support of the OS for a SDR max luminance in HDR mode setting
+ * \return true when the OS supports that setting, false otherwise
+*/
+bool CWinSystemWin32::HasSystemSdrPeakLuminance()
+{
+  MONITOR_DETAILS* md = GetDisplayDetails(m_hMonitor);
+  if (md)
+    return CWIN32Util::GetSystemSdrWhiteLevel(md->DeviceNameW, nullptr);
+
+  return false;
+}
+
+/*!
+ * \brief Cache the system HDR/SDR balance for use during rendering, instead of querying the API
+ for each frame.
+*/
+void CWinSystemWin32::CacheSystemSdrPeakLuminance()
+{
+  m_validSystemSdrPeakLuminance = false;
+
+  MONITOR_DETAILS* md = GetDisplayDetails(m_hMonitor);
+  if (md)
+  {
+    m_validSystemSdrPeakLuminance =
+        CWIN32Util::GetSystemSdrWhiteLevel(md->DeviceNameW, &m_systemSdrPeakLuminance);
+  }
 }
 
 RECT CWinSystemWin32::GetScreenWorkArea(HMONITOR handle) const
